@@ -21,6 +21,7 @@
 
 void Configurator::initMe(QApplication *pApp)
 {
+	int iRet = 0;
 	bool bState = false;
 	m_pNewProcess = NULL;
 	m_iCurrentStep = 0;
@@ -39,8 +40,10 @@ void Configurator::initMe(QApplication *pApp)
 	if (!checkLibraryExists (qsLib))
 		checkVideoVLC->setEnabled(false);
 	qsLib = QString ("mplayer");
-	system ((const char *)QString ("which %1 > /tmp/out.txt 2>/dev/null").arg(qsLib));
-	QFileInfo fileInfo("/tmp/out.txt");
+	QString qsTempFile;
+	qsTempFile = QString ( "/tmp/%1_out.txt" ).arg ( getlogin ( ) );
+	iRet = system ((const char *)QString ("which %1 > %2 2>/dev/null").arg(qsLib).arg ( qsTempFile ) );
+	QFileInfo fileInfo( qsTempFile );
 	// Okay we can not find it, so we wont bother asking the user ...
 	if (fileInfo.size() < 5)
 		checkVideoMPlayer->setEnabled(false);
@@ -58,11 +61,13 @@ void Configurator::initMe(QApplication *pApp)
 		checkVideoVLC->setChecked(true);
 
 	// Last we set the lineEdits to reflect the current environment variables.
-	QString qsInstallDir (getenv("PREFIX"));
-	if (!qsInstallDir.isEmpty())
-		editInstallDir->setText(qsInstallDir);
-	editQtDir->setText(QString ( getenv("QTDIR")));
-	editLDLibraryPath->setText(QString ( getenv("LD_LIBRARY_PATH")));
+	QString qsInstallDir  ( getenv ( "PREFIX"      ) );
+	QString qsIncludePath = QString ( QString ( getenv ( "INCLUDEPATH" ) ) + " " + QString ( getenv ( "ADD_INCLUDEDIR" ) ) );
+	if  ( ! qsInstallDir.isEmpty ( ) )
+		editInstallDir->setText ( qsInstallDir );
+	editQtDir->setText(QString ( getenv  ( "QTDIR" ) ) );
+	editLDLibraryPath->setText ( QString ( getenv ( "LD_LIBRARY_PATH" ) ) );
+	editIncludePath->setText   ( QString ( qsIncludePath ) );
 	// Here we check if an executable exists already ...
 	QFileInfo theFile ("../bin/qdvdauthor");
 	if ( (theFile.exists()) && (theFile.size() > 1) ) 
@@ -80,14 +85,17 @@ void Configurator::initMe(QApplication *pApp)
 
 QString Configurator::findGuiSU()
 {
+	int iRet;
 	uint t;
 	QString qsReturn;
- 	char *arraySUs[3] = {"kdesu", "xsu", "gnomesu"};
-	QFileInfo fileInfo("/tmp/out.txt");
+ 	char arraySUs[3][8] = {"kdesu", "xsu", "gnomesu"};
+	QString qsFileName;
+	qsFileName = QString ( "/tmp/%1_out.txt" ).arg ( getlogin ( ) );
+	QFileInfo fileInfo( qsFileName );
 	for (t=0;t<3;t++)	{
 		// the next check is to see if we can find kdesu
-		system ((const char *)QString ("which %1 > /tmp/out.txt 2>/dev/null").arg(arraySUs[t]));
-		fileInfo.setFile("/tmp/out.txt");
+		iRet = system ((const char *)QString ("which %1 > %2 2>/dev/null").arg(arraySUs[t]).arg ( qsFileName ) );
+		fileInfo.setFile( qsFileName );
 		// Okay we cna not find it, so we wont bother asking the user ...
 		if (fileInfo.size() > 4)	{
 			qsReturn = QString ("%1").arg(arraySUs[t]);
@@ -142,6 +150,7 @@ bool Configurator::checkLibraryExists(QString &libName)
 void Configurator::slotCompile()
 {
 	QCursor myCursor (QCursor::WaitCursor);
+	int iRet = 0;
 	uint t;
 	m_iTotalSteps = getCompileSteps();
 	tabWidget2->setCurrentPage(2);
@@ -168,14 +177,16 @@ void Configurator::slotCompile()
 	if (checkDebug->isOn())
 		listEnv.append (QString("DEBUG_QDVDAUTHOR=debug"));
 
-	if (!editLDLibraryPath->text().isEmpty())
-		listEnv.append (QString("LD_LIBRARY_PATH=%1").arg(editLDLibraryPath->text()));
-	if (checkVideoXine->isOn())
-		 listEnv.append ("WITH_XINE_SUPPORT=1");
+	if (!editLDLibraryPath->text ( ).isEmpty ( ) )
+		listEnv.append ( QString("LD_LIBRARY_PATH=%1").arg ( editLDLibraryPath->text ( ) ) );
+	if (!editIncludePath->text ( ).isEmpty ( ) )
+		listEnv.append ( QString("ADD_INCLUDEDIR=%1").arg  ( editIncludePath->text   ( ) ) );
+	if (checkVideoXine->isOn ( ) )
+		 listEnv.append ( "WITH_XINE_SUPPORT=1" );
 	if (checkVideoMPlayer->isOn())
-		 listEnv.append ("WITH_MPLAYER_SUPPORT=1");
+		 listEnv.append ( "WITH_MPLAYER_SUPPORT=1" );
 	if (checkVideoVLC->isOn())
-		 listEnv.append ("WITH_VLC_SUPPORT=1");
+		 listEnv.append ( "WITH_VLC_SUPPORT=1" );
 
 	if ( !checkVideoXine->isOn() && !checkVideoMPlayer->isOn() && !checkVideoVLC->isOn() )
 		 listEnv.append ("WITH_MPLAYER_SUPPORT=1");
@@ -201,10 +212,10 @@ void Configurator::slotCompile()
 		putenv ((char *)((const char *)listEnv [t]));
 
 	// qdvdauthor.pro needs those files to physically be there ... Go figure !
-	system ("touch ../bin/qdvdauthor ../bin/qslideshow ../bin/qplayer");
+	iRet = system ("touch ../bin/qdvdauthor ../bin/qslideshow ../bin/qplayer");
 	// Next we should remove the Makefile's so we build with new media engine - support.
 	if (hasMediaEngineSelectionChanged())
-		system ("rm ../qdvdauthor/Makefile ../qdvdauthor/qplayer/Makefile ../qdvdauthor/qslideshow/Makefile");
+		iRet = system ("rm Makefile ../qdvdauthor/Makefile ../qdvdauthor/qplayer/Makefile ../qdvdauthor/qslideshow/Makefile");
 
 	m_pNewProcess->setWorkingDirectory (QDir ("../"));
 	// And here we generate the make file and compile the application.
@@ -435,6 +446,7 @@ int Configurator::getCompileSteps ()
 
 void Configurator::slotMakeClean()
 {
+	int iRet = 0;
 	tabWidget2->setCurrentPage(2);
 	progressBarCompile->setProgress (0);
 	buttonExecute->setEnabled( false );
@@ -451,14 +463,16 @@ void Configurator::slotMakeClean()
 	m_pNewProcess->addArgument (QString("make"));
 	m_pNewProcess->addArgument (QString("clean"));
 	m_pNewProcess->start ();
-	system ("rm ../bin/*");
+	iRet = system ( "rm ../bin/qdvdautor; rm ../bin/qslideshow; rm ../bin/qplayer; rm ../bin/configurator; rm ../bin/qrender; rm ../bin/core*");
+	iRet = system ( "rm ../qdvdauthor/i18n/*.qm ../qdvdauthor/CONFIG.h ../qdvdauthor/qplayer/MEDIA_CONFIG.h 2>&1 > /dev/null" );
 	buttonExecute->setEnabled( false );
 	buttonInstall->setEnabled( false );
 }
 
 void Configurator::slotExecute()
 {
-	system ("../bin/qdvdauthor &");
+	int iRet = 0;
+	iRet = system ("../bin/qdvdauthor &");
 }
 
 void Configurator::slotInstall()
@@ -545,7 +559,7 @@ void Configurator::slotInstall()
 		stream << "#!/bin/sh\n\n" << qsQTDir << QString ("make -C %1 install").arg(theDir.absPath());
 		file.close();
 	}
-	chmod ("/tmp/make_install.sh", S_IEXEC | S_IRUSR | S_IWRITE);
+	chmod ("/tmp/make_install.sh", S_IEXEC | S_IRUSR | S_IWRITE | S_IROTH | S_IXOTH | S_IWOTH );
 
 	if (!bCanWriteToInstallDir)	{
 		if (qsGuiSU == QString ("kdesu"))	{
