@@ -1,6 +1,11 @@
 
 cd /home/varol/projects/
 
+echo "cd htdocs/nightly/
+put qdvdauthor.tar.bz2
+quit
+"
+
 rm qdvdauthor.tar.bz2
 allFiles=`find qdvdauthor -type f | grep -v CVS`
 tar -cjf qdvdauthor.tar.bz2 $allFiles
@@ -9,16 +14,5 @@ echo
 ls -ll qdvdauthor.tar.bz2
 echo
 
-echo "cd htdocs/nightly/
-put qdvdauthor.tar.bz2
-quit
-
-" > cmds.txt
-
-cat cmds.txt
-
-
 sftp qdvdauthor@sftp.sourceforge.net
 
-rm cmds.txt
-
