@@ -13,6 +13,7 @@
 **
 ****************************************************************************/
 
+#include <qtimer.h>
 #include <qobject.h>
 #include <qfileinfo.h>
 #include <qlistview.h>
@@ -23,9 +24,11 @@
 #include "menupreview.h"
 #include "dialogbutton.h"
 #include "menuobject.h"
+#include "textobject.h"
 #include "frameobject.h"
 #include "buttonobject.h"
 #include "qdvdauthor.h"
+#include "imageobject.h"
 #include "sourcefileentry.h"
 #include "structuretoolbar.h"
 
@@ -45,26 +48,29 @@ ButtonObject::~ButtonObject ()
 	// Creation and destruction is done in the Parent (MenuPreview / ButtonPreview etc.)
 }
 
-MenuObject *ButtonObject::clone()
+MenuObject *ButtonObject::clone ( QWidget *pParent )
 {
-	uint t;
-	ButtonObject *pNewObject = new ButtonObject (MenuObject::parent());
-	for (t=0;t<m_listNormalState.count();t++)
-		pNewObject->appendNormal (m_listNormalState[t]->clone());
-	for (t=0;t<m_listSelectedState.count();t++)
-		pNewObject->appendSelected (m_listSelectedState[t]->clone());
-	for (t=0;t<m_listHighlightedState.count();t++)
-		pNewObject->appendHighlighted (m_listHighlightedState[t]->clone());
-
-	pNewObject->setSourceFileEntry(sourceFileEntry());
-	pNewObject->setAction(m_qsAction);
-	pNewObject->setName  (m_qsName);
-	pNewObject->setNext (NEXT_BUTTON_UP,    m_qsUp   );
-	pNewObject->setNext (NEXT_BUTTON_DOWN,  m_qsDown );
-	pNewObject->setNext (NEXT_BUTTON_RIGHT, m_qsRight);
-	pNewObject->setNext (NEXT_BUTTON_LEFT,  m_qsLeft );
-	
-	return pNewObject;
+  if ( ! pParent )
+    pParent = MenuObject::parent ( );
+  uint t;
+  ButtonObject *pNewObject = new ButtonObject ( pParent );
+  for (t=0;t<m_listNormalState.count();t++)
+    pNewObject->appendNormal (m_listNormalState[t]->clone ( pParent ) );
+  for (t=0;t<m_listSelectedState.count();t++)
+    pNewObject->appendSelected (m_listSelectedState[t]->clone ( pParent ) );
+  for (t=0;t<m_listHighlightedState.count();t++)
+    pNewObject->appendHighlighted (m_listHighlightedState[t]->clone ( pParent ) );
+  
+  pNewObject->setSourceFileEntry(sourceFileEntry());
+  pNewObject->setAction   ( action    ( ) );
+  pNewObject->setPreAction( preAction ( ) );
+  pNewObject->setName     ( name      ( ) );
+  pNewObject->setNext     ( NEXT_BUTTON_UP,    m_qsUp    );
+  pNewObject->setNext     ( NEXT_BUTTON_DOWN,  m_qsDown  );
+  pNewObject->setNext     ( NEXT_BUTTON_RIGHT, m_qsRight );
+  pNewObject->setNext     ( NEXT_BUTTON_LEFT,  m_qsLeft  );
+  
+  return pNewObject;
 }
 
 ButtonObject &ButtonObject::operator = (ButtonObject &theOther)
@@ -72,12 +78,13 @@ ButtonObject &ButtonObject::operator = (ButtonObject &theOther)
 	uint t;
 	clear ();
 	setSourceFileEntry(theOther.sourceFileEntry());
-	m_qsAction = theOther.action();
-	m_qsName   = theOther.name();
-	m_qsUp     = theOther.next(NEXT_BUTTON_UP);
-	m_qsDown   = theOther.next(NEXT_BUTTON_DOWN);
-	m_qsRight  = theOther.next(NEXT_BUTTON_RIGHT);
-	m_qsLeft   = theOther.next(NEXT_BUTTON_LEFT);
+	m_qsAction    = theOther.action();
+	m_qsPreAction = theOther.preAction();
+	m_qsName      = theOther.name();
+	m_qsUp        = theOther.next(NEXT_BUTTON_UP);
+	m_qsDown      = theOther.next(NEXT_BUTTON_DOWN);
+	m_qsRight     = theOther.next(NEXT_BUTTON_RIGHT);
+	m_qsLeft      = theOther.next(NEXT_BUTTON_LEFT);
 	// The following lists hold the information for the different button states.
 	for (t=0;t<theOther.getNormalCount();t++)
 		appendNormal(theOther.getNormal(t));
@@ -93,11 +100,12 @@ void ButtonObject::clear ()
 	uint t;
 
 	m_iButtonState = STATE_NORMAL;
-	m_qsAction = QString ("");
-	m_qsUp     = QString ("");
-	m_qsDown   = QString ("");
-	m_qsRight  = QString ("");
-	m_qsLeft   = QString ("");
+	m_qsAction     = QString ("");
+	m_qsPreAction  = QString ("");
+	m_qsUp         = QString ("");
+	m_qsDown       = QString ("");
+	m_qsRight      = QString ("");
+	m_qsLeft       = QString ("");
 	m_pSourceFileEntry = NULL;
 
 	for (t=0;t<m_listNormalState.count();t++)
@@ -211,14 +219,14 @@ bool ButtonObject::mouseMoveEvent (QMouseEvent *pEvent)
 
 bool ButtonObject::mousePressEvent (QMouseEvent *pEvent)
 {
-	m_currentMousePos = pEvent->pos();
+	m_currentMousePos = pEvent->pos ( );
 	if (pEvent->button() == Qt::RightButton)	{
 		QPoint globalPos = pEvent->globalPos();
 		return createContextMenu ( globalPos );
 	}
 	else // Here I only want to activate the drawing of the frame rather then the full thing.
-		if (m_listNormalState[0])
-			m_listNormalState[0]->mousePressEvent (pEvent);
+	  if ( m_listNormalState[0] )
+	       m_listNormalState[0]->mousePressEvent (pEvent);
 	m_bDrawRect = true;
 	return false;
 }
@@ -226,8 +234,8 @@ bool ButtonObject::mousePressEvent (QMouseEvent *pEvent)
 bool ButtonObject::mouseReleaseEvent (QMouseEvent *pEvent)
 {
 	m_bDrawRect = false;
-	if (m_listNormalState[0])
-		m_listNormalState[0]->mouseReleaseEvent (pEvent);
+	if ( m_listNormalState[0] )
+	     m_listNormalState[0]->mouseReleaseEvent (pEvent);
 	emit (signalUpdatePixmap());
 	emit (signalUpdateStructure());
 	return false;
@@ -235,9 +243,31 @@ bool ButtonObject::mouseReleaseEvent (QMouseEvent *pEvent)
 
 bool ButtonObject::mouseDoubleClickEvent(QMouseEvent *)
 {
-	// Call MenuPreview::slotCreateButtonDialog ()
-	emit (signalCreateButtonDialog (this));
-	return false;
+  // Call MenuPreview::slotCreateButtonDialog ()
+  emit (signalCreateButtonDialog (this));
+  return false;
+}
+
+MenuObject *ButtonObject::shadow ( )
+{
+  MenuObject *pNormal = getNormal ( 0 );
+  if ( pNormal )
+    return pNormal->shadow ( );
+  return NULL;
+}
+
+void ButtonObject::updateShadow ( )
+{
+  MenuObject *pNormal = getNormal ( 0 );
+  if ( pNormal )
+       pNormal->updateShadow ( );
+}
+
+void ButtonObject::setShadow ( MenuObject *pShadow )
+{
+  MenuObject *pNormal = getNormal ( 0 );
+  if ( pNormal )
+       pNormal->setShadow ( pShadow );
 }
 
 void ButtonObject::appendNormal (MenuObject *pObject)
@@ -323,6 +353,10 @@ bool ButtonObject::readProjectFile  (QDomNode &theNode)
 	if (!attribute.isNull())
 		m_qsAction = attribute.value();
 
+	attribute = theElement.attributeNode ( BUTTON_OBJECT_PRE_ACTION );
+	if ( ! attribute.isNull ( ) )
+		m_qsPreAction = attribute.value ( );
+
 	attribute = theElement.attributeNode ( BUTTON_OBJECT_UP );
 	if (!attribute.isNull())
 		m_qsUp = attribute.value();
@@ -359,7 +393,6 @@ bool ButtonObject::readProjectFile  (QDomNode &theNode)
 		m_qsSourceDisplayName = attribute.value();
 	// Please note that the nortmal / selected / highlighted objects are read
 	// in by ButtonObject::readObjects(...);
-//printf ("ButtonObject::readProjectFile <%s> \n", (const char *)m_qsSourceDisplayName);
 	return true;
 }
 
@@ -407,13 +440,15 @@ bool ButtonObject::writeProjectFile (QDomElement &theElement)
 		buttonNode.setAttribute( BUTTON_OBJECT_NAME,   m_qsName );
 	if (!m_qsAction.isNull())
 		buttonNode.setAttribute( BUTTON_OBJECT_ACTION, m_qsAction );
-	if ( (!m_qsUp.isNull()) || ( m_qsUp != QString ("-- default --")) )
+	if ( ! m_qsPreAction.isNull ( ) )
+		buttonNode.setAttribute( BUTTON_OBJECT_PRE_ACTION, m_qsPreAction );
+	if ( (!m_qsUp.isNull()) && ( m_qsUp != QString ("-- default --")) )
 		buttonNode.setAttribute( BUTTON_OBJECT_UP,     m_qsUp );
-	if ( (!m_qsDown.isNull()) || ( m_qsDown != QString ("-- default --")) )
+	if ( (!m_qsDown.isNull()) && ( m_qsDown != QString ("-- default --")) )
 		buttonNode.setAttribute( BUTTON_OBJECT_DOWN,   m_qsDown );
-	if ( (!m_qsLeft.isNull()) || ( m_qsLeft != QString ("-- default --")) )
+	if ( (!m_qsLeft.isNull()) && ( m_qsLeft != QString ("-- default --")) )
 		buttonNode.setAttribute( BUTTON_OBJECT_LEFT,   m_qsLeft );
-	if ( (!m_qsRight.isNull()) || ( m_qsRight != QString ("-- default --")) )
+	if ( (!m_qsRight.isNull()) && ( m_qsRight != QString ("-- default --")) )
 		buttonNode.setAttribute( BUTTON_OBJECT_RIGHT,  m_qsRight );
 	if (!m_bMoveable)
 		buttonNode.setAttribute( BUTTON_OBJECT_MOVEABLE, QString ("false") );
@@ -446,29 +481,54 @@ bool ButtonObject::writeProjectFile (QDomElement &theElement)
 
 bool ButtonObject::createContextMenu (QPoint globalPos)
 {
-	int iID = -1;
-        QPoint globalPos2 = globalPos;
+	int     iID = -1;
+	bool    bHasPropertyDialog;
+	QString qsObject, qsEditObject;
+        QPoint  globalPos2 = globalPos;
 	QPopupMenu *pStackMenu = new QPopupMenu(m_pParent);
+	pStackMenu->insertItem ( tr ("Cut") , this, SLOT ( slotCut  ( ) ) );
+	pStackMenu->insertItem ( tr ("Copy"), this, SLOT ( slotCopy ( ) ) );
+	pStackMenu->insertSeparator ( );
 	pStackMenu->insertItem ( tr ("To Front")  , this, SLOT(slotToFront()));
 	pStackMenu->insertItem ( tr ("To Back")   , this, SLOT(slotToBack()));
-	globalPos.setX (globalPos.x() - pStackMenu->sizeHint().width()); // -100);
+	globalPos.setY ( globalPos.y ( ) - 25 );
+	globalPos.setX ( globalPos.x ( ) - pStackMenu->sizeHint().width()); // -100);
 	pStackMenu->popup(globalPos, 1);
 
-	if (m_pContextMenu)
-		delete m_pContextMenu;
+	bHasPropertyDialog = false;
+	qsEditObject = tr ( "Edit Object ..." );
+	if ( m_listNormalState[0] ) {
+	  if ( m_listNormalState[0]->objectType ( ) == QString ( IMAGE_OBJECT ) ) {
+	    qsEditObject = tr ( "Edit Image ..." );
+	    qsObject     = tr ( "Image Properties ..." );
+	    bHasPropertyDialog = true;
+	  }
+	  else if ( m_listNormalState[0]->objectType ( ) == QString ( MOVIE_OBJECT ) ) {
+	    qsEditObject = tr ( "Edit Movie ..." );
+	    qsObject     = tr ( "Movie Properties ..." );
+	    bHasPropertyDialog = true;
+	  }
+	}
+
+	if ( m_pContextMenu )
+	     delete m_pContextMenu;
 	m_pContextMenu = new QPopupMenu(m_pParent);
 	m_pContextMenu->setCheckable (true);
-	m_pContextMenu->insertItem ( tr ("Edit ..."), (QObject *)this, SLOT(slotEdit     ()));
-	m_pContextMenu->insertItem ( tr ("Unbutton"), (QObject *)this, SLOT(slotUnbutton ()));
-	m_pContextMenu->insertItem ( tr ("Delete")  , (QObject *)this, SLOT(slotDelete   ()));
-	iID = m_pContextMenu->insertItem ( tr ("Moveable"), (QObject *)this, SLOT(slotMoveable ()));
-	m_pContextMenu->insertSeparator();
-	m_pContextMenu->insertItem ( tr ("Add Frame"), (QObject *)this, SLOT(slotAddFrame()));
-	m_pContextMenu->insertItem ( tr ("Add Image"), (QObject *)this, SLOT(slotAddImage()));
-	m_pContextMenu->insertItem ( tr ("Add Movie"), (QObject *)this, SLOT(slotAddMovie()));
+	if ( bHasPropertyDialog )
+	     m_pContextMenu->insertItem ( qsObject,          (QObject *)this, SLOT(slotObjectProperties ( ) ) );
+	m_pContextMenu->insertItem ( qsEditObject,           (QObject *)this, SLOT(slotEditObject ( ) ) );
+	m_pContextMenu->insertSeparator ( );
+	m_pContextMenu->insertItem ( tr ("Edit Button ..."), (QObject *)this, SLOT(slotEdit       ( ) ) );
+	m_pContextMenu->insertItem ( tr ("Unbutton"),        (QObject *)this, SLOT(slotUnbutton   ( ) ) );
+	m_pContextMenu->insertItem ( tr ("Delete"),          (QObject *)this, SLOT(slotDelete     ( ) ) );
+	iID = m_pContextMenu->insertItem ( tr ("Moveable"),  (QObject *)this, SLOT(slotMoveable   ( ) ) );
+	m_pContextMenu->insertSeparator ( );
+	m_pContextMenu->insertItem ( tr ("Add Frame"),       (QObject *)this, SLOT(slotAddFrame   ( ) ) );
+	m_pContextMenu->insertItem ( tr ("Add Image"),       (QObject *)this, SLOT(slotAddImage   ( ) ) );
+	m_pContextMenu->insertItem ( tr ("Add Movie"),       (QObject *)this, SLOT(slotAddMovie   ( ) ) );
 	m_pContextMenu->setItemChecked (iID, m_bMoveable);
 
-	m_pContextMenu->exec(globalPos2, 4);
+	m_pContextMenu->exec(globalPos2, 5);
 
 	delete pStackMenu;
 	if (m_pContextMenu)
@@ -479,44 +539,43 @@ bool ButtonObject::createContextMenu (QPoint globalPos)
 	// base classes to continue with the mouse event
 //	if (iReturn != -1)
 		return true;
-//printf ("Clicked inside TextButton\n");
 }
 
 void ButtonObject::createStructure (QListViewItem *pParentItem)
 {
-	// Creating teh ListView structure of this Button.
-	StructureItem *pButtonItem;
-	StructureItem *pStateItem;
+  // Creating teh ListView structure of this Button.
+  StructureItem *pButtonItem;
+  StructureItem *pStateItem;
 
-	QString qsAction;
-	QStringList actionList;
-	if (!m_qsAction.isEmpty())	{	// For new buttons this might be empty ...
-		actionList = QStringList::split (QString (STRING_SEPARATOR), m_qsAction);
-		if (actionList.count() == 1)	
-			qsAction = m_qsAction;
-		else	{
-			qsAction = actionList[0] + QString (" ") +actionList[1] + QString (" ") +actionList[2];
-			if (actionList.count() == 4)
-				qsAction += QString (" ") +actionList[3];
-		}
-	}
-	pButtonItem = new StructureItem(this, pParentItem, m_qsName, qsAction);
-	pButtonItem->setExpandable (TRUE);
-
-	uint t;
-	for (t=0;t<m_listHighlightedState.count();t++)	{
-	  pStateItem = new StructureItem(this, pButtonItem, QString ("Highlighted"), QString (""));
-		pStateItem->setExpandable (TRUE);
-		m_listHighlightedState[t]->createStructure (pStateItem);
-	}
-	for (t=0;t<m_listSelectedState.count();t++)	{
-	  pStateItem = new StructureItem(this, pButtonItem, QString ("Selected"), QString (""));
-		pStateItem->setExpandable (TRUE);
-		m_listSelectedState[t]->createStructure (pStateItem);
-	}
-	for (t=0;t<m_listNormalState.count();t++)	{
-		m_listNormalState[t]->createStructure (pButtonItem);
-	}
+  QString qsAction;
+  QStringList actionList;
+  if (!m_qsAction.isEmpty())	{	// For new buttons this might be empty ...
+    actionList = QStringList::split (QString (STRING_SEPARATOR), m_qsAction);
+    if (actionList.count() == 1)	
+      qsAction = m_qsAction;
+    else	{
+      qsAction = actionList[0] + QString (" ") +actionList[1] + QString (" ") +actionList[2];
+      if (actionList.count() == 4)
+	qsAction += QString (" ") +actionList[3];
+    }
+  }
+  pButtonItem = new StructureItem(this, pParentItem, m_qsName, qsAction);
+  pButtonItem->setExpandable (TRUE);
+  
+  uint t;
+  for (t=0;t<m_listHighlightedState.count();t++)	{
+    pStateItem = new StructureItem(this, pButtonItem, QString ("Highlighted"), QString (""));
+    pStateItem->setExpandable (TRUE);
+    m_listHighlightedState[t]->createStructure ( pStateItem );
+  }
+  for (t=0;t<m_listSelectedState.count();t++)	{
+    pStateItem = new StructureItem(this, pButtonItem, QString ("Selected"), QString (""));
+    pStateItem->setExpandable (TRUE);
+    m_listSelectedState[t]->createStructure ( pStateItem );
+  }
+  for (t=0;t<m_listNormalState.count();t++)	{
+    m_listNormalState[t]->createStructure ( pButtonItem );
+  }
 }
 
 void ButtonObject::replaceColor (QColor theColor, QColor oldColor)
@@ -568,6 +627,16 @@ QString &ButtonObject::action()
 	return m_qsAction;
 }
 
+void ButtonObject::setPreAction(QString &qsPreAction)
+{
+  m_qsPreAction = qsPreAction;
+}
+
+QString &ButtonObject::preAction()
+{
+  return m_qsPreAction;
+}
+
 void ButtonObject::setSourceFileEntry(SourceFileEntry *pEntry)
 {
 	m_pSourceFileEntry = pEntry;
@@ -642,7 +711,7 @@ int ButtonObject::chapter ( bool bAllEntries )
       if ( pEntry->listFileInfos[t] == pInfo )
 	break; // break out of the loop
       iTemp = pEntry->listFileInfos[t]->listChapters.count();
-      iTemp = (iTemp < 1) ? 1: iTemp;
+      //iTemp = (iTemp < 1) ? 1: iTemp; // removed 20060920. No chapter, no -pit-stop-, no count increase.
       iChapterNumber += iTemp;
     }
   }
@@ -653,7 +722,9 @@ int ButtonObject::chapter ( bool bAllEntries )
 	iChapterNumber += t;
     }
   }
-  
+  else // In order to reach this VOB it needs to have at least one chapter to get to. Remember pInfo is associated with this button.
+    pInfo->listChapters.append ( "00:00:00.000" ); 
+
   return iChapterNumber;  // Info present but no chapter info...
 }
 
@@ -694,22 +765,74 @@ QString &ButtonObject::next(uint iNext)
 	return m_qsUp;
 }
 
-void ButtonObject::slotEdit()
+void ButtonObject::slotEdit ( )
 {
-	mouseDoubleClickEvent(NULL);
+	mouseDoubleClickEvent ( NULL );
 }
 
-void ButtonObject::slotUnbutton()
+void ButtonObject::slotEditObject ( )
 {
-	// Here we are going to split the Button object into its three distinkt 
-	// objects and add them to the Preview (MenuPreview that is).
-	emit (signalUnbuttonMe(this));
-	// The work is done in MenuPreview::slotUnbutton()
+  MenuObject *pMenuObject = m_listNormalState[0];
+  if ( pMenuObject ) {
+       pMenuObject->mouseDoubleClickEvent ( NULL );
+    // Here we handle a special case if the Text / Font of a TextObject has changed
+    if ( pMenuObject->objectType ( ) == QString ( TEXT_OBJECT ) ) {
+      uint t;
+      TextObject *pTextObject = (TextObject *)pMenuObject;
+      QPoint  align   = pTextObject->getTextAlign ( );
+      QString theText = pTextObject->getText ( );
+      QFont   theFont = pTextObject->getFont ( );
+      for ( t=0; t<m_listSelectedState.count ( ); t++ ) {
+	pMenuObject = m_listSelectedState[t];
+	if ( pMenuObject && ( pMenuObject->objectType ( ) == QString ( TEXT_OBJECT ) ) ) {
+	  pTextObject = (TextObject *)pMenuObject;
+	  pTextObject->setText (  theText  );
+	  pTextObject->setFont (  theFont  );
+	  pTextObject->setTextAlign( align );
+	}
+      }
+      for ( t=0; t<m_listHighlightedState.count ( ); t++ ) {
+	pMenuObject = m_listHighlightedState[t];
+	if ( pMenuObject && ( pMenuObject->objectType ( ) == QString ( TEXT_OBJECT ) ) ) {
+	  pTextObject = (TextObject *)pMenuObject;
+	  pTextObject->setText (  theText  );
+	  pTextObject->setFont (  theFont  );
+	  pTextObject->setTextAlign( align );
+	}
+      }
+    }
+  }
+}
+
+void ButtonObject::slotObjectProperties ( )
+{
+  if ( m_listNormalState[0] ) {
+    MenuObject *pObject = m_listNormalState[0];
+    if ( ( pObject->objectType ( ) == QString ( IMAGE_OBJECT ) ) || 
+	 ( pObject->objectType ( ) == QString ( MOVIE_OBJECT ) ) ) {
+      ImageObject *pImage = (ImageObject *)pObject;
+      pImage->slotProperties ( );
+    }
+  }
+}
+
+void ButtonObject::slotUnbutton ( )
+{
+  // get a slight delay to allow the ContextMenu to be destroyed ...
+  QTimer::singleShot ( 10, this, SLOT ( slotEmitUnbuttonMe ( ) ) );
+}
+
+void ButtonObject::slotEmitUnbuttonMe ( )
+{
+  // Here we are going to split the Button object into its three distinkt 
+  // objects and add them to the Preview (MenuPreview that is).
+  emit ( signalUnbuttonMe ( this ) );
+  // The work is done in MenuPreview::slotUnbutton()
 }
 
 void ButtonObject::slotMoveable()
 {
-	// if iot is not moveable the the Button is locked in.
+	// if it is not moveable the Button is locked in.
 	m_bMoveable = !m_bMoveable;
 }
 
@@ -723,6 +846,26 @@ void ButtonObject::slotAddImage()
 
 }
 
+void ButtonObject::setRect ( QRect &theRect )
+{
+  uint t;
+  for ( t=0; t<m_listHighlightedState.count ( ); t++ )
+    m_listHighlightedState[t]->setRect ( theRect );
+  for ( t=0; t<m_listSelectedState.count ( ); t++ )
+    m_listSelectedState[t]->setRect ( theRect );
+  for ( t=0; t<m_listNormalState.count ( ); t++ )
+    m_listNormalState[t]->setRect ( theRect );
+  MenuObject::setRect ( theRect );
+}
+
+QRect &ButtonObject::rect ( )
+{
+  if ( m_listHighlightedState.count ( ) > 0 )
+    return m_listHighlightedState[ 0 ]->rect ( );
+
+  return m_rect;
+}
+
 void ButtonObject::slotAddMovie() // movie object for the Menu that is ...
 {
 
