@@ -1,8 +1,10 @@
 /****************************************************************************
 ** ButtonPreview class
 **
-** Created: Tue Feb 02 22:06:51 2004
-**      by: Varol Okan using Kate
+**   Created : Tue Feb 02 22:06:51 2004
+**        by : Varol Okan using Kate
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 ** This class is the encapsulation of the ButtonPreview from the FileSelection
 ** Dialog.
@@ -28,21 +30,63 @@
 #include "dvdmenu.h"
 
 ButtonPreview::ButtonPreview(QWidget * parent, const char * name, WFlags f)
-	: QLabel (parent, name, f)
+  : QLabel (parent, name, f),
+    m_pUndoBuffer   ( NULL ),
+    m_pActiveObject ( NULL )
 {
-	// Here we have the undo buffer ...
-	m_pUndoBuffer = new UndoBuffer(MAX_UNDO_DEPTH);
-
-	m_iCursorStyle = MousePointerCursor;
-	m_pActiveObject = NULL;
-	m_bMouseEventDone = false;
-	m_bDrawVisibleRegion = false;	// This is set in the derived calss MenuPreview - only ... (No need for the buttonPreview class to play with)
+  // Here we have the undo buffer ...
+  m_pUndoBuffer = new UndoBuffer(MAX_UNDO_DEPTH);
+  
+  m_iCursorStyle = MousePointerCursor;
+  m_pActiveObject = NULL;
+  m_bMouseEventDone = false;
+  m_bDrawVisibleRegion = false;	// This is set in the derived calss MenuPreview - only ... (No need for the buttonPreview class to play with)
 }
 
 ButtonPreview::~ButtonPreview()
 {
-	if (m_pUndoBuffer)
-		delete m_pUndoBuffer;
+  if ( m_pUndoBuffer )
+    delete m_pUndoBuffer;
+
+ uint t;
+ MenuObject *pObject;
+ for ( t=0; t<m_listMenuObjects.count ( ); t++ )
+   delete m_listMenuObjects.at ( t );
+
+ m_listMenuObjects.clear ( );
+}
+
+ButtonPreview &ButtonPreview::operator= ( ButtonPreview &theOther )
+{
+  // Unclonable parameters ...
+  //    UndoBuffer *m_pUndoBuffer;
+  //  MenuObject *m_pActiveObject;
+  // tells the process to skip further handling of the MouseEvents since they were already taken care of.
+  //  bool        m_bMouseEventDone;
+
+  int t;
+  MenuObject *pObject;
+  for ( t=0; t<(int)m_listMenuObjects.count ( ); t++ )
+    delete m_listMenuObjects.at ( t );
+  m_listMenuObjects.clear ( );
+
+  for ( t=0; t<(int)theOther.m_listMenuObjects.count ( ); t++ ) {
+    pObject = theOther.m_listMenuObjects.at ( t );
+    if ( ! pObject )
+      continue;
+    pObject = pObject->clone ( this );
+    // At this point we cloned a child for theOther - parent, so we need to 
+    // re-parent the clone to the new owner 
+    //    pObject->reParent ( this );
+    addMenuObject ( pObject );
+  }
+
+  m_rectViewport       = theOther.m_rectViewport;     // This is the viewport set in drawContents()
+  m_backgroundPixmap   = theOther.m_backgroundPixmap;
+  m_bDrawVisibleRegion = theOther.m_bDrawVisibleRegion;
+  m_iCursorStyle       = theOther.m_iCursorStyle;
+
+  return *this;
 }
 
 bool ButtonPreview::removeObject(MenuObject *pTheObject)
@@ -54,16 +98,29 @@ bool ButtonPreview::removeObject(MenuObject *pTheObject)
 
 void ButtonPreview::slotDeleteObject(MenuObject *pTheObject)
 {
-	m_listMenuObjects.remove(pTheObject);
-	delete pTheObject;
-	update ();
+  // object not found. Maybe it is in a ButtonObject ...
+  if ( m_listMenuObjects.remove ( pTheObject ) == false )
+    return;
+
+  if ( m_pActiveObject == pTheObject )
+    m_pActiveObject = NULL;
+  delete pTheObject;
+  update ( );
 }
 
 void ButtonPreview::addMenuObject(MenuObject *pNewObject)
 {
 	// Adds the menuObject to the list of MenuObjects.
-	m_listMenuObjects.append(pNewObject);
-	update ();
+  m_listMenuObjects.append ( pNewObject );
+  update ( );
+}
+
+uint ButtonPreview::clearObjectList  ( )
+{
+  uint iListSize = m_listMenuObjects.count ( );
+  // Only clear, do not delete the objects.
+  m_listMenuObjects.clear ( );
+  return iListSize;
 }
 
 void ButtonPreview::setViewport(QRect &rectViewport)
@@ -156,6 +213,11 @@ void ButtonPreview::setMouseCursor ( enPointerShape iPointerShape )
   m_iCursorStyle = iPointerShape;
 }
 
+void ButtonPreview::slotAnimateObject ( QString &qsTempAnim, int iType, QString qsFontName )
+{
+  emit ( signalAnimateObject ( qsTempAnim, iType, qsFontName ) );
+}
+
 void ButtonPreview::slotMoveOnStack(MenuObject *pObject, int iHowMany)
 {
 	// This function pushes the currently selected child on the stack by iHowMany steps
@@ -175,14 +237,14 @@ void ButtonPreview::slotMoveOnStack(MenuObject *pObject, int iHowMany)
 	updatePixmap ();
 }
 
-void ButtonPreview::mousePressEvent (QMouseEvent *pEvent)
+void ButtonPreview::mousePressEvent ( QMouseEvent *pEvent )
 {
   // Here we check if the mouse click appeared withtin one of the MenuObjects,
   // in which case the Object will take over the mouse handling ...
-  QPoint thePos  = pEvent->pos();
-  MenuObject *pObject = childContains(thePos);
+  QPoint thePos  = pEvent->pos ( );
+  MenuObject *pObject = childContains ( thePos );
   if (pObject != NULL)	{
-    MenuObject::enState currentState = pObject->setObjectState ( thePos );
+    MenuObject::enState currentState = pObject->setObjectState ( thePos, pEvent->state ( ) );
     setObjectCursor ( currentState );
     m_bMouseEventDone = pObject->mousePressEvent ( pEvent );
     // Here we protect the action toTop for creation of Buttons, which delete the returned pObject
@@ -368,26 +430,26 @@ void ButtonPreview::fitDVDMenuBackground (QPixmap *pPixmap, int iResizeAlgorithm
 
 void ButtonPreview::drawContents(QPainter *painter)
 {
-	QLabel::drawContents (painter);
-	// We use the viewport to draw the Object in the Center for the ButtonDialog.
-	// The Viewport is not used in the MenuPreview for the main window, thus drawing the button
-	// on the right location ...
-	if (m_rectViewport.width() > 10)
-		painter->setViewport(m_rectViewport);
-	// In case the user has not yet defined a background Image, we want to show the Objects anyways ...
-	// Note: we draw usually all objects into the pixmap, which we have set as a background see updatePixmap()
-	if (m_backgroundPixmap.isNull())	{
-		uint t;
-		erase(5, 5, width()-10, height()-10);
-		drawVisibleRegion(painter);
-		for (t=0;t<m_listMenuObjects.count();t++)	{
-			m_listMenuObjects.at(t)->drawContents (painter);
-		}
-		return;
-	}
-	// This will draw the currentObject on top of the 'copy' we already painted into the pixmap. 
-	if (m_pActiveObject)
-		m_pActiveObject->drawContents(painter);
+  QLabel::drawContents ( painter );
+  // We use the viewport to draw the Object in the Center for the ButtonDialog.
+  // The Viewport is not used in the MenuPreview for the main window, thus drawing the button
+  // on the right location ...
+  if ( m_rectViewport.width ( ) > 10 )
+       painter->setViewport ( m_rectViewport );
+  // In case the user has not yet defined a background Image, we want to show the Objects anyways ...
+  // Note: we draw usually all objects into the pixmap, which we have set as a background see updatePixmap()
+  if ( m_backgroundPixmap.isNull ( ) )  {
+    uint t;
+    erase ( 5, 5, width ( ) - 10, height ( ) - 10 );
+    drawVisibleRegion ( painter );
+    for ( t=0; t<m_listMenuObjects.count ( ); t++ )  {
+      m_listMenuObjects.at(t)->drawContents (painter);
+    }
+    return;
+  }
+  // This will draw the currentObject on top of the 'copy' we already painted into the pixmap. 
+  if ( m_pActiveObject )
+       m_pActiveObject->drawContents(painter);
 }
 
 void ButtonPreview::drawVisibleRegion(QPainter *pPainter)
@@ -442,7 +504,6 @@ void ButtonPreview::updatePixmap()
 
 void ButtonPreview::setBackground ( QPixmap &thePixmap )
 {
-  // This change might affect some areas I am not currently considering. (2004 Oct 20)
   if ( parentWidget ( )->parentWidget ( )->name ( ) == QString ( "usingScrollView" ) )
     setPaletteBackgroundPixmap ( thePixmap );
   else
