@@ -1,8 +1,10 @@
 /****************************************************************************
 ** Interface to the GUI.
 **
-** Created: Sun Dec 14 12:09:08 2003
-**      by: Varol Okan using kate editor
+**   Created : Sun Dec 14 12:09:08 2003
+**        by : Varol Okan using kate editor
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 ** This class generates the command line for dvdauthor.
 ** Current Version of DVDAUTHOR used is 0.67
@@ -41,6 +43,7 @@ public:
    ButtonPreview (QWidget * parent, const char * name = 0, WFlags f = 0 );
   ~ButtonPreview ();
 
+  ButtonPreview & operator =    ( ButtonPreview & );
   void         toTop            ( MenuObject * );
   void         setViewport      ( QRect & );
   UndoBuffer  *undoBuffer       ( );
@@ -50,6 +53,7 @@ public:
   void         updatePixmap     ( );
   bool         removeObject     ( MenuObject * );
   void         addMenuObject    ( MenuObject * );
+  uint         clearObjectList  ( );
   QPixmap     &renderMenu       ( CDVDMenuInterface *, long, long );
   void fitDVDMenuBackground     ( QPixmap  *, int, int, QSize, int, int );
   void         setMouseCursor   ( enPointerShape );
@@ -61,9 +65,11 @@ public slots:
   virtual void slotDeleteObject ( MenuObject * );
   virtual void setPixmap        ( const QPixmap & );
   virtual void slotMoveOnStack  ( MenuObject *, int );
+  virtual void slotAnimateObject( QString &, int, QString );
 	
 signals:
   void signalRenderProgress     ( float );
+  void signalAnimateObject      ( QString &, int, QString );
 
 protected:
   virtual void mousePressEvent	     ( QMouseEvent * );
