@@ -30,11 +30,11 @@ DialogAnimation::~DialogAnimation ()
 void DialogAnimation::initMe ( QString qsAnimation, long iFrames, float fFPS, int iType )
 {
 	char *standardProperties[] = {"rect", "visibleFromTo", "transparency", "rotate", "zoom", "scale", "shear"}; // index 0-14
-	char *frameProperties [] = {"color", "frameWidth", "frameStyle", "frameJoin"}; // index 15-26
-	//	char *imageProperties [] = {"backgroundFileName", "showBackground", "startPos", "res", "aspectRatio", "blendColor", "brightness" }; // index 15-26
-	char *imageProperties [] = {"backgroundFileName", "showBackground", "startPos", "pos", "blendColor", "brightness" }; // index 15-24
-	char *movieProperties [] = {"frameNo"}; // index 26
-	char *textProperties  [] = {"text", "font", "textAlign", "foregroundColor", "backgroundColor"}; // index 15-27
+	char *frameProperties   [] = {"color", "frameWidth", "frameStyle", "frameJoin"}; // index 15-26
+	//char *imageProperties [] = {"fileName", "backgroundFileName", "showBackground", "kenBurns", "pos", "blendColor", "brightness" }; // index 15-24
+	char *imageProperties   [] = {"fileName", "kenBurns", "pos", "blendColor", "brightness" }; // index 15-24
+	char *movieProperties   [] = {"frameNo"}; // index 26
+	char *textProperties    [] = {"text", "font", "textAlign", "foregroundColor", "backgroundColor"}; // index 15-27
 	// Note we have to synch those entries when we make the changes. I.e. 
 	// standard properties.rect has 6 variables, index 0-5 (x1, y1, x2, y2, width, height)
 	// standard properties.rotate has 1 variable, index 6 etc.
@@ -81,8 +81,8 @@ void DialogAnimation::initMe ( QString qsAnimation, long iFrames, float fFPS, in
 	m_pComboAttributes->clear ();
 	m_pComboAttributes->insertStringList ( listAttributes );
 	m_pSliderPosition->setMaxValue  ( iFrames );
-	m_pSliderPosition->setLineStep ( (int)(iFrames/15.0) );
-	m_pSliderPosition->setPageStep ( (int)(iFrames/5.0 ) );
+	m_pSliderPosition->setLineStep  ( (int)(iFrames/15.0) );
+	m_pSliderPosition->setPageStep  ( (int)(iFrames/5.0 ) );
 	m_pSpinBoxPosition->setMaxValue ( iFrames );
 
 	connect (m_pButtonAdd,       SIGNAL (clicked ()), this, SLOT(slotAddAttribute ()));
@@ -134,34 +134,36 @@ void DialogAnimation::slotValueChanged ( int iNewValue )
 
 void DialogAnimation::slotAddAttribute ()
 {
-	// This function adds the set Attribute at the curren cursor position in the text edit
+  // This function adds the set Attribute at the curren cursor position in the text edit
 	
-	// The following attributes should show up as N::property.attribute=
-	char *arrayProperties[] = {"visibleFromTo", "color", "startPos", "res", "blendColor", "foregroundColor", "backgroundColor", "rect", "scale", "shear"};
+  // The following attributes should show up as N::property.attribute=
+  char *arrayProperties[] = {"visibleFromTo", "color", "kenBurns", "startPos", "res", "blendColor", "foregroundColor", "backgroundColor", "rect", "scale", "shear", "pos" };
 
-	uint t;
-	bool bFound = false;
-	QString qsNewText;
-	qsNewText=QString ("%1::%2").arg (m_pSpinBoxPosition->text ()).arg (m_pComboAttributes->currentText());
+  uint t;
+  bool bFound = false;
+  QString qsNewText;
+  qsNewText=QString ("%1::%2").arg (m_pSpinBoxPosition->text ()).arg (m_pComboAttributes->currentText());
 
-	for (t=0; t < sizeof (arrayProperties) / sizeof (arrayProperties[0]); t++)	{
-		if (m_pComboAttributes->currentText () == arrayProperties[t])	{
-			bFound = true;
-			break;
-		}
-	}
+  for (t=0; t < sizeof (arrayProperties)  / sizeof (arrayProperties[0] ); t++ )	{
+    if ( m_pComboAttributes->currentText ( ) == arrayProperties[t] )	{
+      bFound = true;
+      break;
+    }
+  }
 
-	if (bFound)	{
-		if (m_pComboAttributeSub->count () > 0)
-			qsNewText += QString (".%1=").arg(m_pComboAttributeSub->currentText());
-		else
-			qsNewText += QString ("=");
-	}
-	else	{
-		qsNewText += QString ("=%1").arg(m_pComboAttributeSub->currentText ());
-	}
-
-	m_pEditScript->insert (qsNewText);
+  if (bFound)	{
+    if ( m_pComboAttributeSub->count ( ) > 0 ) {
+      qsNewText += QString (".%1=").arg ( m_pComboAttributeSub->currentText ( ) );
+      if ( m_pComboAttributes->currentText ( ) == "visibleFromTo" ) // slightly different handling/meaning for this prop.
+	qsNewText += m_pSpinBoxPosition->text ( );
+    }
+    else
+      qsNewText += QString ( "=" );
+  }
+  else 
+    qsNewText += QString ( "=%1" ).arg ( m_pComboAttributeSub->currentText ( ) );
+  
+  m_pEditScript->insert ( qsNewText );
 }
 
 void DialogAnimation::slotAttribute (const QString &newText)
@@ -173,6 +175,12 @@ void DialogAnimation::slotAttribute (const QString &newText)
 		m_pComboAttributeSub->insertItem ( "green" );
 		m_pComboAttributeSub->insertItem ( "blue" );
 	}
+	else if ( newText == "kenBurns" )	{
+		m_pComboAttributeSub->insertItem ( "x1" );
+		m_pComboAttributeSub->insertItem ( "y1" );
+		m_pComboAttributeSub->insertItem ( "x2" );
+		m_pComboAttributeSub->insertItem ( "y2" );
+	}
 	else if ( newText == "rect" )	{
 		m_pComboAttributeSub->insertItem ( "x1" );
 		m_pComboAttributeSub->insertItem ( "y1" );
@@ -185,7 +193,7 @@ void DialogAnimation::slotAttribute (const QString &newText)
 		m_pComboAttributeSub->insertItem ( "startFrame" );
 		m_pComboAttributeSub->insertItem ( "stopFrame" );
 	}
-	else if ( ( newText == "startPos" ) || ( newText == "pos" )|| ( newText == "res" ) || ( newText == "scale" ) || ( newText == "shear" ) )	{
+	else if ( ( newText == "pos" )|| ( newText == "res" ) || ( newText == "scale" ) || ( newText == "shear" ) )   {
 		m_pComboAttributeSub->insertItem ( "x" );
 		m_pComboAttributeSub->insertItem ( "y" );
 	}
