@@ -1,8 +1,10 @@
 /****************************************************************************
 ** DialogCommandEditor class
 **
-** Created: Mon Jun 07 22:48:00 2004
-**      by: Varol Okan using Kate
+**   Created : Mon Jun 07 22:48:00 2004
+**        by : Varol Okan using Kate
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 **
 ****************************************************************************/
@@ -13,6 +15,8 @@
 #include <qlabel.h>
 #include <qtextedit.h>
 #include <qcombobox.h>
+#include <qtabwidget.h>
+#include <qpushbutton.h>
 
 #include "dialogcommandeditor.h"
 
@@ -29,14 +33,16 @@ DialogCommandEditor::~DialogCommandEditor ()
 	// so we won't have to do it manually here
 }
 
-void DialogCommandEditor::initMe (QDVDAuthorInit::MenuBlock::Block *pBlock, uint iCurrentTab, QStringList listVars)
+void DialogCommandEditor::initMe (QDVDAuthorInit::MenuBlock::Block *pBlock, uint iCurrentTab, QStringList listVars, uint iMaxVars )
 {
-	uint t;
-	initMe (pBlock, iCurrentTab);
-	m_pComboVar->clear ();
-	for (t=0;t<listVars.count ();t++)	{
-		m_pComboVar->insertItem (listVars[t].replace ("+", ""));
-	}
+  uint t, iCount;
+  initMe (pBlock, iCurrentTab);
+  m_pComboVar->clear ();
+
+  iCount = ( iMaxVars > 0 ) ? iMaxVars : listVars.count ();
+
+  for (t=0;t<iCount;t++) 
+    m_pComboVar->insertItem (listVars[t].replace ("+", ""));
 }
 
 void DialogCommandEditor::initMe (QDVDAuthorInit::MenuBlock::Block *pBlock, uint iCurrentTab)
