@@ -1,18 +1,26 @@
 /****************************************************************************
 ** DialogCreateTemplate class
 **
-** Created: Mon Jun 10 22:48:00 2005
-**      by: Varol Okan using XEmacs
+**   Created : Mon Jun 10 22:48:00 2005
+**        by : Varol Okan using XEmacs
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 **
 ****************************************************************************/
+#include <stdlib.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#ifdef QDVD_LINUX 
+#include <unistd.h>
+#endif
 
 #include <qnetworkprotocol.h>
 #include <qradiobutton.h>
 #include <qprogressbar.h>
 #include <qmessagebox.h>
+#include <qpushbutton.h>
+#include <qtabwidget.h>
 #include <qtextedit.h>
 #include <qcombobox.h>
 #include <qfileinfo.h>
@@ -21,13 +29,16 @@
 #include <qprocess.h>
 #include <qspinbox.h>
 #include <qpainter.h>
+#include <qlayout.h>
 #include <qcursor.h>
 #include <qslider.h>
 #include <qregexp.h>
 #include <qframe.h>
+#include <qimage.h>
 #include <qdir.h>
 #include <qftp.h>
 
+#include "win32.h"
 #include "CONFIG.h"
 #include "global.h"
 #include "utils.h"
@@ -36,9 +47,11 @@
 #include "messagebox.h"
 #include "menuobject.h"
 #include "textobject.h"
+#include "qdvdauthor.h"
 #include "menupreview.h"
 #include "buttonobject.h"
 #include "qdvdauthorinit.h"
+#include "sourcefileentry.h"
 #include "objectcollection.h"
 #include "dialogcreatetemplate.h"
 
@@ -205,8 +218,8 @@ void CreateTemplatePreview::ensureUniqueDropZoneName ()
   for (t=0;t<(int)m_listOfDropZones.count( );t++) {
     qsName = m_listOfDropZones[t]->name( );
     while ( ! isUniqueName ( t, qsName ) ) {
-      c1 = qsName[ qsName.length ( ) - 1 ];
-      c2 = qsName[ qsName.length ( ) - 2 ];
+      c1 = qsName.at ( qsName.length ( ) - 1 );
+      c2 = qsName.at ( qsName.length ( ) - 2 );
       if ( ( c1.digitValue ( ) == -1 ) || ( c2.digitValue ( ) == -1 ) ) {
 	qsName += "00"; // try this if the last two chars are no digits
 	m_listOfDropZones[t]->setName ( qsName );
@@ -470,8 +483,8 @@ void DialogCreateTemplate::slotInstall ( )
   QFile theFile;
   QDir theDir ( qsInstallDir );
   if ( ! theDir.exists ( ) )
-    qsCommand += QString ( "mkdir -p %1;\n" ).arg ( qsInstallDir );
-  qsCommand += QString ( "cd %1; tar -xzf %2/%3.tar.gz\n" ).arg ( qsPrefixDir ).arg ( Global::qsTempPath ).arg ( m_pEditFileName->text ( ) );
+    qsCommand += QString ( "mkdir -p \"%1\";\n" ).arg ( qsInstallDir );
+  qsCommand += QString ( "cd \"%1\"; tar -xzf \"%2/%3.tar.gz\"\n" ).arg ( qsPrefixDir ).arg ( Global::qsTempPath ).arg ( m_pEditFileName->text ( ) );
   // Last we use the same routine to install as in TemplateDownload ...
   
   qsExecutable = QString ( "%1/execute.sh" ).arg ( Global::qsTempPath );
@@ -481,7 +494,7 @@ void DialogCreateTemplate::slotInstall ( )
     stream << qsCommand;
     theFile.close ( );
   }
-  chmod ((const char *)QString( qsExecutable ), S_IEXEC | S_IRUSR | S_IWRITE);
+  chmod ((const char *)QString( qsExecutable ), S_IEXEC | S_IRUSR | S_IWRITE | S_IROTH | S_IXOTH | S_IWOTH );
   
   installToSystem ( qsExecutable, m_pRadioLocally->isChecked ( ) );
 
@@ -492,14 +505,16 @@ void DialogCreateTemplate::slotInstall ( )
 #define draw cd
 QString DialogCreateTemplate::findGuiSU ( )
 {
+  int iRet = 0;
   uint t;
   QString qsReturn;
+  QString qsTmpOut = QString ( "%1/%2_out.txt" ).arg ( Global::qsTempPath ).arg ( getlogin ( ) );
   char *arraySUs[3] = {"kdesu", "xsu", "gnomesu"};
-  QFileInfo fileInfo("/tmp/out.txt");
+  QFileInfo fileInfo( qsTmpOut );
   for (t=0;t<3;t++)	{
     // the next check is to see if we can find kdesu
-    system ((const char *)QString ("which %1 > %2/out.txt 2>/dev/null").arg( arraySUs[t] ).arg ( Global::qsTempPath ) );
-    fileInfo.setFile("/tmp/out.txt");
+    iRet = system ((const char *)QString ("which %1 > %2 2>/dev/null").arg( arraySUs[t] ).arg ( qsTmpOut ) );
+    fileInfo.setFile( qsTmpOut );
     // Okay we cna not find it, so we wont bother asking the user ...
     if (fileInfo.size() > 4)	{
       qsReturn = QString ("%1").arg( arraySUs[t] );
@@ -597,22 +612,17 @@ QString DialogCreateTemplate::createTemplate ( )
   // 1) create the directory under Global::qsTempPath
   // 2) create the template in this directory
   // 3) tar, gz the result
+  Utils theUtils;
   QString qsCommand, qsTemplatePath;
   QDir theDir;
+  int iRet = 0;
 
   qsTemplatePath = QString ( "%1/%2%3").arg ( Global::qsTempPath ).arg ( getTypePath ( ) ).arg ( m_pEditFileName->text ( ) );
-  qsCommand = QString ( "mkdir -p \"%1/background\"" ).arg ( qsTemplatePath );
-  system ( qsCommand.ascii () );
-
-  theDir = QDir ( qsTemplatePath );
-  if ( ! theDir.exists () ) {
-    MessageBox::warning ( this, tr ( "Failed to create temp directory" ), 
-			  tr( "Failed to create Temp directory\n\n%1\n\nPlease make sure you have read/write permission to %2." )
-			  .arg ( qsTemplatePath ).arg ( Global::qsTempPath ) );
+  if ( ! theUtils.recMkdir ( qsTemplatePath + "/background" ) )  {
     QString qsTemp;
     return qsTemp;
   }
-  
+
   m_pFrameProperties->ensureUniqueDropZoneName ( );
   if ( ! createTemplateXml ( qsTemplatePath ) )
     return qsTemplatePath;
@@ -625,7 +635,7 @@ QString DialogCreateTemplate::createTemplate ( )
 
   qsTemplatePath = QString ( "%2%3").arg ( getTypePath ( ) ).arg ( m_pEditFileName->text ( ) );
   qsCommand = QString ( "cd %1; tar -czf %2.tar.gz %3" ).arg( Global::qsTempPath ).arg( m_pEditFileName->text () ).arg( qsTemplatePath );
-  system ( qsCommand.ascii ( ) );
+  iRet = system ( qsCommand.ascii ( ) );
 
   // These two functions are for convenience ... 
   // And need to get executed AFTER the creation of the Template package file
@@ -636,7 +646,7 @@ QString DialogCreateTemplate::createTemplate ( )
     arg ( Global::qsTempPath ).
     arg ( qsTemplatePath ).arg( m_pEditFileName->text ( ) ).arg ( m_pEditFileName->text ( ) ).
     arg ( m_pEditFileName->text ( ) );
-  system ( qsCommand.ascii ( ) );
+  iRet = system ( qsCommand.ascii ( ) );
 
   qsTemplatePath = QString ( "%1/%2.tar.gz" ).arg ( Global::qsTempPath ).arg ( m_pEditFileName->text ( ) );
 
@@ -646,7 +656,7 @@ QString DialogCreateTemplate::createTemplate ( )
 bool DialogCreateTemplate::createTemplateXml ( QString &qsTemplatePath )
 {
   // This is where the template XML file is created.
-  int                      t, iPos;
+  int                      t;
   QString                  qsXml, qsMenuXml, qsObjectType;
   QRect                    theRect;
   ButtonObject          *  pDropZone;
@@ -658,13 +668,14 @@ bool DialogCreateTemplate::createTemplateXml ( QString &qsTemplatePath )
   qsDescription = qsDescription.replace ( ">", "&gt;" );
   
   qsXml  = "<!DOCTYPE QDVDAuthor>\n";
-  qsXml += "<QDVDTemplate TemplateName=\"" + m_pEditFileName->text () + "\" "TEMPLATE_VERSION"=\"" + QString ( "%1" ).arg (TEMPLATE_VERSION_NUMBER ) + "\" >\n";
-  qsXml += " <"TEMPLATE_VERSION">"         + m_pEditVersion->text () + "</"TEMPLATE_VERSION">\n";
-  qsXml += " <"TEMPLATE_AUTHOR">"          + m_pEditAuthor->text  () + "</"TEMPLATE_AUTHOR">\n";
-  qsXml += " <"TEMPLATE_CONTACT">"         + m_pEditContact->text () + "</"TEMPLATE_CONTACT">\n";
-  qsXml += " <"TEMPLATE_HEADER">"          + m_pEditHeader->text  () + "</"TEMPLATE_HEADER">\n";
-  qsXml += " <"TEMPLATE_DESCRIPTION">"     +     qsDescription       + "</"TEMPLATE_DESCRIPTION">\n";
-  qsXml += " <"TEMPLATE_COMMENT">"         + m_pTextComment->text () + "</"TEMPLATE_COMMENT">\n";
+  qsXml += "<QDVDTemplate TemplateName=\"" + m_pEditFileName->text ( ) + "\" "TEMPLATE_VERSION"=\"" + QString ( "%1" ).arg (TEMPLATE_VERSION_NUMBER ) + "\" >\n";
+  qsXml += " <"TEMPLATE_VERSION">"         + m_pEditVersion->text  ( ) + "</"TEMPLATE_VERSION">\n";
+  qsXml += " <"TEMPLATE_AUTHOR">"          + m_pEditAuthor->text   ( ) + "</"TEMPLATE_AUTHOR">\n";
+  qsXml += " <"TEMPLATE_CONTACT">"         + m_pEditContact->text  ( ) + "</"TEMPLATE_CONTACT">\n";
+  qsXml += " <"TEMPLATE_HEADER">"          + m_pEditHeader->text   ( ) + "</"TEMPLATE_HEADER">\n";
+  qsXml += " <"TEMPLATE_CATEGORY">" +m_pComboCategory->currentText ( ) + "</"TEMPLATE_CATEGORY">\n";
+  qsXml += " <"TEMPLATE_DESCRIPTION">"     +     qsDescription         + "</"TEMPLATE_DESCRIPTION">\n";
+  qsXml += " <"TEMPLATE_COMMENT">"         + m_pTextComment->text  ( ) + "</"TEMPLATE_COMMENT">\n";
 
   for (t=0;t<(int)listOfDropZones.count ();t++) {
     pDropZone = (ButtonObject *) listOfDropZones[t];
@@ -688,7 +699,8 @@ bool DialogCreateTemplate::createTemplateXml ( QString &qsTemplatePath )
   qsXml += " <![CDATA[\n";  
 
   QRegExp      rx, rx1;
-  QString      qsTemp, qsImageObject;
+  QString      qsTemp, qsPattern, qsImageObject;
+  QFileInfo    fileInfo;
   QDomDocument xmlDoc;
   QDomElement  menuElement = xmlDoc.createElement( "RemoveMe" );
 
@@ -710,79 +722,19 @@ bool DialogCreateTemplate::createTemplateXml ( QString &qsTemplatePath )
   qsMenuXml.replace ( rx, "<MenuName>"+m_pEditFileName->text ( )+"</MenuName>" );
   
   // Next we change the background file name
-  rx.setPattern ( "<MenuBackground[^>]*[^/]>.*</MenuBackground>" );
-  if ( rx.search ( qsMenuXml ) > -1 ) {
-    QString qsMenuBackground = rx.cap ( 0 );
-    //    printf ("MenuBackground=<%s>\n", qsMenuBackground.ascii () );
-    rx1.setPattern ( ">[^>]*</MenuBackground>" );
-    qsTemp = QString (">+PREFIX_DIRECTORY+/%1%2/background/background00000.jpg</MenuBackground>" )
-      .arg( getTypePath ( ) ).arg( m_pEditFileName->text ( ) );
-    if ( rx1.search ( qsMenuBackground ) > -1 )
-      qsMenuBackground.replace ( rx1, qsTemp );
-    else
-      qsMenuBackground = QString ("<MenuBackground" ) + qsTemp;
+  handleMenuBackground ( qsMenuXml );
+
+  // In case we have a MovieBackground ...
+  handleMenuMovie      ( qsMenuXml );
+
+  // In case we have a MenuAudio ... (Note: multiple entries are possible)
+  handleMenuAudio      ( qsMenuXml, qsTemplatePath );
 
-    qsMenuXml.replace ( rx, qsMenuBackground );
-  }
-  
-  QString qsButtonXml, qsPattern;
-  rx.setMinimal ( true );
   // Now we handle the drop zones
-  for (t=0;t<(int)listOfDropZones.count ();t++) {
-    pDropZone = (ButtonObject *) listOfDropZones[t];
-    // We get the right line through 
-    qsPattern = QString ( "<ButtonObject[^>]*ButtonName=\"%1\"[^>]*>.*</ButtonObject>" ).arg ( pDropZone->name ( ) );
-    //    printf ( "Pattern=<%s>\n", qsPattern.ascii ( ) );
-    rx.setPattern ( qsPattern );
-    if ( rx.search ( qsMenuXml ) > -1 ) {
-      qsButtonXml = rx.cap ( 0 );
-      qsButtonXml = handleButtonXml ( t, qsButtonXml );
-    }
-    qsMenuXml.replace ( rx, qsButtonXml );
-  }
-  if ( 0 ) {
-    // Not sure yet ...
-    // At this point we should eliminate all other ButtonObjects, not selected by the user.
-    rx.setPattern ( "ButtonObject" );
-    qsMenuXml.replace ( rx, "IgnoreObject" );
-  }
+  handleMenuDropZones  ( qsMenuXml );
 
   // Last we handle Images ...
-  // Note if there are any imageObjects (outside ButtonObjects), then we need to 
-  // copy the image into the Template folder and 'bend' the image pathe accordingly ...
-  rx.setPattern ( "<ImageObject[^>]*>[^>]*>" );
-  iPos = 0;
-  QStringList listOrig, listNew, listTemp;
-  QString qsFileName, qsCommand;
-  QFileInfo fileInfo;
-  while ( iPos >= 0 ) {
-    iPos = rx.search ( qsMenuXml, iPos );
-    if ( iPos > -1 ) {
-      qsImageObject = rx.cap ( 0 );  // get the full ImageObject - Tag 
-      listOrig.append ( qsImageObject );
-
-      rx1.setPattern ( "FileName=\"[^\"]*\"" );
-      if ( rx1.search ( qsImageObject ) > -1 ) {
-	QString qsOrigFileName = rx1.cap ( 0 );
-	listTemp = QStringList::split ( "\"", rx1.cap ( 0 ) );
-	fileInfo.setFile ( listTemp [ 1] );
-	qsFileName = fileInfo.fileName ( );
-	// Next we should copy the file over ...
-	qsCommand = QString ( "cp \"%1\" \"%2\"" ).arg ( listTemp[1] ).arg ( qsTemplatePath );
-	system ( qsCommand.ascii ( ) );
-      }
-      else // Not found .. Oooops ...
-	qsFileName = QString ( "dummy.png" );
-      
-      qsTemp = QString ( "FileName=\"+PREFIX_DIRECTORY+/%1%2/%3\"" ).arg ( getTypePath ( ) ).arg ( m_pEditFileName->text ( ) ).arg ( qsFileName );
-      qsImageObject.replace ( rx1, qsTemp );
-      listNew.append  ( qsImageObject );
-      iPos += rx.matchedLength ( );
-    }
-  }
-  // Finally we exchange the two strings
-  for ( t=0;t<(int)listOrig.count ();t++ )
-    qsMenuXml.replace ( listOrig[t], listNew[t] );
+  handleMenuImages     ( qsMenuXml, qsTemplatePath );
 
   qsXml += qsMenuXml;
 
@@ -804,6 +756,189 @@ bool DialogCreateTemplate::createTemplateXml ( QString &qsTemplatePath )
   return true;
 }
 
+void DialogCreateTemplate::handleMenuAudio ( QString &qsMenuXml, QString &qsTemplatePath )
+{
+  // Note the Sound is stored in the MENU by the SourceFIleENtry and not by file name
+  // Thus we have to get the associated SourceFileEntry from QDVDAuthor and extract all 
+  // sound files.
+  // Ps A menu can have multiple MenuSound - tags
+  int              iPos, iRet, t;
+  QRegExp          rx;
+  QFileInfo        fileInfo;
+  QString          qsSoundEntry, qsCommand, qsFileName, qsSoundEntries;
+  QString          qsTemplateFileName;
+  QStringList      listSoundFiles;
+  QDVDAuthor      *pDVDAuthor = NULL;
+  SourceFileEntry *pSoundEntry;
+
+  rx.setPattern ( "<MenuSound>.*</MenuSound>" );
+  if ( m_pDVDMenu && m_pDVDMenu->getDVDAuthor ( ) ) {
+    pDVDAuthor = Global::pApp; //m_pDVDMenu->getDVDAuthor ( );
+
+    rx.setMinimal ( true );
+    iPos = 0;
+    while ( iPos >= 0 ) {
+      iPos = rx.search ( qsMenuXml, iPos );
+      if ( iPos > -1 ) {
+	qsSoundEntry = rx.cap ( 0 );  // get the full ImageObject - Tag 
+	qsSoundEntry = qsSoundEntry.remove  (  "<MenuSound>" );
+	qsSoundEntry = qsSoundEntry.remove  ( "</MenuSound>" );
+	qsSoundEntry = qsSoundEntry.replace ( "&lt;", "<" );
+	qsSoundEntry = qsSoundEntry.replace ( "&gt;", ">" );
+	pSoundEntry = pDVDAuthor->getSourceEntryByDisplayName ( qsSoundEntry );
+	if ( pSoundEntry && pSoundEntry->bSoundSource ) {
+	  // At this point we have a Sound - SourceFileEntry
+	  for ( t=0;t < (int)pSoundEntry->listFileInfos.count ( ); t++ )
+	    listSoundFiles.append ( pSoundEntry->listFileInfos[t]->qsFileName );
+	}
+	iPos += rx.matchedLength ( );
+      }
+    }
+    
+    // The second step is to copy the files over and create the XML ...
+    for ( t=0;t<(int)listSoundFiles.count ( ); t++ ) {
+// printf ( "%s::%s::%d - [%d] = <%s>\n", __FILE__, __FUNCTION__, __LINE__, t, listSoundFiles [t].ascii ( ) );
+      fileInfo.setFile ( listSoundFiles[t] );
+      if ( fileInfo.exists ( ) ) {
+	qsFileName = fileInfo.fileName ( );
+	qsTemplateFileName = QString ( "+PREFIX_DIRECTORY+/%1%2/%3" ).arg ( getTypePath ( ) ).arg ( m_pEditFileName->text ( ) ).arg ( qsFileName );
+	qsCommand = QString ( "cp \"%1\" \"%2/%3\"" ).arg ( listSoundFiles[t] ).arg ( qsTemplatePath ).arg ( qsFileName );
+	iRet = system ( qsCommand.ascii ( ) );
+	qsSoundEntries += "   <MenuSound>" + qsTemplateFileName + "</MenuSound>\n";
+      }
+    }
+  }
+
+  // The final step is to replace all of the MenuSound entries with the ones in the list.
+  rx.setMinimal ( false );
+  qsMenuXml.replace ( rx, qsSoundEntries );
+}
+
+void DialogCreateTemplate::handleMenuDropZones ( QString &qsMenuXml )
+{
+  int     t;
+  QRegExp rx;
+  QValueList<MenuObject *> listOfDropZones = m_pFrameProperties->getDropZones ( );
+  // Now we handle the drop zones
+  rx.setMinimal ( true );
+  for (t=0;t<(int)listOfDropZones.count ();t++) {
+    ButtonObject *pDropZone;
+    QString       qsButtonXml, qsPattern;
+    pDropZone = (ButtonObject *) listOfDropZones[t];
+    // We get the right line through 
+    qsPattern = QString ( "<ButtonObject[^>]*ButtonName=\"%1\"[^>]*>.*</ButtonObject>" ).arg ( pDropZone->name ( ) );
+    //    printf ( "Pattern=<%s>\n", qsPattern.ascii ( ) );
+    rx.setPattern ( qsPattern );
+    if ( rx.search ( qsMenuXml ) > -1 ) {
+      qsButtonXml = rx.cap ( 0 );
+      qsButtonXml = handleButtonXml ( t, qsButtonXml );
+    }
+    qsMenuXml.replace ( rx, qsButtonXml );
+  }
+  if ( 0 ) {
+    // Not sure yet ...
+    // At this point we should eliminate all other ButtonObjects, not selected by the user.
+    rx.setPattern ( "ButtonObject" );
+    qsMenuXml.replace ( rx, "IgnoreObject" );
+  }
+}
+
+void DialogCreateTemplate::handleMenuBackground ( QString &qsMenuXml ) 
+{
+  QRegExp rx, rx1;
+
+  rx.setPattern ( "<MenuBackground[^>]*[^/]>.*</MenuBackground>" );
+  if ( rx.search ( qsMenuXml ) > -1 ) {
+    QString qsTemp, qsMenuBackground = rx.cap ( 0 );
+    //    printf ("MenuBackground=<%s>\n", qsMenuBackground.ascii () );
+    rx1.setPattern ( ">[^>]*</MenuBackground>" );
+    qsTemp = QString (">+PREFIX_DIRECTORY+/%1%2/background/background00000.jpg</MenuBackground>" )
+      .arg( getTypePath ( ) ).arg( m_pEditFileName->text ( ) );
+    if ( rx1.search ( qsMenuBackground ) > -1 )
+      qsMenuBackground.replace ( rx1, qsTemp );
+    else
+      qsMenuBackground = QString ("<MenuBackground" ) + qsTemp;
+
+    qsMenuXml.replace ( rx, qsMenuBackground );
+  }
+}
+
+void DialogCreateTemplate::handleMenuImages ( QString &qsMenuXml, QString &qsTemplatePath )
+{
+  // Note if there are any imageObjects (outside ButtonObjects), then we need to 
+  // copy the image into the Template folder and 'bend' the image path accordingly ...
+  int         iPos, iRet, t;
+  QRegExp     rx, rx1;
+  QStringList listOrig, listNew, listTemp;
+  QFileInfo   fileInfo;
+  QString     qsFileName, qsCommand, qsImageObject, qsPattern, qsTemp;
+
+  rx.setPattern ( "<ImageObject[^>]*>[^>]*>" );
+  rx.setMinimal ( true );
+  iPos = 0;
+  while ( iPos >= 0 ) {
+    iPos = rx.search ( qsMenuXml, iPos );
+    if ( iPos > -1 ) {
+      qsImageObject = rx.cap ( 0 );  // get the full ImageObject - Tag 
+      listOrig.append ( qsImageObject );
+
+      rx1.setPattern ( "FileName=\"[^\"]*\"" );
+      if ( rx1.search ( qsImageObject ) > -1 ) {
+	QString qsOrigFileName = rx1.cap ( 0 );
+	listTemp = QStringList::split ( "\"", rx1.cap ( 0 ) );
+	fileInfo.setFile ( listTemp [ 1] );
+	qsFileName = fileInfo.fileName ( );
+	// Next we should copy the file over ...
+	qsCommand = QString ( "cp \"%1\" \"%2\"" ).arg ( listTemp[1] ).arg ( qsTemplatePath );
+	iRet = system ( qsCommand.ascii ( ) );
+      }
+      else // Not found .. Oooops ...
+	qsFileName = QString ( "dummy.png" );
+      
+      qsTemp = QString ( "FileName=\"+PREFIX_DIRECTORY+/%1%2/%3\"" ).arg ( getTypePath ( ) ).arg ( m_pEditFileName->text ( ) ).arg ( qsFileName );
+      qsImageObject.replace ( rx1, qsTemp );
+      listNew.append  ( qsImageObject );
+      iPos += rx.matchedLength ( );
+    }
+  }
+  // Finally we exchange the two strings
+  for ( t=0;t<(int)listOrig.count ();t++ )
+    qsMenuXml.replace ( listOrig[t], listNew[t] );
+}
+
+void DialogCreateTemplate::handleMenuMovie ( QString &qsMenuXml )
+{
+  QRegExp rx, rx1;
+  
+  // In case we have a MovieBackground ...
+  rx.setPattern ( "<MenuMovie>.*</MenuMovie>" );
+  if ( rx.search ( qsMenuXml ) > -1 ) {
+    QFileInfo fileInfo;
+    QString   qsMovieFileName, qsTemp;
+    QString   qsMenuMovie = rx.cap ( 0 );
+
+    rx1.setPattern ( ">[^<]*<" );
+    if ( rx1.search ( qsMenuMovie ) > -1 ) {
+      qsMovieFileName = rx1.cap ( 0 );
+      if ( qsMovieFileName.length ( ) > 2 ) {
+	qsMovieFileName =   qsMovieFileName.mid ( 1, qsMovieFileName.length () - 2 );
+	fileInfo.setFile  ( qsMovieFileName );
+	qsMovieFileName = fileInfo.fileName  ( );
+      }
+    }
+    //    printf ("%s::%s::%d - MenuMovie=<%s> fileName<%s>\n", __FILE__, __FUNCTION__, __LINE__, qsMenuMovie.ascii ( ), qsMovieFileName.ascii ( ) );
+    rx1.setPattern ( ">[^>]*</MenuMovie>" );
+    qsTemp = QString (">+PREFIX_DIRECTORY+/%1%2/background/%3</MenuMovie>" )
+      .arg( getTypePath ( ) ).arg( m_pEditFileName->text ( ) ).arg ( qsMovieFileName );
+    if ( rx1.search ( qsMenuMovie ) > -1 )
+      qsMenuMovie.replace ( rx1, qsTemp );
+    else
+      qsMenuMovie = QString ("<MenuMovie" ) + qsTemp;
+
+    qsMenuXml.replace ( rx, qsMenuMovie );
+  }
+}
+
 QString DialogCreateTemplate::handleButtonXml ( int iCount, QString &qsButtonXml )
 {
   QString qsResult, qsKey;
@@ -815,8 +950,8 @@ QString DialogCreateTemplate::handleButtonXml ( int iCount, QString &qsButtonXml
   qsButtonXml.replace ( rx, qsKey );
 
   // Replace the Action - attribute
-  rx.setPattern ( "Action=\"[^\"]*\"" );
-  qsKey = QString ( "Action=\"+DROP_ZONE_%1_ACTION+\"" ).arg ( iCount );
+  rx.setPattern ( " Action=\"[^\"]*\"" );
+  qsKey = QString ( " Action=\"+DROP_ZONE_%1_ACTION+\"" ).arg ( iCount );
   qsButtonXml.replace ( rx, qsKey );
 
   // Replace the SourceEntry - attribute
@@ -826,8 +961,8 @@ QString DialogCreateTemplate::handleButtonXml ( int iCount, QString &qsButtonXml
   if ( qsButtonXml.find ( rx ) > -1 )
     qsButtonXml.replace ( rx, qsKey );
   else { // ButtonObject might not have a SourceEntry (E.g. button to menu)
-    rx.setPattern ( "Action=" );
-    qsKey = QString ( "SourceEntry=\"+DROP_ZONE_SOURCE_ENTRY+\" Action=" );
+    rx.setPattern ( " Action=" );
+    qsKey = QString ( " SourceEntry=\"+DROP_ZONE_SOURCE_ENTRY+\" Action=" );
     qsButtonXml.replace ( rx, qsKey );
   }
 
@@ -878,7 +1013,9 @@ bool DialogCreateTemplate::createBackground ( QString &qsTemplatePath )
   // - background/background00000.jpg
   // - thumbnail.png
   // - preview.png
+  // - and in case of a MovieBackground, copy the Movie over to background/MovieName.ext
   bool                    bFound;
+  int                     iRet = 0;
   uint                    t, i, iWidth, iHeight;
   QPainter                thePainter;
   QPixmap                 theThumbnail, theBackground;
@@ -904,7 +1041,7 @@ bool DialogCreateTemplate::createBackground ( QString &qsTemplatePath )
   qsFileName = qsTemplatePath + "/background/background00000.jpg";
   if ( pInterface && pInterface->backgroundImage.isNull ( ) ) {
     theBackground = QPixmap ( iWidth, iHeight );
-    theBackground.fill ( pInterface->pgcColors[0] );
+    theBackground.fill ( pInterface->pgcColors[0].color ( ) );
   }
   else
     theBackground = QPixmap ( pInterface->backgroundImage );
@@ -916,6 +1053,12 @@ bool DialogCreateTemplate::createBackground ( QString &qsTemplatePath )
     theImage.save   ( qsFileName, "JPEG", 100 );    
   }
 
+  if ( pInterface && ! pInterface->qsMovieFileName.isNull ( ) ) {
+    QString qsCommand;
+    qsCommand = QString ( "cp %1 %2/background/" ).arg ( pInterface->qsMovieFileName ).arg ( qsTemplatePath );
+    iRet = system ( qsCommand.ascii ( ) );
+  }
+
   thePainter.begin ( &theBackground );
   if ( pMenuPreview ) {
     for (t=0;t<pMenuPreview->objectCount ( );t++) {
@@ -951,9 +1094,16 @@ bool DialogCreateTemplate::createIndexXml ( )
 {
   // This is not realy part of the template but rather the lines to plug into 
   // the index.xml - file to let this Template show up.
-  QString qsIndexXml, qsFileName, qsTemplatePath;
+  QString qsIndexXml, qsFileName, qsTemplatePath, qsCategory;
   QFileInfo fileInfo;
-  int iThumbnailSize, iPackageSize;
+  int iThumbnailSize, iPackageSize, iWidth, iHeight;
+  const QPixmap *pThumbnail = m_pFrameThumbnail->paletteBackgroundPixmap ( );
+  iWidth = iHeight = 0;
+  if ( pThumbnail ) {
+    iWidth  = pThumbnail->width  ( );
+    iHeight = pThumbnail->height ( );
+  }
+  qsCategory = m_pComboCategory->currentText ( );
   
   qsFileName = m_pEditFileName->text ( );
   qsTemplatePath = QString ( "%1/%2%3" ).arg ( Global::qsTempPath ).arg ( getTypePath ( ) ).arg ( qsFileName );
@@ -964,9 +1114,10 @@ bool DialogCreateTemplate::createIndexXml ( )
   iPackageSize = fileInfo.size ( );
 
   qsIndexXml  = QString ( "<Templates>\n" );
-  qsIndexXml += QString ( "  <Entry name=\"%1\" type=\"%2\" >\n" ).arg ( qsFileName ).arg ( getTypePath ( ) );
+  qsIndexXml += QString ( "  <Entry name=\"%1\" type=\"%2\" category=\"%3\">\n" ).arg ( qsFileName ).arg ( getTypePath ( ) ).arg ( qsCategory );
   qsIndexXml += QString ( "    <Description>%1</Description>\n").arg ( m_pTextDesc->text ( ) );
-  qsIndexXml += QString ( "    <Thumbnail size=\"%1\">%2.png</Thumbnail>\n").arg( iThumbnailSize ).arg( qsFileName );
+  qsIndexXml += QString ( "    <Thumbnail width=\"%1\" height=\"%2\"size=\"%3\">%4.png</Thumbnail>\n").
+    arg( iWidth ).arg( iHeight ).arg( iThumbnailSize ).arg( qsFileName );
   qsIndexXml += QString ( "    <Location size=\"%1\">%2.tar.gz</Location>\n" ).arg( iPackageSize ).arg( qsFileName );
   qsIndexXml += QString ( "  </Entry>\n" );
   qsIndexXml += QString ( "<Templates>\n" );
