@@ -1,8 +1,10 @@
 /****************************************************************************
 ** Interface to the GUI.
 **
-** Created: Wed March 16 22:48:00 2005
-**      by: Varol Okan using kate editor
+**   Created : Wed March 16 22:48:00 2005
+**        by : Varol Okan using kate editor
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 **
 ****************************************************************************/
@@ -17,18 +19,20 @@
 
 class MovieObject;
 class DVDMenu;
+class QDVDAuthor;
 class MediaInterface;
 class StartStopControl;
+class Subtitles::entry;
 
 class ListViewColorItem : public QListViewItem
 {
 public:
-	ListViewColorItem (QListView *, QColor, QString, QString l2=QString::null, QString l3=QString::null, QString l4=QString::null,
-		QString l5=QString::null, QString l6=QString::null, QString l7=QString::null, QString l8=QString::null);
+  ListViewColorItem (QListView *, Rgba, QString, QString l2=QString::null, QString l3=QString::null, QString l4=QString::null,
+		     QString l5=QString::null, QString l6=QString::null, QString l7=QString::null, QString l8=QString::null);
 
-	virtual void paintCell ( QPainter *, const QColorGroup &, int, int, int);
+  virtual void paintCell ( QPainter *, const QColorGroup &, int, int, int );
 private:
-	QColor m_theColor;
+  Rgba m_theColor;
 };
 
 class DialogMovie : public uiDialogMovie
@@ -38,18 +42,18 @@ public:
 	 DialogMovie(QWidget *p=NULL, const char *n=NULL, WFlags f=0);
 	~DialogMovie();
 
-	void initMe(SourceFileInfo  *, const void *, int);
+	void initMe(SourceFileInfo  *, const void *, QDVDAuthor * );
 	void initMe(SourceFileEntry *);
 	void initMe(MovieObject     *);
 	void initMe(DVDMenu         *);
-	void initMediaInterface(DVDMenu *);
 
-	bool transcodeEnabled ();
-	void initTranscodeTab ();
+	bool transcodeEnabled ( );
+	void initTranscodeTab ( );
 	
-	SourceFileInfo *sourceFileInfo ();
+	SourceFileInfo *sourceFileInfo ( );
 
 protected slots:
+	virtual void timerEvent       ( QTimerEvent * );
 	virtual void slotNewVolume    ( int );
 	virtual void accept           ( );
 	virtual void slotBlink        ( );
@@ -63,6 +67,7 @@ protected slots:
 	virtual void slotTranscode    ( );
 	virtual void slotEncodeNow    ( );
 
+	virtual void slotImportChapter( );
 	virtual void slotAddChapter   ( );
 	virtual void slotDelChapters  ( );
 	virtual void slotAutoChapters ( );
@@ -84,19 +89,42 @@ protected slots:
 	virtual void slotAudioOutChanged        (const QString &);
 	virtual void slotAudioTypeChanged       (const QString &);
 	virtual void slotAudioBitrateChanged    (const QString &);
-	virtual void slotSetStartStop           ();
 
-	virtual void slotAddColorKey ();
-	virtual void slotDelColorKey ();
-	virtual void slotBrowseColorKey ();
+	virtual void slotSetStartStop       ( );
+	virtual void slotSetMediaInfo       ( );
+	virtual void slotInitMediaInterface ( );
+	virtual void slotSameAsMenuLength   ( );
+
+	virtual void slotAddColorKey    ( );
+	virtual void slotDelColorKey    ( );
+	virtual void slotBrowseColorKey ( );
+	
+	virtual void slotAddAudio       ( );
+	virtual void slotEditAudio      ( );
+	virtual void slotDeleteAudio    ( );
+	virtual void slotAddSubtitle    ( );
+	virtual void slotEditSubtitle   ( );
+	virtual void slotDeleteSubtitle ( );
+	virtual void slotAudioSelectionChanged    ( QListViewItem * );
+	virtual void slotSubtitleSelectionChanged ( QListViewItem * );
+
+	virtual void slotSetSelectedItem( );
+	virtual void slotSubLangChanged ( bool );
 
 signals:
 	void signalSetThumbnail ( long );
 
 private:
-	long normToLong ( QString qsInput );
-	QString longToNorm  ( long iInput );
-	void setStartStop          ( bool );
+	QString keepClean   ( const QString  & );
+	void setStartStop   ( bool             );
+	void addChapter     ( QString &        );
+	void initMediaInterface ( DVDMenu    * );
+	void initAudioTab   ( SourceFileInfo *, DVDMenu *p=NULL );
+	bool sanityCheckSubtitleTrack( int   & );
+	void addSubtitle    ( QString, int, QValueList<Subtitles::entry *> & );
+	bool subtitleDialog ( int &, QString & );
+	void deleteSubtitle ( int );
+	TranscodeInterface *checkRightAudioFormat ( QString & );
 
 private:
 	QRect             m_rectGeometry;
@@ -104,11 +132,16 @@ private:
 	QString           m_qsPosition;
 	int               m_iMovieLength;
 	QWidget          *m_pTranscodeTab;
-	MediaInterface   *m_pMediaInterface;
+	QListViewItem    *m_pSelectItem;
+	MediaInterface   *m_pMediaInterface;	
 	StartStopControl *m_pStartStopControl;
 	SourceFileInfo    m_sourceFileInfo;
+	SourceFileEntry  *m_pParentSourceFileEntry;
 	MovieObject      *m_pMovieObject;
 	DVDMenu          *m_pDVDMenu;
+
+	// the following is only used for the initializaion part
+	const void       *m_pExistingEngine;
 };
 
 #endif // DIALOGMOVIE_H
