@@ -1,8 +1,10 @@
 /****************************************************************************
 ** DialogTextFont class
 **
-** Created: Tue Feb 18 22:48:00 2004
-**      by: Varol Okan using Kate
+**   Created : Tue Feb 18 22:48:00 2004
+**        by : Varol Okan using Kate
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 **
 ****************************************************************************/
@@ -27,19 +29,21 @@
 #include "dialoganimation.h"
 
 // Here we initialize the static member variables ...
-QFont   DialogTextFont::m_previousFont       = QFont   ();
-QString DialogTextFont::m_previousText       = QString ();
+QFont   DialogTextFont::m_previousFont       = QFont   ( );
+QString DialogTextFont::m_previousText       = QString ( );
 QPoint  DialogTextFont::m_previousTextAlign  = QPoint  ( Qt::AlignHCenter, Qt::AlignVCenter );
-QColor  DialogTextFont::m_previousBackground = QColor  ( TRANSPARENT_COLOR );
-QColor  DialogTextFont::m_previousForeground = QColor  ( 0, 0, 0 );
+Rgba    DialogTextFont::m_previousBackground = Rgba    ( TRANSPARENT_COLOR, 0xff );
+Rgba    DialogTextFont::m_previousForeground = Rgba    ( 20, 20, 255, 255 );
 
-DialogTextFont::DialogTextFont(QWidget * parent, const char * name, WFlags f)
-	: uiDialogTextFont (parent, name, f)
+DialogTextFont::DialogTextFont ( QWidget *pParent, const char *pName, WFlags f)
+	: uiDialogTextFont ( pParent, pName, f )
 {
-  initMe();
+  initMe ( );
+  if ( pParent )
+    connect ( this, SIGNAL ( signalAnimate ( QString &, int, QString ) ), pParent, SLOT ( slotAnimateObject ( QString &, int, QString ) ) );
 }
 
-DialogTextFont::~DialogTextFont()
+DialogTextFont::~DialogTextFont ( )
 {
 
 }
@@ -56,6 +60,7 @@ void DialogTextFont::setFont ( const QFont &newFont )
 			break;
 		}
 	}
+	updateFont ( 0 );
 	// Next we try to set the style of the font.
 	iIndex = 0;
 	QFontDatabase database;
@@ -67,6 +72,7 @@ void DialogTextFont::setFont ( const QFont &newFont )
 		}
 	}
 	m_pComboFontStyle->setCurrentItem(iIndex);
+	updateFont ( 1 );
 	// Here we get the font size which comes closest to the newFont pointSize (or the same).
 	int iAvailFontSize, iFontSize = newFont.pointSize();
 	for (iIndex=0;iIndex<m_pComboFontSizes->count();iIndex++)	{
@@ -247,23 +253,33 @@ void DialogTextFont::updateButtons ()
 void DialogTextFont::initMe()
 {
 	// Here we set all available options ...
+        m_iSelectedFontSize = 12;
 	QFontDatabase database;
 	setTransparency (0.0);
 	QStringList listFonts = database.families();
 	m_pListFonts->insertStringList(listFonts);
 	// Next we search for a good starting font ...
 	uint t, iIndex;
+	QString fontName;
 	for (iIndex=0;iIndex<m_pListFonts->count();iIndex++)	{
-		if (m_pListFonts->text(iIndex) == QString ("Arial"))
-			break;
-		else if (m_pListFonts->text(iIndex) == QString ("Courier"))
-			break;
-		else if (m_pListFonts->text(iIndex) == QString ("Times New Roman"))
-			break;
-		else if (m_pListFonts->text(iIndex) == QString ("Times"))
-			break;
+		fontName = m_pListFonts->text(iIndex);
+		if (fontName == QString ("Arial"))
+		  break;
+		else if (fontName == QString ("Courier"))
+		  break;
+		else if (fontName == QString ("Times New Roman"))
+		  break;
+		else if (fontName == QString ("Times"))
+		  break;
+		else if (fontName == QString ("Nimbus Sans L"))
+		  break;
+		else if (fontName == QString ("Sans Serif"))
+		  break;
 	}
-	QString fontName = m_pListFonts->text(iIndex);
+	if ( iIndex < listFonts.count ( ) )
+		fontName = m_pListFonts->text(iIndex);
+	else
+		fontName = m_pListFonts->text( 0 );
 
 	QStringList listStyles = database.styles (fontName);
 	m_pComboFontStyle->insertStringList (listStyles);
@@ -284,7 +300,7 @@ void DialogTextFont::initMe()
 	iIndex = 0;
 	for (t=0;t<listSizes.count();t++)	{
 		m_pComboFontSizes->insertItem (QString ("%1").arg(listSizes[t]));
-		if (listSizes[t] < 11)	// Lets get at least a nice big raedable size
+		if (listSizes[t] < 11)	// Lets get at least a nice big readable size
 			iIndex = t;
 	}
 	m_pComboFontSizes->setCurrentItem (iIndex);
@@ -315,7 +331,7 @@ void DialogTextFont::initMe()
 	connect (m_pListFonts, SIGNAL(highlighted (int)), this, SLOT(slotFontFamilyChanged(int)));
 	connect (m_pComboFontStyle, SIGNAL(activated (int)), this, SLOT(slotFontStyleChanged(int)));
 	connect (m_pComboFontSizes, SIGNAL(activated (int)), this, SLOT(slotFontSizeChanged(int)));
-	connect (m_pComboFontSizes, SIGNAL(textChanged ( const QString & )), this, SLOT(slotFontSizeChanged( const QString & )));
+	//	connect (m_pComboFontSizes, SIGNAL(textChanged ( const QString & )), this, SLOT(slotFontSizeChanged( const QString & )));
 	connect (m_pComboScript, SIGNAL(activated (int)), this, SLOT(slotScriptChanged(int)));
 
 	connect (m_pButtonLeft, SIGNAL(toggled (bool)), this, SLOT(slotLeft(bool)));
@@ -354,30 +370,45 @@ void DialogTextFont::resizeEvent ( QResizeEvent *pEvent )
 
 void DialogTextFont::paintEvent (QPaintEvent *pPaint)
 {
-	// first we call the main function
-	QWidget::paintEvent(pPaint);
-
-	// and here we do  our little do ...
-	QColor transparentColor = QColor(TRANSPARENT_COLOR);
-	if (transparentColor.rgb() ==  m_backgroundColor.rgb())	{	//m_pFrameBackgroundColor->paletteForegroundColor())	{
-		QPainter thePainter (m_pFrameBackgroundColor);
-		thePainter.setPen(QPen(QColor(0, 0, 0), 2));
-		thePainter.drawLine(6, 6, m_pFrameBackgroundColor->width()-6, m_pFrameFontColor->height()-6);
-		thePainter.drawLine(6, m_pFrameFontColor->height()-6, m_pFrameBackgroundColor->width()-6, 6);
-	}
+  // first we call the main function
+  QWidget::paintEvent(pPaint);
+  
+  // and here we do  our little do ...
+  if ( m_backgroundColor.alpha ( ) == 0 )  {
+    //m_pFrameBackgroundColor->paletteForegroundColor())	{
+    QPainter thePainter ( m_pFrameBackgroundColor );
+    thePainter.setPen   ( QPen ( QColor ( 0, 0, 0 ), 2 ) );
+    thePainter.drawLine ( 6, 6, m_pFrameBackgroundColor->width ( )-6, m_pFrameFontColor->height ( )-6 );
+    thePainter.drawLine ( 6, m_pFrameFontColor->height ( )-6, m_pFrameBackgroundColor->width ( )-6, 6 );
+  }
+  if ( m_foregroundColor.alpha ( ) == 0 )  {
+    //m_pFrameBackgroundColor->paletteForegroundColor())	{
+    QPainter thePainter ( m_pFrameBackgroundColor );
+    thePainter.setPen   ( QPen ( QColor ( 0, 0, 0 ), 2 ) );
+    thePainter.drawLine ( 6, 6, m_pFrameBackgroundColor->width ( )-6, m_pFrameFontColor->height ( )-6 );
+    thePainter.drawLine ( 6, m_pFrameFontColor->height ( )-6, m_pFrameBackgroundColor->width ( )-6, 6 );
+  }
 }
 
 void DialogTextFont::slotForegroundColor ()
 {
-	QColor newColor = QColorDialog::getColor(m_foregroundColor, this);
-	setForegroundColor (newColor);
+  bool bOkay;
+  QRgb newColor = QColorDialog::getRgba ( m_foregroundColor.rgb ( ), &bOkay, this );
+  if ( bOkay ) {
+    Rgba theColor      ( newColor );
+    setForegroundColor ( theColor );
+  }
 }
 
 void DialogTextFont::slotBackgroundColor ()
 {
-	QColor transparentColor = QColor(TRANSPARENT_COLOR);
-	QColor newColor = QColorDialog::getColor(transparentColor, this);
-	setBackgroundColor (newColor);
+  bool bOkay;
+  Rgba transparentColor = Rgba ( TRANSPARENT_COLOR, 0 );
+  QRgb newColor         = QColorDialog::getRgba ( transparentColor.rgb ( ), &bOkay, this );
+  if ( bOkay ) {
+    Rgba theColor      ( newColor );
+    setBackgroundColor ( theColor );
+  }
 }
 
 void DialogTextFont::slotTransparency (int iNewValue)
@@ -402,17 +433,23 @@ void DialogTextFont::slotFontStyleChanged(int)
 	updateFont(1);
 }
 
-void DialogTextFont::slotFontSizeChanged(int)
+void DialogTextFont::slotFontSizeChanged ( int )
 {
   QSize size = m_pTextEdit->size ( );
   m_pTextEdit->setFixedSize ( size );
   updateFont(2);
-  //  m_pTextEdit->resize ( size );
+  m_iSelectedFontSize = m_pComboFontSizes->currentText ( ).toInt ( );
+  if ( m_iSelectedFontSize < 4 )
+       m_iSelectedFontSize = 12;
 }
 
 void DialogTextFont::slotFontSizeChanged( const QString & )
 {
-  updateFont(2);
+  m_iSelectedFontSize = m_pComboFontSizes->currentText ( ).toInt ( );
+  if ( m_iSelectedFontSize < 4 )
+       m_iSelectedFontSize = 12;
+  //  printf ( "       DialogTextFone::slotFontSizeChanged  :  SelectedFontSize<%d> vs <%s>\n", m_iSelectedFontSize, string.ascii() );
+  updateFont ( 2 );
 }
 
 void DialogTextFont::slotScriptChanged(int)
@@ -486,22 +523,7 @@ void DialogTextFont::slotStrikeout (bool)
 
 void DialogTextFont::slotAnimation ()
 {
-	// This function gets the Animation Dialog
-	// Within this dialo, you can create a script
-	// (or hardcode) Attributes of the object.
-	// Before rendering the menu the script will 
-	// get executed and all data sent to stdout 
-	// will be captured in the data file, wich 
-	// will provide the data for the animation.
-	QString qsEmpty;
-	DialogAnimation dialog ( this );
-	dialog.initMe ( m_qsAnimation, 300, 25.0, DialogAnimation::TypeText );
-	dialog.setFontName ( m_qfFont.toString () );
-	if ( dialog.exec () == QDialog::Accepted )
-		m_qsAnimation = dialog.string ();
-
-	if (m_qsAnimation.length () < 5)
-		m_qsAnimation = qsEmpty;
+  emit ( signalAnimate ( m_qsAnimation, DialogAnimation::TypeText, m_qfFont.toString ( ) ) );
 }
 
 void  DialogTextFont::updateFont(uint iSwitch)
@@ -512,7 +534,8 @@ void  DialogTextFont::updateFont(uint iSwitch)
 	QFontDatabase database;
 	QString fontName  = m_pListFonts->text(m_pListFonts->currentItem());
 	QString styleName = m_pComboFontStyle->text(m_pComboFontStyle->currentItem());
-	int iFontSize     = m_pComboFontSizes->currentText ().toInt();
+	//	int iFontSize     = m_pComboFontSizes->currentText ().toInt();
+	int iFontSize = m_iSelectedFontSize;
 	switch (iSwitch)	{
 	case 0:	{
 		// The fontName has changed, so we need to get the styles avail for this new font.
@@ -574,32 +597,29 @@ int DialogTextFont::findString (QStringList &list, QString string)
 	return -1;
 }
 
-QColor &DialogTextFont::getBackgroundColor ()
+Rgba &DialogTextFont::getBackgroundColor ()
 {
-	return m_backgroundColor;
+  return m_backgroundColor;
 }
 
-QColor &DialogTextFont::getForegroundColor ()
+Rgba &DialogTextFont::getForegroundColor ()
 {
-	return m_foregroundColor;
+  return m_foregroundColor;
 }
 
-void DialogTextFont::setBackgroundColor ( const QColor &newColor )
+void DialogTextFont::setBackgroundColor ( Rgba &newColor )
 {
-	// Check if the user pressed cancel ...
-	if (!newColor.isValid())
-		return;
-	m_pFrameBackgroundColor->setPaletteBackgroundColor(newColor);
-	update();
-	m_pTextEdit->setPaletteBackgroundColor   (newColor);
-	m_backgroundColor = newColor;
+  m_pFrameBackgroundColor->setPaletteBackgroundColor ( newColor.color ( ) );
+  update ( );
+  m_pTextEdit->setPaletteBackgroundColor             ( newColor.color ( ) );
+  m_backgroundColor = newColor;
 }
 
-void DialogTextFont::setForegroundColor (QColor &newColor)
+void DialogTextFont::setForegroundColor ( Rgba &newColor )
 {
-	m_pFrameFontColor->setPaletteBackgroundColor(newColor);
-	m_pTextEdit->setPaletteForegroundColor (newColor);
-	m_foregroundColor = newColor;
+  m_pFrameFontColor->setPaletteBackgroundColor ( newColor.color ( ) );
+  m_pTextEdit->setPaletteForegroundColor       ( newColor.color ( ) );
+  m_foregroundColor = newColor;
 }
 
 void DialogTextFont::slotOkay()
