@@ -1,8 +1,10 @@
 /****************************************************************************
 ** Interface to the GUI.
 **
-** Created: Wed Feb 18 22:48:00 2004
-**      by: Varol Okan using kate editor
+**   Created : Wed Feb 18 22:48:00 2004
+**        by : Varol Okan using kate editor
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 **
 ****************************************************************************/
@@ -14,6 +16,7 @@
 #include <qstring.h>
 
 // the designer created GUI.
+#include "rgba.h"
 #include "uidialogtextfont.h"
 
 class QPaintEvent;
@@ -25,29 +28,29 @@ public:
 	 DialogTextFont (QWidget * parent, const char * name = 0, WFlags f = 0 );
 	~DialogTextFont ();
 
-	void     setFont (const QFont &);
-	QFont   &getFont              ();
-	void     setText     (QString &);
-	void     setTextAlign (QPoint &);
-	void     setTransparency (float);
-	void     setRect       (QRect &);
-	QRect   &getRect              ();
-	void     setAnimation(QString &);
-	QString &getAnimation         ();
-	bool     getFit               ();
-	QString  getText              ();
-	QPoint  &getTextAlign         ();
-	QColor  &getBackgroundColor   ();
-	QColor  &getForegroundColor   ();
-	float    getTransparency      ();
-	void     setBackgroundColor   (const QColor &);
-	void     setForegroundColor   (QColor &);
+	void     setFont (const QFont & );
+	QFont   &getFont              ( );
+	void     setText     (QString & );
+	void     setTextAlign (QPoint & );
+	void     setTransparency (float );
+	void     setRect       (QRect & );
+	QRect   &getRect              ( );
+	void     setAnimation(QString & );
+	QString &getAnimation         ( );
+	bool     getFit               ( );
+	QString  getText              ( );
+	QPoint  &getTextAlign         ( );
+        Rgba    &getBackgroundColor   ( );
+	Rgba    &getForegroundColor   ( );
+	float    getTransparency      ( );
+	void     setBackgroundColor   ( Rgba & );
+	void     setForegroundColor   ( Rgba & );
 
 protected:
 	void initMe             ( );
 	void updateFont         ( uint iSwitch );
 	void updateButtons      ( );
-	int  findString         ( QStringList &list, QString string);
+	int  findString         ( QStringList &, QString );
 	virtual void paintEvent ( QPaintEvent * );
 
 protected slots:
@@ -71,19 +74,23 @@ protected slots:
 	virtual void slotTransparency      ( int  );
 	virtual void slotOkay              (      );
 
+signals:
+	void signalAnimate ( QString &, int, QString );
+
 private:
-	QFont	m_qfFont;
-	QColor	m_backgroundColor;
-	QColor	m_foregroundColor;
+	QFont   m_qfFont;
+	Rgba    m_backgroundColor;
+	Rgba    m_foregroundColor;
 	float   m_fTransparency;
 	QString m_qsAnimation;
+	int     m_iSelectedFontSize;
 
 	static QFont    m_previousFont;
 	static QString  m_previousText;
 	static float    m_previousTransparency;
 	static QPoint   m_previousTextAlign;
-	static QColor   m_previousForeground;
-	static QColor   m_previousBackground;
+	static Rgba     m_previousForeground;
+	static Rgba     m_previousBackground;
 };
 
 #endif // DIALOGTEXTFONT_H
