@@ -1,7 +1,9 @@
 /****************************************************************************
 ** UndoBuffer and UndoObject classes
-** Created: Saturday Nov 30'st 2004
-** Varol Okan
+**   Created : Saturday Nov 30'st 2004
+**        by : Varol Okan
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 ****************************************************************************/
 #ifndef DVDMENUUNDOOBJECT_H
 #define DVDMENUUNDOOBJECT_H
@@ -23,7 +25,7 @@ class DVDMenuUndoObject : public UndoObject
 {
 	class BackgroundInfo	{
 	public:
-		BackgroundInfo () {};
+		BackgroundInfo ( );
 		void getBackgroundInfo (CDVDMenuInterface  *);
 		void setBackgroundInfo (CDVDMenuInterface  *);
 		BackgroundInfo &operator = (BackgroundInfo &);
