@@ -1,8 +1,10 @@
 /****************************************************************************
 ** Execute class
 **
-** Created: Tue Jan 20 12:09:08 2003
-**      by: Varol Okan using kate editor
+**   Created : Tue Jan 20 12:09:08 2003
+**        by : Varol Okan using kate editor
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 ** This class is an enhaced version of QProcess. It will display the 
 ** output and the error messages (if any) in a graphical GUI.
@@ -19,10 +21,11 @@
 #include <qvariant.h>
 #include <qdialog.h>
 
-#define RENDER_MENU        "#=- Internal : Render Menu -=# "
-#define CONVERT_VIDEOTRANS "#=- VideoTrans -=# "
-#define CONVERT_TRANSCODE  "#=- Transcode -=# "
-#define CONVERT_MENCODER   "#=- MEncoder -=# "
+#define RENDER_MENU          "#=- Internal : Render Menu -=# "
+#define CONVERT_VIDEOTRANS   "#=- VideoTrans -=# "
+#define CONVERT_TRANSCODE    "#=- Transcode -=# "
+#define CONVERT_MENCODER     "#=- MEncoder -=# "
+#define BACKGROUND_MISCTOOLS "#=- Misc Tools -=#"
 
 class QVBoxLayout;
 class QHBoxLayout;
@@ -57,6 +60,7 @@ public:
 public:
     QPushButton* buttonHelp;
     QCheckBox* checkKeepOpen;
+    QPushButton* buttonAnalyze;
     QPushButton* buttonExport;
     QPushButton* buttonPlay;
     QPushButton* buttonOk;
@@ -72,11 +76,12 @@ protected:
     QHBoxLayout* layout2;
 
 protected slots:
-    virtual void languageChange();
-    virtual void slotTimerDone();
-    virtual void slotKeepOpen(bool);
-    virtual void slotExport ();
-    virtual void slotPlay ();
+    virtual void languageChange ( );
+    virtual void slotTimerDone  ( );
+    virtual void slotKeepOpen   ( bool );
+    virtual void slotExport     ( );
+    virtual void slotPlay       ( );
+    virtual void slotAnalyze    ( );
 
 protected:
 	QTimer *m_pTimer;
