@@ -1,8 +1,10 @@
 /****************************************************************************
 ** FrameObject class
 **
-** Created: Tue Feb 02 22:06:51 2004
-**      by: Varol Okan using Kate
+**   Created : Tue Feb 02 22:06:51 2004
+**        by : Varol Okan using Kate
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 ** This class is the encapsulation of the FrameObject.
 **
@@ -36,7 +38,6 @@ FrameObject::FrameObject (QWidget *pParent)
 
 FrameObject::~FrameObject ()
 {
-
 }
 
 void FrameObject::setFrameWidth(int iFrameWidth)
@@ -54,25 +55,25 @@ void FrameObject::setFrameStyle(int iFrameStyle)
 	m_iFrameStyle = iFrameStyle;
 }
 
-void FrameObject::replaceColor(QColor theColor, QColor oldColor)
+void FrameObject::replaceColor ( Rgba theColor, Rgba oldColor )
 {
-	if (color () == oldColor)
-		setFrameColor (theColor);
+  if ( color ( ) == oldColor )
+    setFrameColor ( theColor );
 }
 
-void FrameObject::setFrameColor(QColor colorFrame)
+void FrameObject::setFrameColor ( Rgba colorFrame )
 {
   m_colorFrame = colorFrame;
 }
 
 int FrameObject::width ()
 {
-	return m_iFrameWidth;
+  return m_iFrameWidth;
 }
 
-QColor FrameObject::color ()
+Rgba FrameObject::color ()
 {
-	return m_colorFrame;
+  return m_colorFrame;
 }
 
 int FrameObject::style ()
@@ -97,7 +98,7 @@ void FrameObject::drawContents (QPainter *painter)
 	// Here we define the cenetered rect.
 	QRect theRect ((int)-(rect().width()/ 2.0), (int)-(rect().height()/2.0), rect().width(), rect().height());
 
-	QPen thePen (m_colorFrame, m_iFrameWidth, (Qt::PenStyle)m_iFrameStyle, Qt::FlatCap, (Qt::PenJoinStyle)m_iFrameJoin);
+	QPen thePen (m_colorFrame.rgb ( ), m_iFrameWidth, (Qt::PenStyle)m_iFrameStyle, Qt::FlatCap, (Qt::PenJoinStyle)m_iFrameJoin);
 	// Set the PEN
 	painter->setPen(thePen);
 	// and make sure no Brush is used ...
@@ -125,11 +126,16 @@ void FrameObject::drawContents (QPainter *painter)
 
 void FrameObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int)
 {
-	// Next is to set the AnimationAttributes
-	for (uint t=0;t<m_listAnimationAttributes.count();t++)
-		m_listAnimationAttributes[t]->setValue (iRenderFrameNumber);
+  // Next is to set the AnimationAttributes
+  for ( uint t=0; t<m_listAnimationAttributes.count ( ); t++ )
+    m_listAnimationAttributes[t]->setValue(iRenderFrameNumber);
 
-	drawContents (pPainter);
+  // If start stop have been set then we check the range
+  if ( ( ( iRenderFrameNumber < modifiers ( )->iStartFrame ) && ( modifiers ( )->iStartFrame != -1 ) ) || 
+       ( ( iRenderFrameNumber > modifiers ( )->iStopFrame  ) && ( modifiers ( )->iStopFrame  != -1 ) ) ) 
+    return;
+
+  drawContents ( pPainter );
 }
 
 bool FrameObject::mousePressEvent (QMouseEvent *pEvent)
@@ -155,31 +161,32 @@ bool FrameObject::mouseReleaseEvent (QMouseEvent *)
 bool FrameObject::mouseDoubleClickEvent (QMouseEvent *)
 {
 	QString qsAnimation;
-	DialogFrame frameDialog (m_pParent);
-	frameDialog.initMe(this);
-	if (frameDialog.exec() == QDialog::Rejected)
+	DialogFrame frameDialog ( m_pParent );
+	frameDialog.initMe ( this );
+	if ( frameDialog.exec ( ) == QDialog::Rejected )
 		return false;
-	setFrameWidth(frameDialog.frameWidth ());
-	setFrameStyle(frameDialog.style());
-	setFrameJoin (frameDialog.join ());
-	qsAnimation = frameDialog.animation ();
-	setAnimation ( qsAnimation );
-	if (color() != frameDialog.color())	{
+
+	setFrameWidth ( frameDialog.frameWidth ( ) );
+	setFrameStyle ( frameDialog.style      ( ) );
+	setFrameJoin  ( frameDialog.join       ( ) );
+	qsAnimation =   frameDialog.animation  ( );
+	setAnimation  ( qsAnimation );
+	if ( color ( ) != frameDialog.color ( ) )  {
 		// This emit signal is only caught when in ButtonDialog and the Selected, or Highlighted mask 
 		// was changed (I.e. This Object is in one of those two frames).
 		// Otherwise the signal is ignored.
-		emit (signalMaskColorChanged(frameDialog.color(), color()));
+		emit ( signalMaskColorChanged ( frameDialog.color ( ), color ( ) ) );
 		// P.s. replaceColor (QColor, QColor) of all ButtonObjects will be called, inclusive this object)
 	}
-	setFrameColor(frameDialog.color());
+	setFrameColor ( frameDialog.color ( ) );
 	int x, y, width, height;
-	x      = frameDialog.m_pEditX->text().toInt();
-	y      = frameDialog.m_pEditY->text().toInt();
-	width  = frameDialog.m_pEditWidth->text().toInt();
-	height = frameDialog.m_pEditHeight->text().toInt();
-	QRect newRect (x, y, width, height);
-	setRect (newRect);
-	emit (signalUpdatePixmap());
+	x      = frameDialog.m_pEditX->text ( ).toInt ( );
+	y      = frameDialog.m_pEditY->text ( ).toInt ( );
+	width  = frameDialog.m_pEditWidth->text  ( ).toInt ( );
+	height = frameDialog.m_pEditHeight->text ( ).toInt ( );
+	QRect newRect ( x, y, width, height );
+	setRect ( newRect );
+	emit    ( signalUpdatePixmap ( ) );
 	return false;
 }
 
@@ -191,7 +198,7 @@ bool FrameObject::readProjectFile  (QDomNode &theNode)
 
 	attribute = theElement.attributeNode ( FRAME_OBJECT_COLOR );
 	if (!attribute.isNull())
-		m_colorFrame = QColor(attribute.value());
+		m_colorFrame.fromString ( attribute.value ( ) );
 
 	attribute = theElement.attributeNode ( FRAME_OBJECT_WIDTH );
 	if (!attribute.isNull())
@@ -224,13 +231,13 @@ bool FrameObject::writeProjectFile (QDomElement &theElement)
 	QDomElement frameNode = xmlDoc.createElement( FRAME_OBJECT );	// <FrameObject>
 	// Here we set the attributes of the <dvdauthor> tag
 	if (m_iFrameWidth != 4)
-		frameNode.setAttribute( FRAME_OBJECT_WIDTH, m_iFrameWidth );
-	if (m_colorFrame != QColor (START_FRAME_COLOR))
-		frameNode.setAttribute( FRAME_OBJECT_COLOR, m_colorFrame.name() );
+		frameNode.setAttribute ( FRAME_OBJECT_WIDTH, m_iFrameWidth );
+	if (m_colorFrame != Rgba ( START_FRAME_COLOR ) )
+		frameNode.setAttribute ( FRAME_OBJECT_COLOR, m_colorFrame.toString ( ) );
 	if (m_iFrameStyle != (int)Qt::SolidLine)
-		frameNode.setAttribute( FRAME_OBJECT_STYLE, m_iFrameStyle );
+		frameNode.setAttribute ( FRAME_OBJECT_STYLE, m_iFrameStyle );
 	if (m_iFrameJoin != (int)Qt::MiterJoin)
-		frameNode.setAttribute( FRAME_OBJECT_JOIN,  m_iFrameJoin );
+		frameNode.setAttribute ( FRAME_OBJECT_JOIN,  m_iFrameJoin );
 
 	theElement.appendChild( frameNode );
 	// And here we write the base class ...
@@ -239,13 +246,22 @@ bool FrameObject::writeProjectFile (QDomElement &theElement)
 
 bool FrameObject::createContextMenu (QPoint globalPos)
 {
+        QString qsShadow;
         QPoint globalPos2 = globalPos;
 	QPopupMenu *pStackMenu = new QPopupMenu(m_pParent);
-	pStackMenu->insertItem ( tr ("To Front")  , this, SLOT(slotToFront()));
-	pStackMenu->insertItem ( tr ("To Back")   , this, SLOT(slotToBack()));
-	globalPos.setX (globalPos.x() - pStackMenu->sizeHint().width()); // -100);
+	pStackMenu->insertItem ( tr ("Cut") , this, SLOT ( slotCut  ( ) ) );
+	pStackMenu->insertItem ( tr ("Copy"), this, SLOT ( slotCopy ( ) ) );
+	pStackMenu->insertSeparator();
+	pStackMenu->insertItem ( tr ("To Front")  , this, SLOT(slotToFront ( ) ) );
+	pStackMenu->insertItem ( tr ("To Back")   , this, SLOT(slotToBack  ( ) ) );
+	globalPos.setY ( globalPos.y ( ) - 25 );
+	globalPos.setX ( globalPos.x ( ) - pStackMenu->sizeHint ( ).width ( ) ); // -100);
 	pStackMenu->popup(globalPos, 1);
 
+	qsShadow = tr ( "Add Shadow ..." );
+	if ( shadow ( ) )
+ 	   qsShadow = tr ( "Edit Shadow ..." );
+
 	if (m_pContextMenu)
 		delete m_pContextMenu;
 	m_pContextMenu = new QPopupMenu(m_pParent);
@@ -253,7 +269,7 @@ bool FrameObject::createContextMenu (QPoint globalPos)
 	m_pContextMenu->insertItem ( tr ("Matrix ..."), this, SLOT(slotMatrix     ( ) ) );
 	m_pContextMenu->insertItem ( tr ("Delete")    , this, SLOT(slotDelete     ( ) ) );
 	m_pContextMenu->insertSeparator();
-	m_pContextMenu->insertItem ( tr ("Add Shadow") , this, SLOT(slotAddShadow ( ) ) );
+	m_pContextMenu->insertItem ( qsShadow          , this, SLOT(slotAddShadow ( ) ) );
 	m_pContextMenu->insertItem ( tr ("Add Text")   , this, SLOT(slotAddText   ( ) ) );
 	m_pContextMenu->insertItem ( tr ("Add Image")  , this, SLOT(slotAddImage  ( ) ) );
 	m_pContextMenu->insertItem ( tr ("Add Movie")  , this, SLOT(slotAddMovie  ( ) ) );
@@ -271,56 +287,56 @@ bool FrameObject::createContextMenu (QPoint globalPos)
 		return true;
 }
 
-void FrameObject::createStructure (QListViewItem *pParentItem)
+StructureItem *FrameObject::createStructure ( StructureItem *pParentItem )
 {
-	StructureItem *pFrameItem;
-	StructureItem *pModifierItem;
+  StructureItem *pFrameItem, *pTemp=NULL;
 
-	QString qsName ( tr("Frame (%1, %2, %3, %4)").
-			 arg ( rect ( ).x      ( ) ).arg ( rect ( ).y      ( ) ).
-			 arg ( rect ( ).width  ( ) ).arg ( rect ( ).height ( ) ) );
-	//arg(m_colorFrame.red  ()).
-	//arg(m_colorFrame.green()).
-	//arg(m_colorFrame.blue ()));
-	setName (qsName);
+  QString qsName ( tr("Frame (%1, %2, %3, %4)" ).
+		   arg ( rect ( ).x      ( ) ).arg ( rect ( ).y      ( ) ).
+		   arg ( rect ( ).width  ( ) ).arg ( rect ( ).height ( ) ) );
+  setName ( qsName );
+  
+  qsName  = tr ( "Frame Object" );
+  QString qsInfo = QString ("%1 - (%2, %3, %4 %5)").arg ( width ( ) ).
+    arg ( rect ( ).x      ( ) ).arg ( rect ( ).y      ( ) ).
+    arg ( rect ( ).width  ( ) ).arg ( rect ( ).height ( ) );
 
-	qsName  = tr("Frame Object");
-	QString qsInfo = QString ("%1 - (%2, %3, %4 %5)").arg ( width ( ) ).
-	  arg ( rect ( ).x      ( ) ).arg ( rect ( ).y      ( ) ).
-	  arg ( rect ( ).width  ( ) ).arg ( rect ( ).height ( ) );
+  pFrameItem = m_pStructureItem;
+  if ( ! pFrameItem ) {
+    pFrameItem = new StructureItem ( this, pParentItem, pParentItem->lastChild ( ), qsName, qsInfo );
+    pFrameItem->setExpandable ( TRUE );
+    m_pStructureItem = pFrameItem;
+  }
+  else
+    pFrameItem->setText ( qsName, qsInfo );
 
-	pFrameItem = new StructureItem(this, pParentItem, qsName, qsInfo);
-	pFrameItem->setExpandable (TRUE);
+  QString qsArgs;
+  qsArgs =  QString ( "%1, %2, %3, %4" ).
+    arg ( rect ( ).x      ( ) ).
+    arg ( rect ( ).y      ( ) ).
+    arg ( rect ( ).width  ( ) ).
+    arg ( rect ( ).height ( ) );
+  pTemp  = pFrameItem->setSibling ( this, pTemp, tr ( "Geometry"    ), qsArgs );
 
-	// And finally we create the modifiers info ...
-	if ( !((m_modifiers.fRotate == 0.0) && (m_modifiers.fShearX == 0.0) && (m_modifiers.fShearY == 0.0) &&
-		   (m_modifiers.fZoom   == 1.0) && (m_modifiers.fScaleX == 1.0) && (m_modifiers.fScaleY == 1.0)) )	{
-	  pModifierItem = new StructureItem(this, pFrameItem, tr ("Modifiers"), NULL);
-		pFrameItem->setExpandable (TRUE);
+  qsArgs = QString ( "%1" ).arg ( width ( ) );
+  pTemp  = pFrameItem->setSibling ( this, pTemp, tr ( "Frame Width" ), qsArgs );
+  
+  qsArgs = tr ( "color(%1, %2, %3)" ).
+    arg ( m_colorFrame.red   ( ) ).
+    arg ( m_colorFrame.green ( ) ).
+    arg ( m_colorFrame.blue  ( ) );
 
-		new StructureItem(this, pModifierItem, tr ("Shear (x, y)"),
-			QString ("%1, %2").arg(m_modifiers.fShearX).arg(m_modifiers.fShearY));
-		new StructureItem(this, pModifierItem, tr ("Zoom"),
-			QString ("%1").arg(m_modifiers.fZoom));
-		new StructureItem(this, pModifierItem, tr ("Rotate"),
-			tr ("%1 deg").arg(m_modifiers.fRotate));
-	}
-	if ( m_pShadow )
-	     m_pShadow->createStructure ( pFrameItem );
+  pTemp  = pFrameItem->setSibling ( this, pTemp, tr ( "Frame Color" ), qsArgs );
+  
+  if ( m_pShadow )
+    pTemp = m_pShadow->createStructure ( pFrameItem );
 
-	new StructureItem(this, pFrameItem, tr ("Frame Color"),
-		tr ("color(%1, %2, %3)").
-			arg(m_colorFrame.red()).
-			arg(m_colorFrame.green()).
-			arg(m_colorFrame.blue()));
+  m_modifiers.createStructure ( pFrameItem, pTemp );
 
-	new StructureItem(this, pFrameItem, tr ("Frame Width"), QString ("%1").arg (width()));
-
-	new StructureItem(this, pFrameItem, tr ("Geometry"),
-		QString ("%1, %2, %3, %4").
-		arg(rect().x()).arg(rect().y()).arg(rect().width()).arg(rect().height()));
+  return pFrameItem;
 }
 
+
 void FrameObject::slotEdit()
 {
 	mouseDoubleClickEvent(NULL);
@@ -356,42 +372,49 @@ void FrameObject::slotDefineAsButton()
 	emit (signalDefineAsButton(this));
 }
 
-MenuObject *FrameObject::clone()
+MenuObject *FrameObject::clone ( QWidget *pParent, MenuObject * )
 {
-	FrameObject *pNewObject = new FrameObject (MenuObject::parent());
-	pNewObject->setFrameWidth(width());
-	pNewObject->setFrameStyle(style());
-	pNewObject->setFrameJoin (join ());
-	pNewObject->setFrameColor(color());
+  if ( !pParent )
+    pParent = MenuObject::parent ( );
 
-	// The following two are not really needed, since we get those
-	// informations solely from the Normal State - objects ...
-	pNewObject->setRect(rect());
-	pNewObject->setModifiers(*modifiers());
-
-	MenuObject *pShadow = shadow ( );
-	if ( pShadow )
-	  pShadow = pShadow->clone ( pNewObject );
-	pNewObject->setShadow      (  pShadow   );
-
-	return pNewObject;
+  FrameObject *pNewObject = new FrameObject ( pParent );
+  pNewObject->setFrameWidth(width());
+  pNewObject->setFrameStyle(style());
+  pNewObject->setFrameJoin (join ());
+  pNewObject->setFrameColor(color());
+  
+  // The following two are not really needed, since we get those
+  // informations solely from the Normal State - objects ...
+  pNewObject->setRect( rect ( ) );
+  pNewObject->setModifiers ( *modifiers ( ) );
+  
+  MenuObject *pShadow = shadow ( );
+  if ( pShadow )
+    pShadow = pShadow->clone ( pParent, pNewObject );
+  pNewObject->setShadow      ( pShadow );
+  
+  return pNewObject;
 }
 
 AnimationAttribute *FrameObject::getSpecificAttributes (long iMaxNumberOfFrames, QString qsProperty)
 {
 	AnimationAttribute *pAnimAttr = NULL;
 	if (qsProperty == "color.red")	{
-		FunctionCallback<QColor> *callMeBack = new FunctionCallback<QColor>(m_colorFrame, TYPE_COLOR_RED);
+		FunctionCallback<Rgba> *callMeBack = new FunctionCallback<Rgba>(m_colorFrame, TYPE_COLOR_RED);
 		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorFrame.red(), callMeBack);
 	}
 	else if (qsProperty == "color.green")	{
-		FunctionCallback<QColor> *callMeBack = new FunctionCallback<QColor>(m_colorFrame, TYPE_COLOR_GREEN);
+		FunctionCallback<Rgba> *callMeBack = new FunctionCallback<Rgba>(m_colorFrame, TYPE_COLOR_GREEN);
 		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorFrame.green(), callMeBack);
 	}
 	else if (qsProperty == "color.blue")	{
-		FunctionCallback<QColor> *callMeBack = new FunctionCallback<QColor>(m_colorFrame, TYPE_COLOR_BLUE);
+		FunctionCallback<Rgba> *callMeBack = new FunctionCallback<Rgba>(m_colorFrame, TYPE_COLOR_BLUE);
 		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorFrame.blue(), callMeBack);
 	}
+	else if (qsProperty == "color.alpha")	{
+		FunctionCallback<Rgba> *callMeBack = new FunctionCallback<Rgba>(m_colorFrame, TYPE_COLOR_ALPHA);
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorFrame.alpha(), callMeBack);
+	}
 	else if (qsProperty == "frameWidth")
 		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_iFrameWidth, &m_iFrameWidth);
 	else if (qsProperty == "frameStyle")
