@@ -17,10 +17,13 @@ QString Global::qsBashString         = QString ("/bin/bash\n\n");
 QString Global::qsTempPath           = QString ("/tmp");
 QString Global::qsProjectPath        = QString ("");
 QString Global::qsExternalPlayer     = QString ("qplayer");
+QString Global::qsLanguage           = QString ("en");
 uint    Global::iMaxRunningThreads   = 4;
 int     Global::iChildThreadPriority = 0;
 int     Global::iDeleteTempOlderThan = 30;
-QEventLoop Global::eventLoop;
+QValueList <Utils::toolsPaths *> Global::listToolsPaths;
+MenuObject *Global::pCopyObject      = NULL;
+QEventLoop  Global::eventLoop;
 
 Global::Global()
 {
