@@ -1,8 +1,10 @@
 /****************************************************************************
 ** ImageObject class
 **
-** Created: Tue Feb 02 22:06:51 2004
-**      by: Varol Okan using Kate
+**   Created : Tue Feb 02 22:06:51 2004
+**        by : Varol Okan using Kate
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 ** This class is the encapsulation of the ImageObject.
 **
@@ -34,7 +36,7 @@
 ImageObject::ImageObject (QWidget *pParent)
 	: MenuObject (pParent)
 {
-	m_qsObjectType = QString (IMAGE_OBJECT);
+  m_qsObjectType = QString (IMAGE_OBJECT);
 }
 
 ImageObject::~ImageObject ()
@@ -54,7 +56,7 @@ void ImageObject::setFile (QString fileName)
 	QFileInfo fileInfo(fileName);
 	m_qsFileName = fileInfo.fileName();
 	setName(m_qsFileName);
-	qsExtractionPath = fileInfo.baseName ();
+	qsExtractionPath = fileInfo.baseName ( true );
 	setExtractionPath(qsExtractionPath);
 	m_qsFileName = fileName;
 //	m_pixmap = QPixmap (fileName);
@@ -104,9 +106,9 @@ float ImageObject::zoom()
 	return m_imageManipulator.fZoom;
 }
 
-void ImageObject::drawContents (QPainter *painter)
+void ImageObject::drawContents ( QPainter *painter )
 {
-  //  printf ( "%s::%s::%d rotate=<%0.4f>\n", __FILE__, __FUNCTION__, __LINE__, manipulator().fRotate );
+  // printf ( "%s::%s::%d me<%p> shadow=<%p>\n", __FILE__, __FUNCTION__, __LINE__, this, m_pShadow );
 	QWMatrix theMatrix;
 	// Here we calculate the center point of gravity (rotation)
 	QPoint centerPos;
@@ -125,20 +127,19 @@ void ImageObject::drawContents (QPainter *painter)
 	// The third step uses the viewport.
 
 	// First we translate to the appropriate location,
-	theMatrix.translate ((double)centerPos.x(), (double)centerPos.y());
+	theMatrix.translate ( (double)centerPos.x ( ), (double)centerPos.y ( ) );
 
 	//. then we apply the other modifications ...
-//	theMatrix.scale  (manipulator().fZoom, manipulator().fZoom);
-	theMatrix.scale  (modifiers()->fScaleX, modifiers()->fScaleY);
-	theMatrix.shear  (manipulator().fShearX, manipulator().fShearY);
-	theMatrix.rotate (manipulator().fRotate);
+	//theMatrix.scale  ( modifiers ( )->fScaleX, modifiers ( )->fScaleY );
+	theMatrix.scale  ( manipulator ( ).fScaleX, manipulator ( ).fScaleY );
+	theMatrix.shear  ( manipulator ( ).fShearX, manipulator ( ).fShearY );
+	theMatrix.rotate ( manipulator ( ).fRotate );
 
 	// Here we get the rect that encompasses the button for this object.
 	m_boundingRect = theMatrix.mapRect(theRect);
-	if (m_bDrawRect) {
+
+	if (m_bDrawRect)
 	  drawActiveFrame ( painter );
-	  //painter->drawRect(m_boundingRect);
-	}
 
 	painter->setWorldMatrix(theMatrix);
 
@@ -253,18 +254,27 @@ void ImageObject::drawContents (QPainter *painter)
 			}
 		}
 	}
-	// Phew ... This funtion has grow over time ...
+	// Phew ... This funtion has grown over time ...
 }
 
 void ImageObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int)
 {
   // Next is to set the AnimationAttributes
-  for (uint t=0;t<m_listAnimationAttributes.count();t++)
-    m_listAnimationAttributes[t]->setValue (iRenderFrameNumber);
+  bool bRefresh = false;
+  for (uint t=0; t<m_listAnimationAttributes.count ( ); t++)
+    bRefresh |= m_listAnimationAttributes[t]->setValue ( iRenderFrameNumber );
+
+  //  printf ( "[%d] : Start<%d> Stop<%d>\n", iRenderFrameNumber, modifiers ( )->iStartFrame, modifiers ( )->iStopFrame );
+  // If start stop have been set then we check the range
+  if ( ( ( iRenderFrameNumber < modifiers ( )->iStartFrame ) && ( modifiers ( )->iStartFrame != -1 ) ) || 
+       ( ( iRenderFrameNumber > modifiers ( )->iStopFrame  ) && ( modifiers ( )->iStopFrame  != -1 ) ) ) 
+    return;
 
   // And then we ought to refresh the pixmap ...
-  if ( m_listAnimationAttributes.count () > 0 )
+  if ( bRefresh ) {
     updatePixmap ( );
+    updateShadow ( );
+  }
   // before we can go ahead and draw the contents with the newly set attributes.
   drawContents (pPainter);
 }
@@ -272,19 +282,26 @@ void ImageObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int)
 // This function checks if pColor is within the min/max of one of the color keys.
 bool ImageObject::filterColorKey ( QColor *pColor, QValueList<QColor *> *pListColorMin, QValueList<QColor *>*pListColorMax )
 {
-	int iRed, iGreen, iBlue, t, iColorKeyCount;
-	iColorKeyCount = manipulator().listColorKeys.count ();
-	if ( ( iColorKeyCount < 1 ) || ( ! pListColorMin ) || ( ! pListColorMax ) )
-		return false;
-	iRed = pColor->red(); iGreen = pColor->green(); iBlue = pColor->blue ();
-	for (t=0;t<iColorKeyCount;t++)	{
-//printf ("RGB<%02x%02x%02x> MIN<%02x%02x%02x> MAX<%02x%02x%02x> - ", iRed, iGreen, iBlue, (*pListColorMin)[t]->red  (), (*pListColorMin)[t]->green  (), (*pListColorMin)[t]->blue  (), (*pListColorMax)[t]->red(),(*pListColorMax)[t]->green(), (*pListColorMax)[t]->blue());
-		if (	(iRed   >= (*pListColorMin)[t]->red  () && iRed   <= (*pListColorMax)[t]->red  ()) && 
-			(iGreen >= (*pListColorMin)[t]->green() && iGreen <= (*pListColorMax)[t]->green()) &&
-			(iBlue  >= (*pListColorMin)[t]->blue () && iBlue  <= (*pListColorMax)[t]->blue ()) )
-			return true;
-	}
-	return false;
+  int iRed, iGreen, iBlue, t, iColorKeyCount;
+  iColorKeyCount = manipulator().listColorKeys.count ();
+  if ( ( iColorKeyCount < 1 ) || ( ! pListColorMin ) || ( ! pListColorMax ) )
+    return false;
+
+  // If image is rotated then pitch balck ought to be removed ...
+  if ( ( ( modifiers ( )->fShearX != 0.0 ) || 
+	 ( modifiers ( )->fShearX != 0.0 ) || 
+	 ( modifiers ( )->fRotate != 0.0 ) ) && 
+       ( *pColor == QColor ( 0, 0, 0 ) ) )
+    return true;
+
+  iRed = pColor->red(); iGreen = pColor->green(); iBlue = pColor->blue ();
+  for (t=0;t<iColorKeyCount;t++)	{
+    if ( (iRed   >= (*pListColorMin)[t]->red  () && iRed   <= (*pListColorMax)[t]->red  ()) && 
+	 (iGreen >= (*pListColorMin)[t]->green() && iGreen <= (*pListColorMax)[t]->green()) &&
+	 (iBlue  >= (*pListColorMin)[t]->blue () && iBlue  <= (*pListColorMax)[t]->blue ()) )
+      return true;
+  }
+  return false;
 }
 
 void ImageObject::updatePixmap()
@@ -310,6 +327,49 @@ void ImageObject::updatePixmap()
 	QImage theImage(fileName());
 	if (theImage.isNull())
 		return;
+
+	// the kenBurns is taken care of here ...
+	if ( ( manipulator().fKenBurnsX1 > -1.0 ) || ( manipulator().fKenBurnsY1 > -1.0 ) ) {
+	  float fKen[4];
+	  int   iKen[4];
+	  // if X2 and Y2 from manipulator is -1 then we go all the way to the max ext of the image
+	  fKen[0] = manipulator ( ).fKenBurnsX1;
+	  fKen[1] = manipulator ( ).fKenBurnsY1;
+	  fKen[2] = manipulator ( ).fKenBurnsX2;
+	  fKen[3] = manipulator ( ).fKenBurnsY2;
+	  iKen[0] = 0;
+	  iKen[1] = 0;
+	  iKen[2] = theImage.width  ( );
+	  iKen[3] = theImage.height ( );
+	  
+	  if ( fKen[0] > fKen[2] ) {
+	       fKen[0] = fKen[2];
+               fKen[2] = manipulator ( ).fKenBurnsX1;
+	  }
+	  if ( fKen[1] > fKen[3] ) {
+  	       fKen[1] = fKen[3];
+               fKen[3] = manipulator ( ).fKenBurnsY1;
+	  }
+	  if ( fKen[2] < 0.0 )
+               fKen[2] = 1.0;
+	  if ( fKen[3] < 0.0 )
+               fKen[3] = 1.0;
+	  iKen[0] = (int)(   fKen[0] * iKen[2] );
+	  iKen[1] = (int)(   fKen[1] * iKen[3] );
+	  iKen[2] = (int)( ( fKen[2] - fKen[0] ) * iKen[2] );
+	  iKen[3] = (int)( ( fKen[3] - fKen[1] ) * iKen[3] );
+	  if ( iKen[0] > theImage.width ( ) )
+	       iKen[0] = 0;
+	  if ( iKen[1] > theImage.height  ( ) )
+	       iKen[1] = 0;
+	  if ( iKen[0] + iKen[2] > theImage.width  ( ) )
+	       iKen[2] = theImage.width  ( ) - iKen[0];
+	  if ( iKen[1] + iKen[3] > theImage.height ( ) )
+	       iKen[3] = theImage.height ( ) - iKen[1];
+	  
+	  theImage = theImage.copy ( iKen[0], iKen[1], iKen[2], iKen[3] );
+	}
+
 	theImage = theImage.smoothScale ( rect ().width(), rect().height(), QImage::ScaleFree);
 
 	centerPos.setX (rect().x() + (int)((float)rect().width () / 2.0));
@@ -317,8 +377,8 @@ void ImageObject::updatePixmap()
 	// First we translate to the appropriate location,
 	theMatrix.translate ((double)centerPos.x(), (double)centerPos.y());
 	// then we apply the other modifications ...
-	theMatrix.scale  (modifiers()->fScaleX, modifiers()->fScaleY);
-//	theMatrix.scale  (manipulator().fZoom, manipulator().fZoom);
+	theMatrix.scale  ( manipulator ( ).fScaleX, manipulator ( ).fScaleY );
+
 	// Here we create the scaled image ...
 	theImage = theImage.xForm ( theMatrix );
 
@@ -334,16 +394,16 @@ void ImageObject::updatePixmap()
 	}
 	for (y=0;y<theImage.height();y++)	{
 		for (x=0;x<theImage.width();x++)	{
-			thePix = theImage.pixel(x, y);
-			iRed = (int)((float)qRed(thePix) * manipulator().fRed);
-			iBlue = (int)((float)qBlue(thePix) * manipulator().fBlue);
-			iGreen = (int)((float)qGreen(thePix) * manipulator().fGreen);
+			thePix = theImage.pixel ( x, y );
+			iRed   = (int)((float)qRed  (thePix) * manipulator ( ).fRed   );
+			iBlue  = (int)((float)qBlue (thePix) * manipulator ( ).fBlue  );
+			iGreen = (int)((float)qGreen(thePix) * manipulator ( ).fGreen );
 
 			theColor = QColor (iRed, iGreen, iBlue);
 			if (bLighter)
-				theColor = theColor.light ((int)fAdjust);
+				theColor = theColor.light ( (int)fAdjust );
 			else
-				theColor = theColor.dark ((int)fAdjust);
+				theColor = theColor.dark  ( (int)fAdjust );
 			// This test is to mask out the transparency color (0, 0, 0)
 			if (theColor == QColor (0,0,0))
 				theColor = QColor (0,0,1);
@@ -397,24 +457,40 @@ bool ImageObject::writeProjectFile (QDomElement &theElement)
 	return MenuObject::writeProjectFile( imageNode );
 }
 
-void ImageObject::createStructure (QListViewItem *pParentItem)
+void ImageObject::resetStructureItem( )
 {
-	StructureItem *pButtonItem;
-	QFileInfo fileInfo(m_qsFileName);
-	QString qsName;
+  if ( m_pStructureItem )
+    delete m_pStructureItem;
+  m_pStructureItem = NULL;
+  manipulator ( ).m_pStructureItem = NULL;
+}
+
+StructureItem *ImageObject::createStructure ( StructureItem *pParentItem )
+{
+  StructureItem *pTemp=NULL;
+  QFileInfo fileInfo ( m_qsFileName );
+  QString qsName;
 	
-	qsName = QString ("Image Object");
+  qsName = tr( "Image Object" );
 
-	pButtonItem = new StructureItem(this, pParentItem, qsName, fileInfo.fileName());
-	pButtonItem->setExpandable (TRUE);
+  if ( ! m_pStructureItem ) {
+    m_pStructureItem = new StructureItem ( this, pParentItem, pParentItem->lastChild ( ), qsName, fileInfo.fileName ( ) );
+    m_pStructureItem->setExpandable      ( TRUE );
+  }
 
-	manipulator ().createStructure (pButtonItem);
-	if ( m_pShadow )
-	     m_pShadow->createStructure ( pButtonItem );
+  //  pTemp = (StructureItem *)m_pStructureItem->firstChild ( );
+  //  if ( pTemp ) printf ( "ImageObject : <%s>\n", pTemp->text ( 0 ).ascii() );
+  //  else         printf ( "ImageObject : No First for <%s>.\n", fileInfo.fileName().ascii() );
 
-	new StructureItem(this, pButtonItem, QString ("Geometry"),
-		QString ("%1, %2, %3, %4").
-		arg(rect().x()).arg(rect().y()).arg(rect().width()).arg(rect().height()));
+  pTemp = m_pStructureItem->setSibling ( this, NULL, tr ( "Geometry" ), QString ( "%1, %2, %3, %4" ).
+       	         arg ( rect().x()).arg(rect().y()).arg(rect().width()).arg(rect().height()) );
+
+  if ( m_pShadow )
+    pTemp = m_pShadow->createStructure ( m_pStructureItem );
+  
+  manipulator ( ).createStructure ( m_pStructureItem, pTemp );
+
+  return m_pStructureItem;
 }
 
 bool ImageObject::mousePressEvent (QMouseEvent *pEvent)
@@ -441,44 +517,57 @@ bool ImageObject::mouseReleaseEvent (QMouseEvent *)
 
 bool ImageObject::mouseDoubleClickEvent (QMouseEvent *)
 {
-	// Back to the MenuPreview - class, where I can handle this request ...
-	emit (signalModifyMe(this));
-	return false;
+  // Back to the MenuPreview - class, where I can handle this request ...
+  emit ( signalModifyMe ( this ) );
+  return false;
 }
 
 bool ImageObject::createContextMenu ( QPoint globalPos )
 {
-	QPoint globalPos2 = globalPos;
-	QPopupMenu *pStackMenu = new QPopupMenu(m_pParent);
-	pStackMenu->insertItem ( tr ("To Front")  , this, SLOT(slotToFront()));
-	pStackMenu->insertItem ( tr ("To Back")   , this, SLOT(slotToBack()));
-	globalPos.setX (globalPos.x() - pStackMenu->sizeHint().width()); // -100);
-	pStackMenu->popup(globalPos, 1);
+  QString qsShadow;
+  QPoint globalPos2 = globalPos;
+  QPopupMenu *pStackMenu = new QPopupMenu(m_pParent);
+  pStackMenu->insertItem ( tr ("Cut") , this, SLOT ( slotCut  ( ) ) );
+  pStackMenu->insertItem ( tr ("Copy"), this, SLOT ( slotCopy ( ) ) );
+  pStackMenu->insertSeparator ( );
+  pStackMenu->insertItem ( tr ("To Front")  , this, SLOT(slotToFront()));
+  pStackMenu->insertItem ( tr ("To Back")   , this, SLOT(slotToBack()));
+  globalPos.setY ( globalPos.y ( ) - 25 );
+  globalPos.setX ( globalPos.x ( ) - pStackMenu->sizeHint().width()); // -100);
+  pStackMenu->popup ( globalPos, 1 );
 
-	if (m_pContextMenu)
-		delete m_pContextMenu;
-	m_pContextMenu = new QPopupMenu(m_pParent);
-	m_pContextMenu->insertItem ( tr ("Edit ...")      , this, SLOT(slotEdit      ( ) ) );
-	m_pContextMenu->insertItem ( tr ("Properties ..."), this, SLOT(slotProperties( ) ) );
-	m_pContextMenu->insertItem ( tr ("Matrix ...")    , this, SLOT(slotMatrix    ( ) ) );
-	m_pContextMenu->insertItem ( tr ("Delete")        , this, SLOT(slotDelete    ( ) ) );
-	m_pContextMenu->insertSeparator();
-	m_pContextMenu->insertItem ( tr ("Rotate 90")     , this, SLOT(slotRotate90  ( ) ) );
-	m_pContextMenu->insertItem ( tr ("Rotate 180")    , this, SLOT(slotRotate180 ( ) ) );
-	m_pContextMenu->insertItem ( tr ("Rotate 270")    , this, SLOT(slotRotate270 ( ) ) );
-	m_pContextMenu->insertSeparator();
-	m_pContextMenu->insertItem ( tr ("Add Shadow")    , this, SLOT(slotAddShadow ( ) ) );
-	m_pContextMenu->insertItem ( tr ("Add Frame")     , this, SLOT(slotAddFrame  ( ) ) );
-	m_pContextMenu->insertItem ( tr ("Add Text")      , this, SLOT(slotAddText   ( ) ) );
-	m_pContextMenu->insertSeparator();
-	m_pContextMenu->insertItem ( tr ("Define as Button") , this, SLOT(slotDefineAsButton()));
-	// Blocking call.
-	m_pContextMenu->exec(globalPos2, 6);
-	delete pStackMenu;
-	if (m_pContextMenu)
-		delete m_pContextMenu;
-	m_pContextMenu = NULL;
-	return true;
+  qsShadow   = tr ( "Add Shadow ..."  );
+  if ( shadow ( ) )
+    qsShadow = tr ( "Edit Shadow ..." );
+  
+  if ( m_pContextMenu )
+    delete m_pContextMenu;
+  m_pContextMenu = new QPopupMenu ( m_pParent );
+  m_pContextMenu->setCheckable ( true );
+  m_pContextMenu->insertItem ( tr ("Edit ..." )      , this, SLOT ( slotEdit      ( ) ) );
+  m_pContextMenu->insertItem ( tr ("Properties ...") , this, SLOT ( slotProperties( ) ) );
+  m_pContextMenu->insertItem ( tr ("Matrix ...")     , this, SLOT ( slotMatrix    ( ) ) );
+  m_pContextMenu->insertItem ( tr ("Delete")         , this, SLOT ( slotDelete    ( ) ) );
+  m_pContextMenu->insertSeparator ( );
+  m_pContextMenu->insertItem ( tr ("Rotate 90")      , this, SLOT ( slotRotate90  ( ) ) );
+  m_pContextMenu->insertItem ( tr ("Rotate 180")     , this, SLOT ( slotRotate180 ( ) ) );
+  m_pContextMenu->insertItem ( tr ("Rotate 270")     , this, SLOT ( slotRotate270 ( ) ) );
+  m_pContextMenu->insertSeparator ( );
+  m_pContextMenu->insertItem ( qsShadow              , this, SLOT ( slotAddShadow ( ) ) );
+  if ( shadow ( ) )
+    m_pContextMenu->insertItem ( tr ("Delete Shadow"), this, SLOT(slotDeleteShadow ( ) ) );
+
+  //	m_pContextMenu->insertItem ( tr ("Add Frame")      , this, SLOT ( slotAddFrame  ( ) ) );
+  //	m_pContextMenu->insertItem ( tr ("Add Text")       , this, SLOT ( slotAddText   ( ) ) );
+  m_pContextMenu->insertSeparator ( );
+  m_pContextMenu->insertItem ( tr ("Define as Button"), this, SLOT(slotDefineAsButton()));
+  // Blocking call.
+  m_pContextMenu->exec(globalPos2, 6);
+  delete pStackMenu;
+  if ( m_pContextMenu )
+    delete m_pContextMenu;
+  m_pContextMenu = NULL;
+  return true;
 }
 
 bool ImageObject::mouseMoveEvent (QMouseEvent *pEvent)
@@ -540,66 +629,52 @@ void ImageObject::slotEdit()
 
 void ImageObject::slotProperties()
 {
-	ImageManipulator *pMan= &manipulator();
-	DialogGeometry *pGeometry = new DialogGeometry ();
-	pGeometry->initMe(rect(), pMan);
+  ImageManipulator *pMan= &manipulator();
 
-	connect ( pGeometry->m_pButtonAnimation, SIGNAL(clicked()), this, SLOT(slotAnimation()) );
+  DialogGeometry *pGeometry = new DialogGeometry ();
+  pGeometry->initMe(rect(), pMan);
+  connect ( pGeometry->m_pButtonAnimation, SIGNAL(clicked()), this, SLOT(slotAnimateMe ( ) ) );
 	
-	if (pGeometry->exec() == QDialog::Accepted)	{
-		int iX, iY, iWidth, iHeight;
-		iX      = pGeometry->m_pEditX->text().toInt();
-		iY      = pGeometry->m_pEditY->text().toInt();
-		iWidth  = pGeometry->m_pEditWidth ->text().toInt();
-		iHeight = pGeometry->m_pEditHeight->text().toInt();
-		QRect rect (iX, iY, iWidth, iHeight);
+  if (pGeometry->exec() == QDialog::Accepted)	{
+    int iX, iY, iWidth, iHeight;
+    iX      = pGeometry->m_pEditX->text().toInt();
+    iY      = pGeometry->m_pEditY->text().toInt();
+    iWidth  = pGeometry->m_pEditWidth ->text().toInt();
+    iHeight = pGeometry->m_pEditHeight->text().toInt();
+    QRect rect (iX, iY, iWidth, iHeight);
 		
-		ImageManipulator::colorKeying *pColorKey;
-		ListViewColorItem *pItem;
-		uint t;
-		float  fDelta;
-		QColor theColor;
-
-		// First we should remove all entries in the color Key
-		for (t=0;t<pMan->listColorKeys.count();t++)
-			delete pMan->listColorKeys[t];
-		pMan->listColorKeys.clear();
-		// And then we add whats currently in the widget.
-		if ( pGeometry->m_pListViewCK->childCount() )	{
-			pItem = (ListViewColorItem *)pGeometry->m_pListViewCK->firstChild ();
-			while (pItem)	{
-				theColor.setNamedColor (pItem->text (0));	// The Color nam is stored in the first text
-				fDelta = pItem->text(1).toFloat();		// The delta value is stored in the second column.
-				pColorKey = new ImageManipulator::colorKeying ( theColor.rgb(), fDelta );
-				pMan->listColorKeys.append ( pColorKey );
-				pItem = (ListViewColorItem *)pItem->itemBelow ();
-			}
-		}
-		setRect (rect);
-		updatePixmap ( );
-		updateShadow ( );
-		emit (signalUpdatePixmap());
-	}
-	delete pGeometry;
+    ImageManipulator::colorKeying *pColorKey;
+    ListViewColorItem *pItem;
+    uint t;
+    float  fDelta;
+    Rgba   theColor;
+    
+    // First we should remove all entries in the color Key
+    for ( t=0; t<pMan->listColorKeys.count ( ); t++ )
+      delete pMan->listColorKeys[t];
+    pMan->listColorKeys.clear ( );
+    // And then we add whats currently in the widget.
+    if ( pGeometry->m_pListViewCK->childCount ( ) )	{
+      pItem = (ListViewColorItem *)pGeometry->m_pListViewCK->firstChild ( );
+      while (pItem)	{
+	theColor.fromString ( pItem->text ( 0 ) );	// The Color name is stored in the first text
+	fDelta = pItem->text ( 1 ).toFloat ( );		// The delta value is stored in the second column.
+	pColorKey = new ImageManipulator::colorKeying ( theColor.rgb ( ), fDelta );
+	pMan->listColorKeys.append ( pColorKey );
+	pItem = (ListViewColorItem *)pItem->itemBelow ();
+      }
+    }
+    setRect ( rect );
+    updatePixmap ( );
+    updateShadow ( );
+    emit ( signalUpdatePixmap ( ) );
+  }
+  delete pGeometry;
 }
 
-void ImageObject::slotAnimation ()
+void ImageObject::slotAnimateMe ( )
 {
-	// This function gets the Animation Dialog
-	// Within this dialog, you can create a script
-	// (or hardcode) Attributes of the object.
-	// Before rendering the menu the script will 
-	// get executed and all data sent to stdout 
-	// will be captured in the data file, wich 
-	// will provide the data for the animation.
-	QString qsEmpty;
-	DialogAnimation dialog;
-	dialog.initMe ( animation(), 300, 25.0, DialogAnimation::TypeImage );
-	if ( dialog.exec () == QDialog::Accepted )
-		setAnimation ( dialog.string () );
-
-	if (animation().length () < 5)
-		setAnimation ( qsEmpty );
+  animationDialog ( animation ( ), DialogAnimation::TypeImage );
 }
 
 void ImageObject::slotRotate90()
@@ -650,73 +725,90 @@ void ImageObject::slotAddText()
 		QMessageBox::Ok ,  QMessageBox::Cancel);
 }
 
-void ImageObject::slotDefineAsButton()
+void ImageObject::slotDefineAsButton ( )
 {
-	emit ( signalDefineAsButton ( this ) );
+  emit ( signalDefineAsButton ( this ) );
 }
 
-MenuObject *ImageObject::clone()
+MenuObject *ImageObject::clone ( QWidget *pParent, MenuObject * )
 {
-	ImageObject *pNewObject = new ImageObject (MenuObject::parent());
-	pNewObject->setPixmap(pixmap());
-	pNewObject->setFile (fileName());
-	pNewObject->setZoom (zoom());
-	// The following two are not really needed, since we get those
-	// informations solely from the Normal State - objects ...
-	pNewObject->setRect(rect());
-	pNewObject->setManipulator(manipulator());
+  if ( !pParent )
+    pParent = MenuObject::parent ( );
+  ImageObject *pNewObject = new ImageObject ( pParent );
+  pNewObject->setPixmap ( pixmap   ( ) );
+  pNewObject->setFile   ( fileName ( ) );
+  pNewObject->setZoom   ( zoom     ( ) );
+  // The following two are not really needed, since we get those
+  // informations solely from the Normal State - objects ...
+  pNewObject->setRect        ( rect        ( ) );
+  pNewObject->setManipulator ( manipulator ( ) );
+  pNewObject->setAnimation   ( animation   ( ) );
 
-	MenuObject *pShadow = shadow ( );
-	if ( pShadow )
-	  pShadow = pShadow->clone ( pNewObject );
-	pNewObject->setShadow      (  pShadow   );
-
-	return pNewObject;
+  MenuObject *pShadow = shadow ( );
+  if ( pShadow )
+    pShadow = pShadow->clone ( pParent, pNewObject );
+  pNewObject->setShadow ( pShadow );
+  
+  return pNewObject;
 }
 
 // Called from xyz, when creating the AnimationAttribute objects, which hold the list of values for the attribute to be set.
 // Note: only those AnimationAttribute objects are created which are modified during the animation (Menu - video).
 AnimationAttribute *ImageObject::getSpecificAttributes (long iMaxNumberOfFrames, QString qsProperty)
 {
-	AnimationAttribute *pAnimAttr = NULL;
+  AnimationAttribute *pAnimAttr = NULL;
 
-	if (qsProperty == "zoom")
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fZoom, &m_imageManipulator.fZoom);
-	else if (qsProperty == "rotate")
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fRotate, &m_imageManipulator.fRotate);
-	else if (qsProperty == "shear.x")
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fShearX, &m_imageManipulator.fShearX);
-	else if (qsProperty == "shear.y")
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fShearY, &m_imageManipulator.fShearY);
-	else if (qsProperty == "scale.x")
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fScaleX, &m_imageManipulator.fScaleX);
-	else if (qsProperty == "scale.y")
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fScaleY, &m_imageManipulator.fScaleY);
-	else if (qsProperty == "transparency")
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fTransparency, &m_imageManipulator.fTransparency);
-	else if (qsProperty == "backgroundFileName")
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.backgroundFileName, &m_imageManipulator.backgroundFileName);
-	else if (qsProperty == "showBackground")
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.bShowBackground, &m_imageManipulator.bShowBackground);
-	else if (qsProperty == "startPos.x")
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fStartX, &m_imageManipulator.fStartX);
-	else if (qsProperty == "startPos.y")
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fStartY, &m_imageManipulator.fStartY);
-	else if (qsProperty == "res.x")
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.iXRes, &m_imageManipulator.iXRes);
-	else if (qsProperty == "res.y")
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.iYRes, &m_imageManipulator.iYRes);
-	else if (qsProperty == "aspectRatio")
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fAspectRatio, &m_imageManipulator.fAspectRatio);
-	else if (qsProperty == "blendColor.red")
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fRed, &m_imageManipulator.fRed);
-	else if (qsProperty == "blendColor.green")
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fGreen, &m_imageManipulator.fGreen);
-	else if (qsProperty == "blendColor.blue")
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fBlue, &m_imageManipulator.fBlue);
-	else if (qsProperty == "brightness")
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fBrightness, &m_imageManipulator.fBrightness);
+  if (qsProperty == "zoom")
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fZoom, &m_imageManipulator.fZoom);
+  else if (qsProperty == "rotate")
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fRotate, &m_imageManipulator.fRotate);
+  else if (qsProperty == "shear.x")
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fShearX, &m_imageManipulator.fShearX);
+  else if (qsProperty == "shear.y")
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fShearY, &m_imageManipulator.fShearY);
+  else if (qsProperty == "scale.x")
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fScaleX, &m_imageManipulator.fScaleX);
+  else if (qsProperty == "scale.y")
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fScaleY, &m_imageManipulator.fScaleY);
+  else if (qsProperty == "transparency")
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fTransparency, &m_imageManipulator.fTransparency);
+  else if (qsProperty == "visibleFromTo.startFrame") {
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.iStartFrame, &m_imageManipulator.iStartFrame);
+    pAnimAttr->setNeedRefresh ( false );
+  }
+  else if (qsProperty == "visibleFromTo.stopFrame") {
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.iStopFrame, &m_imageManipulator.iStopFrame);
+    pAnimAttr->setNeedRefresh ( false );
+  }
+  //	else if (qsProperty == "backgroundFileName")
+  //		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.backgroundFileName, &m_imageManipulator.backgroundFileName);
+  //	else if (qsProperty == "showBackground")
+  //		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.bShowBackground, &m_imageManipulator.bShowBackground);
+  else if (qsProperty == "kenBurns.x1")
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fKenBurnsX1, &m_imageManipulator.fKenBurnsX1);
+  else if (qsProperty == "kenBurns.y1")
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fKenBurnsY1, &m_imageManipulator.fKenBurnsY1);
+  else if (qsProperty == "kenBurns.x2")
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fKenBurnsX2, &m_imageManipulator.fKenBurnsX2);
+  else if (qsProperty == "kenBurns.y2")
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fKenBurnsY2, &m_imageManipulator.fKenBurnsY2);
+  //	else if (qsProperty == "res.x")
+  //		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.iXRes, &m_imageManipulator.iXRes);
+  //	else if (qsProperty == "res.y")
+  //		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.iYRes, &m_imageManipulator.iYRes);
+  //	else if (qsProperty == "aspectRatio")
+  //		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fAspectRatio, &m_imageManipulator.fAspectRatio);
+  else if (qsProperty == "blendColor.red")
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fRed, &m_imageManipulator.fRed);
+  else if (qsProperty == "blendColor.green")
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fGreen, &m_imageManipulator.fGreen);
+  else if (qsProperty == "blendColor.blue")
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fBlue, &m_imageManipulator.fBlue);
+  else if (qsProperty == "brightness")
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fBrightness, &m_imageManipulator.fBrightness);
+  else if (qsProperty == "fileName")
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_qsFileName, &m_qsFileName);
 
-	return pAnimAttr;
+  return pAnimAttr;
 }
 
