@@ -1,8 +1,10 @@
 /****************************************************************************
 ** Interface to the GUI.
 **
-** Created: Sun Feb 23 21:45:00 2004
-**      by: Varol Okan using kate editor
+**   Created : Sun Feb 23 21:45:00 2004
+**        by : Varol Okan using kate editor
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 **  pure virtual class as base for the three button types.
 **
@@ -12,13 +14,13 @@
 #define IMAGEOBJECT_H
 
 #include <qpixmap.h>
-#include "qslideshow/xml_slideshow.h"
 #include "menuobject.h"
 
 
 class ImageObject : public MenuObject
 {
 	Q_OBJECT
+
 public:
 	// Public functions needed for the abstract base class.
 	ImageObject (QWidget *pParent = 0);
@@ -32,23 +34,24 @@ public:
 
 	virtual bool readProjectFile       ( QDomNode &     );
 	virtual bool writeProjectFile      ( QDomElement &  );
-	virtual void createStructure       ( QListViewItem *);
 	virtual bool createContextMenu     ( QPoint         );
-	virtual MenuObject *clone();
+	virtual StructureItem *createStructure ( StructureItem * );
+	virtual MenuObject    *clone       ( QWidget *p1=NULL, MenuObject *p2=NULL );
 
 public:
 	// Further public functions not dervied from the base class.
-	virtual void setPixmap        ( QPixmap & );
-	virtual void updatePixmap     ( );
-	virtual void setManipulator   ( ImageManipulator & );
-	virtual void setModifiers     ( Modifiers & );
-	void setFile                  ( QString );
-	void setZoom                  ( float );
-	QPixmap &pixmap               ( );
-	QString &fileName             ( );
-	float    zoom                 ( );
-	virtual Modifiers *modifiers  ( );
-	ImageManipulator &manipulator ( );
+	virtual void setPixmap         ( QPixmap & );
+	virtual void updatePixmap      ( );
+	virtual void setManipulator    ( ImageManipulator & );
+	virtual void setModifiers      ( Modifiers & );
+	virtual void setFile           ( QString );
+	void setZoom                   ( float );
+	QPixmap &pixmap                ( );
+	QString &fileName              ( );
+	float    zoom                  ( );
+	virtual Modifiers *modifiers   ( );
+	ImageManipulator &manipulator  ( );
+	virtual void resetStructureItem( );
 
 signals:
 	void signalModifyMe ( MenuObject * );
@@ -58,17 +61,19 @@ protected:
 	bool filterColorKey ( QColor *, QValueList<QColor *>*, QValueList<QColor *>*);
 	void rotate (float);
 
+public slots:
+	virtual void slotProperties     ( );
+
 protected slots:
-	virtual void slotEdit          ();
-	virtual void slotProperties    ();
-	virtual void slotRotate90      ();
-	virtual void slotRotate180     ();
-	virtual void slotRotate270     ();
-	virtual void slotMatrix        ();
-	virtual void slotAddFrame      ();
-	virtual void slotAddText       ();
-	virtual void slotAnimation     ();
-	virtual void slotDefineAsButton();
+	virtual void slotEdit           ( );
+	virtual void slotRotate90       ( );
+	virtual void slotRotate180      ( );
+	virtual void slotRotate270      ( );
+	virtual void slotMatrix         ( );
+	virtual void slotAddFrame       ( );
+	virtual void slotAddText        ( );
+	virtual void slotDefineAsButton ( );
+	virtual void slotAnimateMe      ( );
 
 protected:
 	QString m_qsFileName;
