@@ -1,10 +1,16 @@
-
+/***********************************************************
+  **
+  **   Created : 
+  **        by : Varol Okan
+  ** Copyright : (c) Varol Okan
+  **   License : GPL v 2.0
+  **
+  *********************************************************/
 #include <qmessagebox.h>
 #include <qstringlist.h>
 #include <qfiledialog.h>
 #include <qfileinfo.h>
-//#include <qobject.h>
-
+#include <qimage.h>
 
 #include "global.h"
 #include "dvdmenu.h"
@@ -18,7 +24,6 @@
 #include "importdvdauthor.h"
 #include "sourcefileentry.h"
 
-
 namespace Import
 {
 
@@ -92,7 +97,7 @@ bool DVDAuthor::import ( )
 				 arg(listOfFailures.count()).arg( listOfFailures.join ("\n").arg ((listOfFailures.count() > 1) ? "s" : "") ), QMessageBox::Ok, QMessageBox::NoButton);
 
     iResponse = QMessageBox::information ( NULL, "Information", QObject::tr("Reading %1 spumux-xml files Was %2 succesfull.\nDo you want to load more spumux files ?").
-					   arg(listFileNames.count()).arg( bSuccess ? "" : "NOT"), QMessageBox::Yes, QMessageBox::No);
+        arg(listFileNames.count()).arg( bSuccess ? "" : "NOT"), QMessageBox::Yes, QMessageBox::No);
   }
 
   bReturn = buildFromDVDAuthorXML ( &theXmlStructure, spumuxList );
@@ -150,6 +155,9 @@ QValueList <SourceFileEntry *> DVDAuthor::takeSourceFileEntries ()
 ////////////////////////////////////////////////////////////
 bool DVDAuthor::buildFromDVDAuthorXML ( CXmlDVDAuthor *pDVDAuthor, QValueList<CXmlSpumux *> &spumuxList )
 {
+  if ( ! pDVDAuthor )
+    return false;
+
   uint t;
   int  iTitleset = 0;
   // First things first ...
@@ -171,18 +179,30 @@ bool DVDAuthor::buildFromDVDAuthorXML ( CXmlDVDAuthor *pDVDAuthor, QValueList<CX
   // At this point we should have build a list of DVDMenu - objects 
   // and should be ready to parse the spumux files to assign some missing attributes
   for ( t=0;t<spumuxList.count();t++) {
-    if ( ! buildFromSpumuxXML ( spumuxList[t] ) )
-      return false;
+    if ( ! buildFromSpumuxXML ( spumuxList[t] ) ) ;
+    //      return false;
   }
 
+  // The last step we check all buttons to make sure they do have a vald rect. 
+  // If not we will position them so that they are at least visible
+  validateButtons ( m_pVMGMenu );
+  for ( t=0; t<m_listDVDMenus.count ( ); t++ )
+    validateButtons ( m_listDVDMenus[t] );
+
   // Stick a fork in me, I am done !
   return true;
 }
 
 bool DVDAuthor::buildFromVMGM ( CXmlDVDAuthor::vmgm_struct *pXMLVMGM )
 {
+  if ( ! pXMLVMGM )
+    return false;
+
   int iMenu  = 0;
+
+  // Here we create a new VMGMenu to be used.
   m_pVMGMenu = new VMGMenu ( m_pDVDAuthor );
+
   // NOTE: Need to check if there are really only Menus and no Titles in VMGM.
   if ( ! pXMLVMGM->ppArrayMenus )
     return true;
@@ -194,7 +214,7 @@ bool DVDAuthor::buildFromVMGM ( CXmlDVDAuthor::vmgm_struct *pXMLVMGM )
     return false;
   
   while ( pXMLVMGM->ppArrayMenus[ iMenu ] ) {
-    if ( ! buildFromMenus ( pXMLVMGM->ppArrayMenus[ iMenu++ ] ) )
+    if  ( ! buildFromMenus ( pXMLVMGM->ppArrayMenus[ iMenu++ ] ) )
       return false;
   }
 
@@ -204,6 +224,9 @@ bool DVDAuthor::buildFromVMGM ( CXmlDVDAuthor::vmgm_struct *pXMLVMGM )
 
 bool DVDAuthor::buildFromTitleset ( CXmlDVDAuthor::titleset_struct *pXMLTitleset )
 {
+  if ( ! pXMLTitleset )
+    return false;
+
   int iMenu  = 0;
   int iTitle = 0;
   // Note, I believe the DVDSpec allows only for one Menus and one Titles - tag
@@ -230,6 +253,8 @@ bool DVDAuthor::buildFromTitleset ( CXmlDVDAuthor::titleset_struct *pXMLTitleset
 bool DVDAuthor::buildFromMenus ( CXmlDVDAuthor::menus_struct *pXMLMenu, VMGMenu *pVMGMenu )
 {
   int iPgc = 0;
+  if ( ! pXMLMenu )
+    return false;
 
   if ( ! pXMLMenu->ppArrayPgc )
     return true;
@@ -243,10 +268,14 @@ bool DVDAuthor::buildFromMenus ( CXmlDVDAuthor::menus_struct *pXMLMenu, VMGMenu
 
 bool DVDAuthor::buildMenuFromPgc ( CXmlDVDAuthor::pgc_struct *pPgc, VMGMenu *pVMGMenu )
 {
+  if ( ! pPgc )
+    return false;
+  
   int iVob    = 0;
   int iButton = 0;
   DVDMenu *pDVDMenu = pVMGMenu;
   CDVDMenuInterface *pInterface;
+  QString qsMenuName;
 
   // For now we simply disregard menus with no videos. This way we break the reconstruction
   // But we can visit this area at a later point again. 2005/10/23
@@ -255,7 +284,9 @@ bool DVDAuthor::buildMenuFromPgc ( CXmlDVDAuthor::pgc_struct *pPgc, VMGMenu *pVM
 
   if ( ! pDVDMenu ) {
     pDVDMenu = new DVDMenu ( m_pDVDAuthor );
-    m_listDVDMenus.append ( pDVDMenu );
+    m_listDVDMenus.append  ( pDVDMenu );
+    qsMenuName = QString   ( "Import %1" ).arg ( m_listDVDMenus.count ( ) );
+    pDVDMenu->getInterface ( )->qsMenuName = qsMenuName;
   }
   pInterface = pDVDMenu->getInterface ();
 
@@ -275,7 +306,7 @@ bool DVDAuthor::buildMenuFromPgc ( CXmlDVDAuthor::pgc_struct *pPgc, VMGMenu *pVM
     delete pPgc->ppArrayVob [ iVob ];
 
     // we should remove the VOBs array but keep the VOBs itself in memory,
-    // as we have just transfered them the the DVDMenu - object.
+    // as we have just transferred them to the DVDMenu - object.
     delete []pPgc->ppArrayVob;
     pPgc->ppArrayVob = NULL;
   } 
@@ -283,8 +314,13 @@ bool DVDAuthor::buildMenuFromPgc ( CXmlDVDAuthor::pgc_struct *pPgc, VMGMenu *pVM
   // now let us take care of the buttons ...
   if ( pPgc->ppArrayButton ) {
     while ( pPgc->ppArrayButton[ iButton ] ) {
-      if ( ! buildButtonFromPgc ( pPgc->ppArrayButton[ iButton++ ], pDVDMenu ) )
-	return false;
+      CXmlDVDAuthor::button_struct *pXMLButton = pPgc->ppArrayButton[ iButton++ ];
+      if ( pXMLButton ) {
+	if ( pXMLButton->name.isEmpty ( ) )
+	  pXMLButton->name  = QString ( "Button %1" ).arg ( iButton );
+	if ( ! buildButtonFromPgc ( pXMLButton, pDVDMenu ) )
+	  return false;
+      }
     }
   }
 
@@ -293,34 +329,36 @@ bool DVDAuthor::buildMenuFromPgc ( CXmlDVDAuthor::pgc_struct *pPgc, VMGMenu *pVM
 
 bool DVDAuthor::buildButtonFromPgc ( CXmlDVDAuthor::button_struct *pXMLButton, DVDMenu *pDVDMenu )
 {
+  if ( ( ! pDVDMenu ) || ( ! pXMLButton ) )
+    return false;
+
   QColor colorRed ( 255,  40,  40), colorBlue(  40, 40, 255 );
   TextObject   *pNewText;
   ButtonObject *pNewButton;
-  MenuPreview  *pPreview = pDVDMenu->getMenuPreview();
+  MenuPreview  *pPreview = pDVDMenu->getMenuPreview ( );
   if ( ! pPreview )
     return false;
 
-  pNewButton = (ButtonObject *)pPreview->createButtonObject ( false );
-  pNewText   = (TextObject *)  pPreview->createTextObject   ( false );
+  pNewText   = (TextObject *)pPreview->createTextObject ( false );
   pNewText->setForegroundColor ( colorRed  );
   pNewText->setForegroundColor ( colorBlue );
+
+  pNewButton = pPreview->defineAsButton ( pNewText, false );
   pNewButton->slotMoveable ( );
   pNewButton->setName      ( pXMLButton->name  );
   pNewButton->setAction    ( pXMLButton->value );
-  pNewButton->appendNormal ( pNewText );
 
-  pPreview->addMenuObject  ( pNewButton );
   return true;
 }
 
 bool DVDAuthor::buildFromTitles ( CXmlDVDAuthor::titles_struct *pTitles )
 {
   int iPgc = 0;
-  if ( ! pTitles->ppArrayPgc )
+  if ( ( ! pTitles ) || ( ! pTitles->ppArrayPgc ) ) 
     return true;
 
   while ( pTitles->ppArrayPgc[ iPgc ] ) {
-    if ( ! buildTitleFromPgc ( pTitles->ppArrayPgc[ iPgc++ ] ) )
+    if  ( ! buildTitleFromPgc ( pTitles->ppArrayPgc[ iPgc++ ] ) )
       return false;
   }
 
@@ -329,6 +367,9 @@ bool DVDAuthor::buildFromTitles ( CXmlDVDAuthor::titles_struct *pTitles )
 
 bool DVDAuthor::buildTitleFromPgc ( CXmlDVDAuthor::pgc_struct *pPgc )
 {
+  if ( ! pPgc )
+    return false;
+
   int iVob = 0;
   CXmlDVDAuthor::vob_struct *pVob;
   SourceFileInfo  *pInfo;
@@ -384,6 +425,9 @@ DVDMenu *DVDAuthor::findMenuFromStream ( CXmlSpumux::stream_struct *pStream )
 {
   int iSpu = 0;
   DVDMenu *pDVDMenu = NULL;
+  if ( ( ! pStream ) || ( ! pStream->ppArraySpu ) )
+    return pDVDMenu;
+
   while ( pStream->ppArraySpu[ iSpu ] ) {
     pDVDMenu = findMenuFromSpu ( pStream->ppArraySpu [ iSpu++ ] );
     if ( pDVDMenu ) // findMenuFromSpu ( pStream->ppArraySpu [ iSpu++ ] ) )
@@ -402,6 +446,9 @@ DVDMenu *DVDAuthor::findMenuFromSpu ( CXmlSpumux::spu_struct *pSpu )
   ButtonObject *pButtonObject;
   DVDMenu *pMenu = m_pVMGMenu;
 
+  if ( ! pSpu )
+    return NULL;
+
   // The only link between spumux and dvdauthor xml files seem to be the button-names.
   while (  iMenu <= (int)m_listDVDMenus.count()  ) {
     listOfButtons = pMenu->getButtons ();
@@ -417,8 +464,10 @@ DVDMenu *DVDAuthor::findMenuFromSpu ( CXmlSpumux::spu_struct *pSpu )
       }
       // count the number of XML buttons
       iXMLButtons = 0;
-      while ( pSpu->ppArrayButton[ iXMLButtons++ ] ) ;
-      iXMLButtons --; // counted one too many.
+      if ( pSpu->ppArrayButton ) {
+	while ( pSpu->ppArrayButton[ iXMLButtons++ ] ) ;
+	iXMLButtons --; // counted one too many.
+      }
       // At this point it seems save to assume we have the right Spumux for the menu
       if ( ( bWeHaveAWinner ) && (iXMLButtons == (int)listOfButtons.count()) ) {
 	return addSpuInfoToMenu ( pSpu, pMenu );
@@ -436,12 +485,12 @@ CXmlSpumux::button_struct *DVDAuthor::findButtonObjectInArray ( CXmlSpumux::butt
   uint iButton = 0;
   CXmlSpumux::button_struct *pXMLButton;
 
-  if ( ! pButtonObject )
+  if ( ( ! pButtonObject ) || ( ! ppArrayButton ) )
     return NULL;
 
   while ( ppArrayButton[ iButton ] ) {
     pXMLButton = ppArrayButton[ iButton++ ];
-    if ( pXMLButton->label == pButtonObject->name() ) 
+    if ( pXMLButton && ( pXMLButton->label == pButtonObject->name ( ) ) )
       return pXMLButton;
   }
   
@@ -458,7 +507,7 @@ ButtonObject *DVDAuthor::findXMLButtonInList ( QValueList<ButtonObject *> &listO
   
   for (t=0;t<listOfButtons.count();t++) {
     pButtonObject = listOfButtons[t];
-    if ( pXMLButton->label == pButtonObject->name() ) 
+    if ( pXMLButton && ( pXMLButton->label == pButtonObject->name ( ) ) )
       return pButtonObject;
   }
   
@@ -481,7 +530,7 @@ DVDMenu *DVDAuthor::addSpuInfoToMenu ( CXmlSpumux::spu_struct *pSpu, DVDMenu *pM
   while ( pSpu->ppArrayButton[ iButton ] ) {
     pXMLButton = pSpu->ppArrayButton[ iButton++ ];
     pButtonObject = findXMLButtonInList ( listOfButtons, pXMLButton );
-    if ( ! pButtonObject )
+    if ( ! pButtonObject ) 
       break; // error.
 
     if ( pXMLButton->label == pButtonObject->name() ) {
@@ -518,11 +567,49 @@ DVDMenu *DVDAuthor::addSpuInfoToMenu ( CXmlSpumux::spu_struct *pSpu, DVDMenu *pM
   }
   // And the last information from spu is the transparent color ...
   if ( !pSpu->transparent.isEmpty () )
-    pMenuInterface->pgcColors[0] = QString ("0x%1").arg( pSpu->transparent );
+    pMenuInterface->pgcColors[0].fromString ( pSpu->transparent );
 
   return pMenu;
 }
 
+void DVDAuthor::validateButtons ( DVDMenu *pDVDMenu )
+{
+  if ( ! pDVDMenu )
+    return;
+  uint t, iCount, iX, iY, iButtonWidth, iButtonHeight, iDeltaX, iDeltaY, iButtonX, iButtonY;
+  QValueList<ButtonObject *> listOfButtons = pDVDMenu->getButtons ( );
+  ButtonObject *pButton;
+  TextObject   *pText;
+  QRect         theRect;
+  iCount = iX = iY = 0;
+  iButtonWidth = 100; iButtonHeight = 30; // button dimensions.
+  iDeltaX = 10; iDeltaY = 10; // space between buttons
+
+  for ( t=0; t<listOfButtons.count ( ); t++ ) {
+    pButton  = listOfButtons[t];
+    if ( pButton ) {
+      pText   = (TextObject *)pButton->getNormal ( 0 );
+      theRect = pButton->rect ( );
+      if ( ! theRect.isValid ( ) || theRect.isNull ( ) || theRect.isEmpty ( ) ) {
+	iButtonX = 10 + iX * (iButtonWidth  + iDeltaX);
+	iButtonY = 10 + iY * (iButtonHeight + iDeltaY);
+	theRect  = QRect ( iButtonX, iButtonY, iButtonWidth, iButtonHeight );
+	pButton->setRect ( theRect );
+	if ( pText->getText ( ).isEmpty ( ) ) {
+	  QString qsText = QString ( "Button %1" ).arg ( iCount );
+	  pText->setText ( qsText );
+	}
+	iCount ++;
+	iX ++;
+	if ( iButtonX + iButtonWidth > 720 ) {
+	  iX =0;
+	  iY ++;
+	}
+      }
+    }
+  }
+}
+
 // TODO: report DVDenus/XMLSpu untouched 
 /*
 <subpictures>
