@@ -30,7 +30,7 @@ bool CXmlKino::readXml ( QString &fileName )
 {
   // Assign the file
   QFile projectFile ( fileName );
-  if (!projectFile.open ( IO_Raw | IO_ReadWrite ) )
+  if (!projectFile.open ( IO_ReadWrite ) )
     return false;
   
   QDomDocument xmlDoc;
@@ -128,6 +128,7 @@ CXmlKino::seq_struct::seq_struct ()
 {
   clipBegin  = 0;
   clipEnd    = 0;
+  id         = -1;
 }
 
 bool CXmlKino::seq_struct::readXml ( QDomElement *pDocElem )
