@@ -1,6 +1,11 @@
 /****************************************************************************
 ** importsrt.cpp
 **
+**   Created :
+**        by : Varol Okan
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
+**
 ** This file holds the implementation of the import filter for the srt 
 ** subtitles file.
 *****************************************************************************/
@@ -32,7 +37,7 @@ bool Srt::import ()
 
   // Sanity check .. Did te user choose a new project file ?
   if (qsImportFile.isNull ())
-    return true;
+    return false;
 
   return readFile ( qsImportFile );
 }
@@ -43,7 +48,7 @@ bool Srt::readFile ( QString &fileName )
   Subtitles::entry *pEntry;
   QString line, lineIndex, lineTimestamp, lineText;
   QFile projectFile ( fileName );
-  if (!projectFile.open ( IO_Raw | IO_ReadWrite ) )
+  if (!projectFile.open ( IO_ReadOnly ) )
     return false;
   
   QTextStream srtStream( &projectFile );
@@ -101,7 +106,7 @@ QString Srt::readEntry ( QTextStream *pStream, Subtitles::entry *pEntry )
   pEntry->iTimeStart  = getTimeFromString ( pEntry->qsTimeStart );
   pEntry->qsTimeStop  = getTimeRange ( lineTimestamp, false );
   pEntry->qsTimeStop.replace ( ',', '.' );
-  pEntry->iTimeStart  = getTimeFromString ( pEntry->qsTimeStop );
+  pEntry->iTimeStop   = getTimeFromString ( pEntry->qsTimeStop );
   pEntry->qsText      = lineText;
 
   return line;
