@@ -19,11 +19,11 @@ Keyword::Keyword ()
   char arrayKeys[12][35] = {"+DVDAUTHOR_XML+", "+PROJECT_PATH+", "+TEMP_PATH+", "+WIDTH+", "+HEIGHT+",
     "+FORMAT+", "+MENU_NAME+", "+START_POS+", "+DURATION+", "+BACKGROUND_FILE_NAME+", "+BACKGROUND_FULL_NAME+", "+SOUND_LIST+" };
 
-  char arrayTranscodeKeys[19][35] = {"+DVDAUTHOR_XML+", "+PROJECT_PATH+", "+TEMP_PATH+", "+INPUT_NAME+", "+BASE_NAME+",
-    "+FILE_EXT+", "+AUDIO_FORMAT+", "+AUDIO_TYPE+", "+AUDIO_BITRATE+", "+SAMPLE_RATE+", "+STARTING_AT+", "+ENDING_AT+",
-    "+WIDTH+", "+HEIGHT+", "+VIDEO_FORMAT+", "+VIDEO_TYPE+", "+VIDEO_BITRATE+", "+FRAME_RATE+", "+RATIO+" };
+  char arrayTranscodeKeys[20][35] = {"+DVDAUTHOR_XML+", "+PROJECT_PATH+", "+TEMP_PATH+", "+INPUT_NAME+", "+BASE_NAME+",
+    "+FILE_EXT+", "+AUDIO_FORMAT+", "+AUDIO_TYPE+", "+AUDIO_BITRATE+", "+SAMPLE_RATE+", "+STARTING_AT+", "+ENDING_AT+", 
+    "+WIDTH+", "+HEIGHT+", "+VIDEO_FORMAT+", "+VIDEO_TYPE+", "+VIDEO_BITRATE+", "+FRAME_RATE+", "+RATIO+", "+AUDIO_LIST+" };
 
-  char arraySubtitlesKeys[5][35] = {"+PROJECT_PATH+", "+TEMP_PATH+", "+INPUT_FILE_NAME+", "+BASE_NAME+", "+BASE_EXTENSION+" };
+  char arraySubtitlesKeys[8][35] = {"+PROJECT_PATH+", "+TEMP_PATH+", "+INPUT_FILE_NAME+", "+XML_FILE_NAME+", "+BASE_NAME+", "+BASE_EXTENSION+", "+SUBTITLE_NUMBER+", "+MULTIPLE_SUBTITLE_PIPE+" };
   
   // init the key lists
   Entry *pEntry = NULL;
@@ -169,6 +169,10 @@ QString Keyword::resolvString ( int iWhichKeyset, QString qsInput)
  * This function is used for the TranscodeInterface - part of CommandQueueDialog.
  * It converts the input values to the propper format needed by the conversion tools.
  * E.g. aspect_ratio = "4:3" translates to '2' for transcode
+ * 
+ * Note, I know that this is not the most efficient place to put this sanity checking
+ * but this function is called less then 100 times per DVD creation and does not really 
+ * affect performance if we leave it here ;o)
  * \see resolveString()
  */
 QString Keyword::resolvConvert (QString qsInput, QString qsConversionTool)
@@ -178,23 +182,49 @@ QString Keyword::resolvConvert (QString qsInput, QString qsConversionTool)
 //		"+WIDTH+", "+HEIGHT+", "+VIDEO_FORMAT+", "+VIDEO_TYPE+", "+VIDEO_BITRATE+", "+FRAME_RATE+", "+RATIO+", 
 //		};
   QString qsRatio, qsValue, qsKey, qsOutput = qsInput;
+  QString qsAudioBitrate, qsVideoBitrate;
   uint t;
-  long iAudioBitrate, iVideoBitrate;
+  long iAudioBitrate, iVideoBitrate, iStartingAt, iEndingAt;
   // Next we adjust it for the conversion tool.
   
   // These here are used for all conversion tools.
-  iAudioBitrate = (int)( value ( TransKeys, TransAudioBitrate ).toInt () / 1000);
-  if (iAudioBitrate < 32)		// according to DVD spec this is the minimum.
-    iAudioBitrate = 32;	// Note: How to handle no audio (0) ?
-  if (iAudioBitrate > 1536)
-    iAudioBitrate = 1536;	// This is the max rate according to DVD spec.
-  
+  qsAudioBitrate = value ( TransKeys, TransAudioBitrate );
+  iAudioBitrate = qsAudioBitrate.toLong ( );
+  if ( iAudioBitrate > 10000 )
+       iAudioBitrate = (int)( (float)iAudioBitrate / 1000.0);
+  if ( iAudioBitrate <   32 )   // according to DVD spec this is the minimum.
+       iAudioBitrate =  128;    // Note: How to handle no audio (0) ?
+  if ( iAudioBitrate > 1536 )
+       iAudioBitrate = 1536;   // This is the max rate according to DVD spec.
   setValue ( TransKeys, TransAudioBitrate, QString ("%1").arg(iAudioBitrate) );
-  iVideoBitrate = (int)( value ( TransKeys, TransVideoBitrate ).toInt ( ) / 1000.0);
-  if (iVideoBitrate < 1856)	// according to DVD spec this is the minimum.
-    iVideoBitrate = 1856;	// Note: How to handle no audio (0) ?
+
+  qsValue     = value ( TransKeys, TransStartingAt );
+  iStartingAt = qsValue.toLong ( );
+  qsValue     = value ( TransKeys, TransEndingAt );
+  iEndingAt   = qsValue.toLong ( );
+  if ( iEndingAt < 20 )
+       iEndingAt = 1000000; // approx. 9.3 hours
+  if ( iStartingAt > iEndingAt )
+       iStartingAt = 0;
+  setValue ( TransKeys, TransStartingAt, QString ( "%1" ).arg ( iStartingAt ) );
+  setValue ( TransKeys, TransEndingAt,   QString ( "%1" ).arg ( iEndingAt   ) );
+
+  qsValue = value ( TransKeys, TransAudioType );
+  // default it to mp2 and only allow ac3, and pcm
+  qsValue = qsValue.lower ( );
+  if ( ( qsValue != "ac3" ) && ( qsValue != "pcm" ) )
+         qsValue  = "mp2";
+  setValue ( TransKeys, TransAudioType, qsValue );
+
+  qsVideoBitrate = value ( TransKeys, TransVideoBitrate );
+  iVideoBitrate = qsVideoBitrate.toInt ( );
+  if ( iVideoBitrate > 10000 )
+       iVideoBitrate = (int)((float)iVideoBitrate / 1000.0 );
+  if ( iVideoBitrate < 1856)	// according to DVD spec this is the minimum.
+       iVideoBitrate = 1856;	// Note: How to handle no audio (0) ?
   setValue ( TransKeys, TransVideoBitrate, QString ("%1").arg( iVideoBitrate ) );
-  if (qsConversionTool == QString (SUB_BLOCK_TRANSCODE))	{
+
+  if (qsConversionTool.find ( SUB_BLOCK_TRANSCODE ) > -1 )	{
     qsRatio = value ( TransKeys, TransRatio );
     if ( qsRatio == QString ("1:1"))
       qsRatio = QString ("1");
@@ -204,10 +234,40 @@ QString Keyword::resolvConvert (QString qsInput, QString qsConversionTool)
       qsRatio = QString ("3");
     else if ( qsRatio == QString ("2.21:1"))
       qsRatio = QString ("4");
+    else 
+      qsRatio = QString ("2");
     setValue ( TransKeys, TransRatio, qsRatio );
   }
-  else if (qsConversionTool == QString (SUB_BLOCK_MENCODER))	{
-    
+  else if (qsConversionTool.find ( SUB_BLOCK_MENCODER ) > -1 )	{
+    bool bOkay;
+    QString qsSampleRate = value ( TransKeys, TransSampleRate );
+    int iSampleRate      = qsSampleRate.toInt ( &bOkay );
+    if ( bOkay && ( iSampleRate < 10000 ) )
+      iSampleRate *= 1000;
+    if ( iSampleRate < 10000 )
+      qsSampleRate = "48000"; // default sample rate.
+    else 
+      qsSampleRate = QString ( "%1" ).arg ( iSampleRate );
+    setValue ( TransKeys, TransSampleRate, qsSampleRate );
+
+    // Next we take care of the end - pos ... 
+    QString qsEndPos = value ( TransKeys, TransEndingAt );
+    int iEndPos = qsEndPos.toInt ( &bOkay );
+    if ( bOkay && iEndPos < 1 )
+      qsEndPos = "100000000"; // 100000sec ~ 27:46h should be enough ...
+
+    // And we also need to convert 29.97 to 30000/1001
+    QString qsFrameRate = value ( TransKeys, TransFrameRate );
+    float fFrameRate = qsFrameRate.toFloat ( &bOkay );
+    qsFrameRate = "30000/1001"; // default to 29.97 (ntsc)
+    if ( ( bOkay ) && ( fFrameRate < 29.0 ) )
+      qsFrameRate = "25";
+    setValue ( TransKeys, TransFrameRate, qsFrameRate );
+  }
+  else if (qsConversionTool.find ( SUB_BLOCK_VIDEOTRANS ) > -1 )	{
+    qsRatio = value ( TransKeys, TransRatio ); // only 4:3 and 16:9 are valid
+    if ( ( qsRatio != QString ("4:3") ) && ( qsRatio != QString ("16:9") ) )
+      setValue ( TransKeys, TransRatio, QString ( "4:3" ) );
   }
   
   for (t=0;t<m_listOfPair[TransKeys].count();t++)	{
