@@ -1,8 +1,10 @@
 /****************************************************************************
 ** Class Keyword 
 **
-** Created: Fri 08 Dec 12:09:08 2005
-**      by: Varol Okan using XEmacs
+**   Created : Fri 08 Dec 12:09:08 2005
+**        by : Varol Okan using XEmacs
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 ** This class will replace a given token in a string with a value
 **
@@ -19,21 +21,22 @@ public:
   enum enKeyBase { Keys, TransKeys, SubKeys, BaseLast };
 
   enum enTranscodeKeys {
-    TransDVDAuthorXML=0, TransProjectPath, TransTempPath,    TransInputName , 
-    TransBaseName,       TransFileExt,     TransAudioFormat, TransAudioType, 
-    TransAudioBitrate,   TransSampleRate,  TransStartingAt,  TransEndingAt,
-    TransWidth,          TransHeight,      TransVideoFormat, TransVideoType, 
-    TransVideoBitrate,   TransFrameRate,   TransRatio,       TransLast
+    TransDVDAuthorXML=0,   TransProjectPath, TransTempPath,    TransInputName , 
+    TransBaseName,         TransFileExt,     TransAudioFormat, TransAudioType, 
+    TransAudioBitrate,     TransSampleRate,  TransStartingAt,  TransEndingAt,
+    TransWidth,            TransHeight,      TransVideoFormat, TransVideoType, 
+    TransVideoBitrate,     TransFrameRate,   TransRatio,       TransAudioList, 
+    TransForEachCounter,   TransTrackName,   TransLast
   };
   enum enKeys {
-    KeyDVDAuthorXML=0,   KeyProjectPath,   KeyTempPath,      KeyWidth, 
-    KeyHeight,           KeyFormat,        KeyMenuName,      KeyStartPos, 
-    KeyDuration,         KeyBackgroundFileName, KeyBackgroundFullName, 
-    KeySoundList,        KeyLast
+    KeyDVDAuthorXML=0,     KeyProjectPath,   KeyTempPath,      KeyWidth, 
+    KeyHeight,             KeyFormat,        KeyMenuName,      KeyAspectRatio,
+    KeyStartPos,           KeyDuration,      KeyNrOfFrames,    KeyBackgroundFileName, 
+    KeyBackgroundFullName, KeySoundList,     KeyLast
   };
   enum enSubtitlesKeys {
-    SubProjectPath=0,  SubTempPath, SubInputFileName, SubBaseName, SubFileExt, 
-    SubLast
+    SubProjectPath=0,  SubTempPath, SubInputFileName, SubXmlFile, SubBaseName,
+    SubFileExt, SubSubtitleNumber, SubMultipleSubtitlePipe, SubLast
   };
   
   class Entry {
