@@ -1,8 +1,10 @@
 /****************************************************************************
 ** ListViewMedia class to
 **
-** Created: Sat Nov 27 12:09:08 2004
-**      by: Varol Okan using kate editor
+**   Created : Sat Nov 27 12:09:08 2004
+**        by : Varol Okan using kate editor
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 ****************************************************************************/
 
@@ -33,8 +35,12 @@ public:
 public slots:
 	void slotItemClicked (QListViewItem *, const QPoint &, int);
 
+private:
+	void handleAudioTracks    ( SourceFileEntry * );
+	void handleSubtitleTracks ( SourceFileEntry * );
+
 signals:
-	void signalRemoveEntry (SourceFileEntry *);
+	void signalRemoveEntry ( SourceFileEntry * );
 
 private:
 	SourceFileEntry *m_pDraggingSourceFileEntry;
