@@ -1,7 +1,15 @@
-
+/*************************************************
+  **
+  **   Created : 
+  **        by : Varol Okan
+  ** Copyright : (c) Varol Okan
+  **   License : GPL v 2.0
+  **
+  ***********************************************/
 
 #include <stdarg.h>
 #include <qstring.h>
+#include <stdlib.h>
 #include <stdio.h>
 #include <time.h>
 
