@@ -1,9 +1,18 @@
-
+/******************************************************
+ **
+ **   Created : December 2003
+ **        by : Varol Okan
+ ** Copyright : (c) Varol Okan
+ **   License : GPL v 2.0
+ **
+ *****************************************************/
 
 #include <signal.h>
 #include <stdlib.h>
-#include <unistd.h>
 #include <getopt.h>
+#ifdef QDVD_LINUX 
+#include <unistd.h>
+#endif
 
 #include <qapplication.h>
 #include <qtextcodec.h>
@@ -16,15 +25,20 @@
 #include "messagebox.h"
 #include "qdvdauthor.h"
 #include "importkino.h"
+#include "cachethumbs.h"
 #include "xml_dvdauthor.h"
 #include "importdvdauthor.h"
 
+#include "../bugs_workaround.h"
+
+#ifndef XINIT_THREADS_CRASH
 #include <X11/Xlib.h>
+#endif
 
 void displayHelp ()
 {
   printf ("qdvdauthor -k -d -p -x -o -h\n"
-	  "Copyrighted 2003-2006 by Varol Okan\n"
+	  "Copyrighted 2003-2007 by Varol Okan\n"
 	  "Built " __DATE__ "\n\n"
 	  "-k <inputFile>              This option allows you to import a kino smil file.\n"
 	  "-d <inputFile>              This option allows you to import a dvdauthor.xml file.\n"
@@ -36,14 +50,21 @@ void displayHelp ()
 	  "                            Note: -a and -x are not yet implemented.\n\n");
 }
 
+#include <qregexp.h>
 int main( int argc, char ** argv )
 {
+#ifndef XINIT_THREADS_CRASH
+  // XInitThreads was causing some hangs on some machines under certain circumstances. lets see if it works without.
+  // Note XinitThreads is/was required for the xine libs.
   // One of the first things we ought to do is to ensure threating is turned on ...
-  if (!XInitThreads ())	{
-    QApplication::beep();
-    MessageBox::warning(NULL, QObject::tr ("XInitThreads failed!"), QObject::tr ("XInitThreads failed!"), QMessageBox::Ok, QMessageBox::NoButton);
-    return -1;
+  if ( !getenv ( "QDVD_NO_XINIT" ) ) {
+    if (!XInitThreads ())	{
+      QApplication::beep();
+      MessageBox::warning(NULL, QObject::tr ("XInitThreads failed!"), QObject::tr ("XInitThreads failed!"), QMessageBox::Ok, QMessageBox::NoButton);
+      return -1;
+    }
   }
+#endif
 
 	int       iReturn = 0; 
 	bool      bSkipAutosaveTest = false;
@@ -55,13 +76,16 @@ int main( int argc, char ** argv )
 
 	char *pLogLevel = getenv ("LOG_LEVEL");
 	if ( pLogLevel ) 
-	  Global::pLogObject = new Log ((Log::type) atoi (pLogLevel) );
+	  Global::pLogObject = new Log ( (Log::type)atoi (pLogLevel) );
 	else
-	  Global::pLogObject = new Log(Log::logDebug);
-
+	  Global::pLogObject = new Log ( Log::logDebug );
+#ifdef QDVD_LINUX
 	signal(SIGTTOU, SIG_IGN);
-
+#endif
 	QApplication application( argc, argv );
+
+	Global::pThumbsCache = new Cache::Thumbs;
+
 	// translation file for Qt
 	QTranslator qt( 0 );
 	// Under $QTDIR/translations/
@@ -69,6 +93,7 @@ int main( int argc, char ** argv )
 	application.installTranslator( &qt );
 
 	QDVDAuthor dvdAuthor;
+	Global::pApp = &dvdAuthor;
 	VMGMenu *pDVDMenu = new VMGMenu (&dvdAuthor);
 
 	dvdAuthor.addDVDMenu(pDVDMenu, true);
@@ -168,8 +193,13 @@ int main( int argc, char ** argv )
 	application.connect( &application, SIGNAL( lastWindowClosed() ), &application, SLOT( quit() ) );
 	iReturn = application.exec();
 
+	// Free global static allocated objects.
 	delete Global::pLogObject;
 	Global::pLogObject = NULL;
+
+	delete Global::pThumbsCache;
+	Global::pThumbsCache = NULL;
+
 	return iReturn;
 }
 
