@@ -1,9 +1,10 @@
- 
 /****************************************************************************
 ** MenuOject class
 **
-** Created: Tue Feb 02 22:06:51 2004
-**      by: Varol Okan using Kate
+**   Created : Tue Feb 02 22:06:51 2004
+**        by : Varol Okan using Kate
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 ** This class is the encapsulation of the MenuObject.
 **
@@ -11,39 +12,53 @@
 ** A MenuObject itself is not visible and not used in itself. Only derived
 ** classes are used in the DVD Menu.
 **
+** Current objects include :
+** TextObject, ImageObject, MovieObject, FrameObject, ButtonObject
+** ShadowObject, MaskObject, ObjectCollection, and MenuObject
+**
 ****************************************************************************/
 
 #include <qfile.h>
+#include <qtimer.h>
 #include <qpainter.h>
 #include <qpopupmenu.h>
 
+#include "global.h"
+
 #include "xml_dvd.h"
 #include "menuobject.h"
 #include "shadowobject.h"
+#include "structuretoolbar.h"
 
 MenuObject::MenuObject (QWidget *pParent)
-	: QObject (pParent)
+  : QObject (pParent)
 {
-	m_qsObjectType = QString (MENU_OBJECT);
-	m_pParent      = pParent;
-	m_bDrawRect    = false;
-	m_pContextMenu = NULL;
-	m_pShadow      = NULL;
-	m_objectState  = StateUnknown;
+  m_qsObjectType   = QString (MENU_OBJECT);
+  m_pParent        = pParent;
+  m_bDrawRect      = false;
+  m_pContextMenu   = NULL;
+  m_pShadow        = NULL;
+  m_pStructureItem = NULL;
+  m_objectState    = StateUnknown;
 }
 
 MenuObject::~MenuObject ()
 {
-	uint t;
-	if (m_pContextMenu)
-		delete m_pContextMenu;
-	m_pContextMenu = NULL;
-	for (t=0;t<m_listAnimationAttributes.count();t++)	{
-		delete m_listAnimationAttributes[t];
-	}
-	m_listAnimationAttributes.clear();
-	if ( m_pShadow )
-	  delete m_pShadow;
+  uint t;
+  if ( m_pContextMenu )
+    delete m_pContextMenu;
+  m_pContextMenu = NULL;
+  for ( t=0; t<m_listAnimationAttributes.count ( ); t++ )
+    delete m_listAnimationAttributes[t];
+
+  m_listAnimationAttributes.clear ( );
+  if ( m_pShadow )
+    delete m_pShadow;
+  m_pShadow = NULL;
+  //  resetStructureItem ( );
+  if ( m_pStructureItem )
+    delete m_pStructureItem;
+  m_pStructureItem = NULL;
 }
 
 bool MenuObject::readProjectFile  (QDomNode &theNode)
@@ -147,12 +162,15 @@ bool MenuObject::readProjectFile  (QDomNode &theNode)
 					if (!attribute.isNull())
 						modifiers()->fShearY = attribute.value().toFloat();
 				}
-				else if (tagName == ANIMATION_OBJECT)	{
-					m_qsAnimation = theElement.text ();
-				}
+				//else if (tagName == ANIMATION_OBJECT)	{
+				//	m_qsAnimation = theElement.text ();
+				//}
 				subNode = subNode.nextSibling ();
 			}
 		}
+		if ( tagName == ANIMATION_OBJECT )	{
+		  m_qsAnimation = nodeText;
+		}
 		else if (tagName == SHADOW_OBJECT)	{
 		  m_pShadow = new ShadowObject ( this );
 		  if ( ! m_pShadow->readProjectFile ( xmlMenuObject ) ) 
@@ -176,14 +194,14 @@ bool MenuObject::writeProjectFile (QDomElement &theElement)
 	QDomDocument xmlDoc = theElement.ownerDocument();
 	QDomElement objectNode = xmlDoc.createElement( MENU_OBJECT );	// <MenuObject>
 	// Here we set the attributes of the <dvdauthor> tag
-	if (!name().isNull())
-		objectNode.setAttribute( MENU_OBJECT_NAME, name() );
-	if (!extractionPath().isNull())
+	if ( ! name ( ).isNull ( ) )
+		objectNode.setAttribute( MENU_OBJECT_NAME, name ( ) );
+	if ( ! extractionPath  ( ).isNull ( ) )
 		objectNode.setAttribute( MENU_OBJECT_EXTRACTION_PATH, extractionPath() );
-	objectNode.setAttribute( RECT_X, rect().x() );
-	objectNode.setAttribute( RECT_Y, rect().y() );
-	objectNode.setAttribute( RECT_WIDTH,  rect().width () );
-	objectNode.setAttribute( RECT_HEIGHT, rect().height() );
+	objectNode.setAttribute( RECT_X, rect ( ).x ( ) );
+	objectNode.setAttribute( RECT_Y, rect ( ).y ( ) );
+	objectNode.setAttribute( RECT_WIDTH,   rect ( ).width  ( ) );
+	objectNode.setAttribute( RECT_HEIGHT,  rect ( ).height ( ) );
 	// And now proceed to writing the Modifiers ... If we need that is ...
 	Modifiers initialValues;
 	if (	(modifiers()->fRotate != initialValues.fRotate) || (modifiers()->fShearX != initialValues.fShearX)  || 
@@ -227,7 +245,7 @@ bool MenuObject::writeProjectFile (QDomElement &theElement)
 	return true;
 }
 
-void MenuObject::update()
+void MenuObject::update ( )
 {
 	QPainter thePainter(parent());
 	QRect theRect = boundingRect();
@@ -238,6 +256,14 @@ void MenuObject::update()
 //	emit(signalUpdatePixmap());
 }
 
+void MenuObject::resetStructureItem ( )
+{
+  if ( m_pStructureItem ) 
+    delete m_pStructureItem;
+  m_pStructureItem = NULL;
+  m_modifiers.m_pStructureItem = NULL;
+}
+
 QString &MenuObject::objectType()
 {
 	return m_qsObjectType;
@@ -253,32 +279,37 @@ QString &MenuObject::extractionPath()
 	return m_qsExtractionPath;
 }
 
+void MenuObject::animationDialog ( QString &qsTempAnim, int iType )
+{
+  emit ( signalAnimateMe ( qsTempAnim, iType, QString ( ) ) );
+}
+
 QString &MenuObject::animation()
 {
-	return m_qsAnimation;
+  return m_qsAnimation;
 }
 
 Modifiers *MenuObject::modifiers()
 {
-	return &m_modifiers;
+  return &m_modifiers;
 }
 
 void MenuObject::setModifiers(Modifiers &theModifiers)
 {
-	*modifiers() = theModifiers;
+  *modifiers() = theModifiers;
 }
 
 QPoint   &MenuObject::currentMousePos()
 {
-	return m_currentMousePos;
+  return m_currentMousePos;
 }
 
 // Need to take m_rectPreview into accoutn ...
 bool MenuObject::contains (QPoint &pos)
 {
-	if (!m_boundingRect.contains(pos))
-		return false;
-	return true;
+  if ( ! boundingRect( ).contains ( pos ) )
+    return false;
+  return true;
 }
 
 bool MenuObject::mouseMoveEvent (QMouseEvent *pEvent)
@@ -366,7 +397,7 @@ void MenuObject::setObjectState ( enState newState )
 // the state of the mouse operation.
 // This function checks wether the mouse was pressed above a hot spot 
 // Resize / rotate etc. or not.
-MenuObject::enState MenuObject::setObjectState ( QPoint &pos )
+MenuObject::enState MenuObject::setObjectState ( QPoint &pos, Qt::ButtonState theState )
 {
   m_objectState = StateMoveObject;
   int iHeight2, iWidth2, iX, iY;
@@ -402,8 +433,9 @@ MenuObject::enState MenuObject::setObjectState ( QPoint &pos )
     if ( ( iX > iWidth2 - HANDLE_WIDTH ) && ( iX < iWidth2 + HANDLE_WIDTH ) )
       m_objectState = StateScaleBottomY;
   }
-  else if ( ( iX > iWidth2  - HANDLE_WIDTH  ) && ( iX < iWidth2  + HANDLE_WIDTH  ) &&
-	    ( iY > iHeight2 - HANDLE_HEIGHT ) && ( iY < iHeight2 + HANDLE_HEIGHT ) ) {
+  //  else if ( ( iX > iWidth2  - HANDLE_WIDTH  ) && ( iX < iWidth2  + HANDLE_WIDTH  ) &&
+  //	    ( iY > iHeight2 - HANDLE_HEIGHT ) && ( iY < iHeight2 + HANDLE_HEIGHT ) ) {
+  else if ( theState == Qt::ControlButton ) {
     m_objectState = StateRotate;
   }
   return m_objectState;
@@ -475,7 +507,7 @@ void MenuObject::updateShadow ( )
        m_pShadow->updateShadow ( );
 }
 
-QRect   &MenuObject::rect()
+QRect &MenuObject::rect()
 {
   return m_rect;
 }
@@ -491,7 +523,7 @@ QPoint MenuObject::position ( )
 
 QRect   &MenuObject::boundingRect()
 {
-	return m_boundingRect;
+  return m_boundingRect;
 }
 
 void MenuObject::setRect(QRect &rect)
@@ -531,19 +563,14 @@ QWidget *MenuObject::parent()
 	return m_pParent;
 }
 
-bool    MenuObject::drawRect()
+bool MenuObject::drawRect()
 {
 	return m_bDrawRect;
 }
 
-MenuObject *MenuObject::clone()
+MenuObject *MenuObject::clone( QWidget *, MenuObject * )
 {  
-	return NULL;
-}
-
-MenuObject *MenuObject::clone( MenuObject * )
-{  
-	return NULL;
+  return NULL;
 }
 
 void MenuObject::setName (QString &qsName)
@@ -558,12 +585,18 @@ void MenuObject::setExtractionPath (QString &qsPath)
 
 void MenuObject::setAnimation (QString &qsAnimation)
 {
-	m_qsAnimation = qsAnimation;
+  m_qsAnimation = qsAnimation;
 }
 
 void MenuObject::slotDelete ()
 {
-	emit (signalDeleteMe(this));
+  // get a slight delay to allow the ContextMenu to be destroyed ...
+  QTimer::singleShot ( 10, this, SLOT ( slotEmitDelete ( ) ) );
+}
+
+void MenuObject::slotEmitDelete ( )
+{
+  emit ( signalDeleteMe ( this ) );
 }
 
 void MenuObject::slotAddShadow ( ) 
@@ -572,6 +605,29 @@ void MenuObject::slotAddShadow ( )
   emit ( signalShadowMe ( this ) );
 }
 
+void MenuObject::slotDeleteShadow ( )
+{
+  setShadow ( NULL );
+  emit ( signalUpdatePixmap ( ) );
+}
+
+void MenuObject::slotCut ( )
+{
+  slotCopy ( );
+  slotEmitDelete ( );
+}
+
+void MenuObject::slotCopy ( )
+{
+  if ( Global::pCopyObject )
+    delete Global::pCopyObject;
+  Global::pCopyObject = clone ( );
+
+  if (m_pContextMenu)
+    delete m_pContextMenu;
+  m_pContextMenu = NULL;
+}
+
 void MenuObject::slotToFront ()
 {
 	// Send it all the way to the front
@@ -592,137 +648,153 @@ void MenuObject::slotToBack ()
 
 void MenuObject::loadAnimationData (QString &qsFileName, long iMaxNumberOfFrames)
 {
-	// Called from MenuPreview::createAnimationData
-	// Loads in the pure data from a file.
-	// Note: changes are done on a per frame basis
-	// If no value for a prop at a frame is defined, 
-	// then the last value is the winner.
-	///////////////////////////////////////////////
-	
-	// Note, these values will change the true props 
-	// of the object.
-	// Once rendering is done the original values are re-set.
-	QFile file (qsFileName);
-	file.open ( IO_ReadOnly );
-	QTextStream stream( &file );
-	QString line;
-	uint t;
-	long iFrameNumber;
-	int  iPos, iPos2;
-	bool bFound;
-	QString qsProperty, qsValue;
+  // Called from MenuPreview::createAnimationData
+  // Loads in the pure data from a file.
+  // Note: changes are done on a per frame basis
+  // If no value for a prop at a frame is defined, 
+  // then the last value is the winner.
+  ///////////////////////////////////////////////
+  
+  // Note, these values will change the true props 
+  // of the object.
+  // Once rendering is done the original values are re-set.
+  QFile file (qsFileName);
+  file.open ( IO_ReadOnly );
+  QTextStream stream( &file );
+  QString line;
+  uint t;
+  long iFrameNumber;
+  int  iPos, iPos2;
+  bool bFound;
+  QString qsProperty, qsValue;
 
-	for (t=0;t<m_listAnimationAttributes.count();t++)	{
-		delete m_listAnimationAttributes[t];
+  for (t=0;t<m_listAnimationAttributes.count();t++)	{
+    delete m_listAnimationAttributes[t];
+  }
+  m_listAnimationAttributes.clear();
+  AnimationAttribute *pAnimAttr;
+  
+  while ( !stream.atEnd() ) {
+    line = stream.readLine(); // line of text excluding '\n'
+    iPos = line.find ("::");
+    iPos2 = line.find ("=");
+    if ( (iPos == -1) || (iPos2 == -1) )
+      continue;
+    qsProperty  = QString ("");
+    qsValue     = QString ("");
+    bFound      = false;
+    iFrameNumber = line.left (iPos).toInt();
+    // Note: Frame position 0 is used to store the original values.
+    if ( (iFrameNumber < 1) || (iFrameNumber > iMaxNumberOfFrames) )
+      continue;
+    qsProperty = line.mid (iPos+2, iPos2-iPos-2);
+    
+    qsValue = line.right (line.length() - iPos2-1);
+    if (qsValue == "SolidLine")
+      qsValue = QString ("%1").arg(Qt::SolidLine);
+    else if (qsValue == "DashLine")
+      qsValue = QString ("%1").arg(Qt::DashLine);
+    else if (qsValue == "DashDotLine")
+      qsValue = QString ("%1").arg(Qt::DashDotLine);
+    else if (qsValue == "DashDotDotLine")
+      qsValue = QString ("%1").arg(Qt::DashDotDotLine);
+    else if (qsValue == "MiterJoin")
+      qsValue = QString ("%1").arg(Qt::MiterJoin);
+    else if (qsValue == "BevelJoin")
+      qsValue = QString ("%1").arg(Qt::BevelJoin);
+    else if (qsValue == "RoundJoin")
+      qsValue = QString ("%1").arg(Qt::RoundJoin);
+    //printf ("MenuObject::loadAnimationData - load <%d> <%s>=<%s>\n", iFrameNumber, (const char *)qsProperty, (const char *)qsValue);
+    
+    // This loop will check if this property is already taken care of and we have a array of values waiting.
+    for (t=0;t<m_listAnimationAttributes.count ();t++)	{
+      pAnimAttr = m_listAnimationAttributes[t];
+      if (pAnimAttr->name() == qsProperty)	{
+	pAnimAttr->append (iFrameNumber, qsValue);
+	bFound = true;
+	break;
+      }
+    }
+    if ( ! bFound )	{
+      pAnimAttr = NULL;
+      // If not a standard property, then branch in the object and get the specific attribute 
+      // (I.e. text for TextObject etc. )
+      pAnimAttr = getSpecificAttributes (iMaxNumberOfFrames, qsProperty);
+      if ( ! pAnimAttr )	{
+	if (qsProperty == QString("pos.x"))	{
+	  FunctionCallback<MenuObject> *callMeBack = new FunctionCallback<MenuObject>(*this, &MenuObject::setPosition, &MenuObject::position, TYPE_POSITION_X );
+	  pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, position().x(), callMeBack);
+	  pAnimAttr->setNeedRefresh ( false );
 	}
-	m_listAnimationAttributes.clear();
-	AnimationAttribute *pAnimAttr;
-
-	while ( !stream.atEnd() ) {
-		line = stream.readLine(); // line of text excluding '\n'
-		iPos = line.find ("::");
-		iPos2 = line.find ("=");
-		if ( (iPos == -1) || (iPos2 == -1) )
-			continue;
-		qsProperty  = QString ("");
-		qsValue     = QString ("");
-		bFound      = false;
-		iFrameNumber = line.left (iPos).toInt();
-		// Note: Frame position 0 is used to store the original values.
-		if ( (iFrameNumber < 1) || (iFrameNumber > iMaxNumberOfFrames) )
-			continue;
-		qsProperty = line.mid (iPos+2, iPos2-iPos-2);
-		
-		qsValue = line.right (line.length() - iPos2-1);
-		if (qsValue == "SolidLine")
-			qsValue = QString ("%1").arg(Qt::SolidLine);
-		else if (qsValue == "DashLine")
-			qsValue = QString ("%1").arg(Qt::DashLine);
-		else if (qsValue == "DashDotLine")
-			qsValue = QString ("%1").arg(Qt::DashDotLine);
-		else if (qsValue == "DashDotDotLine")
-			qsValue = QString ("%1").arg(Qt::DashDotDotLine);
-		else if (qsValue == "MiterJoin")
-			qsValue = QString ("%1").arg(Qt::MiterJoin);
-		else if (qsValue == "BevelJoin")
-			qsValue = QString ("%1").arg(Qt::BevelJoin);
-		else if (qsValue == "RoundJoin")
-			qsValue = QString ("%1").arg(Qt::RoundJoin);
-		//printf ("MenuObject::loadAnimationData - load <%d> <%s>=<%s>\n", iFrameNumber, (const char *)qsProperty, (const char *)qsValue);
-
-		// This loop will check if this property is already taken care of and we have a array of values waiting.
-		for (t=0;t<m_listAnimationAttributes.count ();t++)	{
-			pAnimAttr = m_listAnimationAttributes[t];
-			if (pAnimAttr->name() == qsProperty)	{
-				pAnimAttr->append (iFrameNumber, qsValue);
-				bFound = true;
-				break;
-			}
-		}
-		if ( ! bFound )	{
-			pAnimAttr = NULL;
-			// If not a standard property, then branch in the object and get the specific attribute 
-			// (I.e. text for TextObject etc. )
-			pAnimAttr = getSpecificAttributes (iMaxNumberOfFrames, qsProperty);
-			if ( ! pAnimAttr )	{
-				if (qsProperty == QString("pos.x"))	{
-				        FunctionCallback<MenuObject> *callMeBack = new FunctionCallback<MenuObject>(*this, &MenuObject::setPosition, &MenuObject::position, TYPE_POSITION_X );
-					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, position().x(), callMeBack);
-				}
-				else if (qsProperty == QString("pos.y"))	{
-				        FunctionCallback<MenuObject> *callMeBack = new FunctionCallback<MenuObject>(*this, &MenuObject::setPosition, &MenuObject::position, TYPE_POSITION_Y );
-					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, position().y(), callMeBack);
-				}
-				else if (qsProperty == QString("rect.x1"))	{
-					FunctionCallback<QRect> *callMeBack = new FunctionCallback<QRect>(m_rect, &QRect::setX);
-					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_rect.x(), callMeBack);
-				}
-				else if (qsProperty == QString("rect.x2"))	{
-					FunctionCallback<QRect> *callMeBack = new FunctionCallback<QRect>(m_rect, &QRect::setRight);
-					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_rect.right(), callMeBack);
-				}
-				else if (qsProperty == "rect.y1")	{
-					FunctionCallback<QRect> *callMeBack = new FunctionCallback<QRect>(m_rect, &QRect::setY);
-					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_rect.y(), callMeBack);
-				}
-				else if (qsProperty == "rect.y2")	{
-					FunctionCallback<QRect> *callMeBack = new FunctionCallback<QRect>(m_rect, &QRect::setBottom);
-					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_rect.bottom(), callMeBack);
-				}
-				else if (qsProperty == "rect.width")	{
-					FunctionCallback<QRect> *callMeBack = new FunctionCallback<QRect>(m_rect, &QRect::setWidth);
-					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_rect.width(), callMeBack);
-				}
-				else if (qsProperty == "rect.height")	{
-					FunctionCallback<QRect> *callMeBack = new FunctionCallback<QRect>(m_rect, &QRect::setHeight);
- 					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_rect.height(), callMeBack);
-				}
-				else if (qsProperty == "visibleFromTo.startFrame")
-					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_modifiers.iStartFrame, &m_modifiers.iStartFrame);
-				else if (qsProperty == "visibleFromTo.stopFrame")
-					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_modifiers.iStopFrame, &m_modifiers.iStopFrame);
-				else if (qsProperty == "transparency")
-					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_modifiers.fTransparency, &m_modifiers.fTransparency);
-				else if (qsProperty == "zoom")
-					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_modifiers.fZoom, &m_modifiers.fZoom);
-				else if (qsProperty == "rotate")
-					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_modifiers.fRotate, &m_modifiers.fRotate);
-				else if (qsProperty == "shear.x")
- 					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_modifiers.fShearX, &m_modifiers.fShearX);
-				else if (qsProperty == "shear.y")
- 					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_modifiers.fShearY, &m_modifiers.fShearY);
-				else if (qsProperty == "scale.x")
- 					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_modifiers.fScaleX, &m_modifiers.fScaleX);
-				else if (qsProperty == "scale.y")
- 					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_modifiers.fScaleY, &m_modifiers.fScaleY);
-			}
-			if (pAnimAttr)
-				m_listAnimationAttributes.append ( pAnimAttr );
-		}
-		if ( ( pAnimAttr ) && ( ! bFound ) )
-			pAnimAttr->append (iFrameNumber, qsValue);
+	else if (qsProperty == QString("pos.y"))	{
+	  FunctionCallback<MenuObject> *callMeBack = new FunctionCallback<MenuObject>(*this, &MenuObject::setPosition, &MenuObject::position, TYPE_POSITION_Y );
+	  pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, position().y(), callMeBack);
+	  pAnimAttr->setNeedRefresh ( false );
 	}
-	file.close();
+	else if (qsProperty == QString("rect.x1"))	{
+	  FunctionCallback<QRect> *callMeBack = new FunctionCallback<QRect>(m_rect, &QRect::setX);
+	  pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_rect.x(), callMeBack);
+	  pAnimAttr->setNeedRefresh ( false );
+	}
+	else if (qsProperty == QString("rect.x2"))	{
+	  FunctionCallback<QRect> *callMeBack = new FunctionCallback<QRect>(m_rect, &QRect::setRight);
+	  pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_rect.right(), callMeBack);
+	  pAnimAttr->setNeedRefresh ( false );
+	}
+	else if (qsProperty == "rect.y1")	{
+	  FunctionCallback<QRect> *callMeBack = new FunctionCallback<QRect>(m_rect, &QRect::setY);
+	  pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_rect.y(), callMeBack);
+	  pAnimAttr->setNeedRefresh ( false );
+	}
+	else if (qsProperty == "rect.y2")	{
+	  FunctionCallback<QRect> *callMeBack = new FunctionCallback<QRect>(m_rect, &QRect::setBottom);
+	  pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_rect.bottom(), callMeBack);
+	  pAnimAttr->setNeedRefresh ( false );
+	}
+	else if (qsProperty == "rect.width")	{
+	  FunctionCallback<QRect> *callMeBack = new FunctionCallback<QRect>(m_rect, &QRect::setWidth);
+	  pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_rect.width(), callMeBack);
+	  pAnimAttr->setNeedRefresh ( false );
+	}
+	else if (qsProperty == "rect.height")	{
+	  FunctionCallback<QRect> *callMeBack = new FunctionCallback<QRect>(m_rect, &QRect::setHeight);
+	  pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_rect.height(), callMeBack);
+	  pAnimAttr->setNeedRefresh ( false );
+	}
+	else if (qsProperty == "visibleFromTo.startFrame") {
+	  pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_modifiers.iStartFrame, &m_modifiers.iStartFrame);
+	  pAnimAttr->setNeedRefresh ( false );
+	}
+	else if (qsProperty == "visibleFromTo.stopFrame") {
+	  pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_modifiers.iStopFrame, &m_modifiers.iStopFrame);
+	  pAnimAttr->setNeedRefresh ( false );
+	}
+	else if (qsProperty == "transparency")
+	  pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_modifiers.fTransparency, &m_modifiers.fTransparency);
+	else if (qsProperty == "zoom")
+	  pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_modifiers.fZoom, &m_modifiers.fZoom);
+	else if (qsProperty == "rotate")
+	  pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_modifiers.fRotate, &m_modifiers.fRotate);
+	else if (qsProperty == "shear.x")
+	  pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_modifiers.fShearX, &m_modifiers.fShearX);
+	else if (qsProperty == "shear.y")
+	  pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_modifiers.fShearY, &m_modifiers.fShearY);
+	else if (qsProperty == "scale.x") {
+	  pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_modifiers.fScaleX, &m_modifiers.fScaleX);
+	  pAnimAttr->setNeedRefresh ( false );
+	}
+	else if (qsProperty == "scale.y") {
+	  pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_modifiers.fScaleY, &m_modifiers.fScaleY);
+	  pAnimAttr->setNeedRefresh ( false );
+	}
+      }
+      if (pAnimAttr)
+	m_listAnimationAttributes.append ( pAnimAttr );
+    }
+    if ( ( pAnimAttr ) && ( ! bFound ) )
+      pAnimAttr->append (iFrameNumber, qsValue);
+  }
+  file.close();
 }
 
 
