@@ -1,8 +1,10 @@
 /****************************************************************************
 ** MovieObject class
 **
-** Created: Tue Feb 02 22:06:51 2004
-**      by: Varol Okan using Kate
+**   Created : Tue Feb 02 22:06:51 2004
+**        by : Varol Okan using Kate
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 ** This class is the encapsulation of the MovieObject.
 **
@@ -15,12 +17,14 @@
 
 #include <qfileinfo.h>
 #include <qlineedit.h>
+#include <qcheckbox.h>
 #include <qpainter.h>
 #include <qtimer.h>
 #include <qdir.h>
 
 #include "global.h"
 #include "xml_dvd.h"
+#include "qdvdauthor.h"
 #include "dvdmenu.h"
 #include "movieobject.h"
 #include "dragndropcontainer.h"
@@ -30,35 +34,83 @@
 #include "qplayer/mediacreator.h"
 #include "qrender/startmenurender.h"
 
-MovieObject::MovieObject (QWidget *pParent)
-	: ImageObject (pParent)
+MovieObject::MovieObject ( QWidget *pParent )
+  : ImageObject ( pParent )
 {
-	m_qsObjectType  = QString (MOVIE_OBJECT);
-	m_pConvertTimer = NULL;
-	m_pDVDMenu      = NULL;
-	m_bExtracted    = false;
-	m_iMSecPreview  = 0;
+  m_qsObjectType  = QString (MOVIE_OBJECT);
+  m_pConvertTimer = NULL;
+  m_pDVDMenu      = NULL;
+  m_bExtracted    = false;
+  m_bMenuLength   = true; // default to the same length as the menu
+  m_iMSecPreview  = 0;
 }
 
-MovieObject::~MovieObject ()
+MovieObject::~MovieObject ( )
 {
-	if (m_pConvertTimer)	{
-		m_pConvertTimer->stop();
-		delete m_pConvertTimer;
-	}
-	// To make sure that there is no background task 
-	// which wants to create the preview for this object
-	MediaCreator::unregisterFromMediaScanner (this);
+  if ( m_pConvertTimer )  {
+       m_pConvertTimer->stop();
+       delete m_pConvertTimer;
+  }
+  // To make sure that there is no background task 
+  // which wants to create the preview for this object
+  MediaCreator::unregisterFromMediaScanner (this);
+  m_pDVDMenu = NULL;
 }
 
-void MovieObject::setOffset   (QTime &timeOffset)
+void MovieObject::setOffset ( QTime &timeOffset )
 {
-	m_timeOffset = timeOffset;
+  m_timeOffset = timeOffset;
+  createExtractionPath ( );
 }
 
-void MovieObject::setDuration (QTime &timeDuration)
+void MovieObject::setDuration ( QTime &timeDuration )
 {
-	m_timeDuration = timeDuration;
+  m_timeDuration = timeDuration;
+  createExtractionPath ( );
+  if ( dvdMenu ( ) )
+    m_bMenuLength = ( timeDuration == dvdMenu ( )->getInterface ( )->timeDuration );
+}
+
+void MovieObject::setMenuLength ( bool bMenuLength )
+{
+  if ( dvdMenu  ( ) )
+    setDuration ( dvdMenu ( )->getInterface ( )->timeDuration );
+
+  m_bMenuLength = bMenuLength;
+}
+
+void MovieObject::createExtractionPath ( )
+{
+  QString   qsExtractionPath, qsOffset;
+  QFileInfo fileInfo ( fileName ( ) );
+  QTime     zeroTime;
+  char      cBuffer[15];
+
+  qsExtractionPath = fileInfo.baseName ( true );
+  qsOffset         = m_timeOffset.toString ( "hhmmsszzz"  );
+  int iDuration    = zeroTime.msecsTo      ( duration ( ) );
+  sprintf ( cBuffer, "-%07d", iDuration );
+  qsExtractionPath += "-"+qsOffset + cBuffer;
+  setExtractionPath ( qsExtractionPath );  
+}
+
+QString &MovieObject::extractionPath ( )
+{
+  // If this is the same length as the Menu then we should mae sure the extractionPath is
+  // always up-to-date. Else m_qsExtractionPath holds the most recent string.
+  if ( isMenuLength ( ) )
+    createExtractionPath ( );
+  return ImageObject::extractionPath ( );
+}
+
+void MovieObject::setFile ( QString fileName )
+{
+  QString qsTemp;
+  QFileInfo fileInfo ( fileName );
+  qsTemp = fileInfo.fileName  ( );
+  setName ( qsTemp );
+  m_qsFileName = fileName;
+  createExtractionPath ( );
 }
 
 void MovieObject::setMSecPreview ( long iMSecPreview )
@@ -73,7 +125,14 @@ QTime &MovieObject::offset    ()
 
 QTime &MovieObject::duration  ()
 {
-	return m_timeDuration;
+  if ( m_bMenuLength && dvdMenu ( ) )
+    return dvdMenu ( )->getInterface ( )->timeDuration;
+  return m_timeDuration;
+}
+
+bool MovieObject::isMenuLength ( )
+{
+  return m_bMenuLength;
 }
 
 long MovieObject::msecPreview  ()
@@ -92,20 +151,21 @@ void MovieObject::setExtracted (bool bExtracted)
 	m_bExtracted = bExtracted;
 }
 
-void MovieObject::setDVDMenu  (DVDMenu *pDVDMenu, bool bRegisterToRender)
+void MovieObject::setDVDMenu ( DVDMenu *pDVDMenu, bool bRegisterToRender )
 {
-	// Here we associate the DVDMenu with the MovieObject.
-	// This is needed to get all information for the rendering process.
-	DragNDropContainer *pDNDContainer;
+  // Here we associate the DVDMenu with the MovieObject.
+  // This is needed to get all information for the rendering process.
+  DragNDropContainer *pDNDContainer;
 
-	m_pDVDMenu = pDVDMenu;
-	pDNDContainer = pDVDMenu->getDVDAuthor()->getDragNDropContainer();
-	setDragNDropValues (pDNDContainer);
-	if (bRegisterToRender)
-		registerToRender   ();
+  m_pDVDMenu    = pDVDMenu;
+  pDNDContainer = pDVDMenu->getDVDAuthor ( )->getDragNDropContainer ( );
+  setDragNDropValues ( pDNDContainer );
+  setMenuLength   ( true );
+  if ( bRegisterToRender )
+       registerToRender( );
 }
 
-DVDMenu *MovieObject::dvdMenu      ()
+DVDMenu *MovieObject::dvdMenu( )
 {
 	return m_pDVDMenu;
 }
@@ -156,13 +216,16 @@ void MovieObject::timerEvent(QTimerEvent *pTimerEvent)
 {
 	// Called after the background thread has generated the preview ...
 	QSize theSize;
-	switch ( pTimerEvent->timerId() )	{
-	case MEDIASCANNER_EVENT:
-		float fZoom = ((float)m_rect.width() / m_imagePreview.width());
-		theSize = m_imagePreview.size();
-		setZoom (fZoom);
-		setMovieSize (theSize);
-		updatePixmap ();
+	switch ( pTimerEvent->timerId ( ) )	{
+	case MEDIASCANNER_EVENT + 2: // ExecuteJob::TYPE_IMAGE
+		float fZoom = ((float)m_rect.width ( ) / m_imagePreview.width ( ) );
+		theSize = m_imagePreview.size ( );
+		setZoom      ( fZoom );
+		setMovieSize ( theSize );
+		updatePixmap ( );
+		updateShadow ( );
+		if (  shadow ( ) ) // need a refresh to do the shadow correctly.
+		      emit   ( signalUpdatePixmap ( ) );
 	break;
 	}
 }
@@ -190,6 +253,7 @@ void MovieObject::updatePixmap()
 	QImage theImage = m_imagePreview;
 	if (theImage.isNull())
 		return;
+	theImage = theImage.smoothScale ( rect ().width(), rect().height(), QImage::ScaleFree);
 
 	centerPos.setX (rect().x() + (int)((float)rect().width () / 2.0));
 	centerPos.setY (rect().y() + (int)((float)rect().height() / 2.0));
@@ -197,7 +261,6 @@ void MovieObject::updatePixmap()
 	theMatrix.translate ((double)centerPos.x(), (double)centerPos.y());
 	// then we apply the other modifications ...
 	theMatrix.scale  (modifiers()->fScaleX, modifiers()->fScaleY);
-	theMatrix.scale  (manipulator().fZoom, manipulator().fZoom);
 	// Here we create the scaled image ...
 	theImage = theImage.xForm ( theMatrix );
 
@@ -260,7 +323,7 @@ void MovieObject::slotProperties ()
 
 	DialogMovie movieDialog (NULL);
 	connect ( &movieDialog, SIGNAL ( signalSetThumbnail ( long ) ), this, SLOT ( slotSetThumbnail ( long ) ) );
-	movieDialog.initMe(this); 
+	movieDialog.initMe ( this ); 
 	if (movieDialog.exec() == QDialog::Accepted)	{
 		int iX, iY, iWidth, iHeight;
 		iX      = movieDialog.m_pEditX->text().toInt();
@@ -272,9 +335,10 @@ void MovieObject::slotProperties ()
 		// Next we hande the start/stop time.
 		QString qsFormat ("hh:mm:ss.zzz");
 		QTime startingTime, endingTime, duration;
-		startingTime = QTime::fromString (movieDialog.m_pEditStarting2->text());
-		endingTime   = QTime::fromString (movieDialog.m_pEditEnding2->text());
-		if (startingTime.isValid())	{
+		startingTime = QTime::fromString ( movieDialog.m_pEditStarting2->text ( ) );
+		endingTime   = QTime::fromString ( movieDialog.m_pEditEnding2  ->text ( ) );
+		setMenuLength ( movieDialog.m_pCheckSameAsMenuLength->isChecked ( ) );
+		if ( startingTime.isValid ( ) )	{
 			setOffset (startingTime);
 			if (endingTime.isValid ())	{
 				int iMSecs = startingTime.msecsTo  (endingTime);
@@ -306,6 +370,11 @@ void MovieObject::registerToRender ()
 }
 
 void MovieObject::slotStartConverting ()
+{
+  startConverting ( true );
+}
+
+void MovieObject::startConverting ( bool bAllowDialogs )
 {
 	QString qsCommand, qsFullPath, qsMenuName, qsFormat;
 	QFileInfo fileInfo;
@@ -320,9 +389,10 @@ void MovieObject::slotStartConverting ()
 		m_pConvertTimer = NULL;
 	}
 	// first we check if we have valid data.
-	if ( duration () == zeroTime )	{
-		MessageBox::warning(NULL, tr("No time left."), tr("Warning I found a length of 0 for MovieButton <%1>.\nFrom Offset %2 with a duration of %3\n\nPlease adjust Offset or Duration for this Object.").arg(fileName()).arg(offset().toString (qsFormat)).arg(duration().toString(qsFormat)), QMessageBox::Ok, QMessageBox::NoButton);
-		return;
+	if ( duration () == zeroTime )  {
+	  if ( bAllowDialogs )
+	    MessageBox::warning(NULL, tr("No time left."), tr("Warning I found a length of 0 for MovieButton <%1>.\nFrom Offset %2 with a duration of %3\n\nPlease adjust Offset or Duration for this Object.").arg(fileName()).arg(offset().toString (qsFormat)).arg(duration().toString(qsFormat)), QMessageBox::Ok, QMessageBox::NoButton);
+	  return;
 	}
 	// Next we create the directory neccesary ...
 	// Note that for the movies we follow the scheme :ith 
@@ -332,15 +402,16 @@ void MovieObject::slotStartConverting ()
 	if (m_pDVDMenu)
 		qsMenuName = m_pDVDMenu->getInterface()->qsMenuName;
 
-	qsFullPath = QString ("%1/%2/%3/%4").arg(Global::qsTempPath).arg(Global::qsProjectName).arg(qsMenuName).arg(extractionPath());
+	qsFullPath = QString ("%1/%2/%3/%4").arg ( Global::qsTempPath ).arg ( Global::qsProjectName ).arg ( qsMenuName ).arg ( extractionPath ( ) );
 	qsCommand  = QString ("mkdir -p '%1'").arg (qsFullPath);
 	if ( system ((const char *)qsCommand) == -1 )
 		return;
 	// and now we check that the path has been created succesfully
 	theTempDir.setPath (qsFullPath);
 	if (!theTempDir.exists())	{
-		MessageBox::warning(NULL, tr("Could not create Path"), tr("Could not create Path \n%1").arg(qsFullPath), QMessageBox::Ok, QMessageBox::NoButton);
-		return;
+	  if ( bAllowDialogs )
+	    MessageBox::warning(NULL, tr("Could not create Path"), tr("Could not create Path \n%1").arg(qsFullPath), QMessageBox::Ok, QMessageBox::NoButton);
+	  return;
 	}
 
 	// At this point we can pretty much be assured we have the writing permissions necessary.
@@ -352,10 +423,10 @@ void MovieObject::slotStartConverting ()
 
 void MovieObject::setDragNDropValues (DragNDropContainer *pDNDContainer)
 {
-	setOffset  (pDNDContainer->timeStartOffset);
-	setDuration(pDNDContainer->timeDuration);
-	setNiceness(pDNDContainer->iHowNiceShouldIBe);
-	setStartAfterDropEvent(pDNDContainer->bStartAfterDropEvent);
+ setOffset   ( pDNDContainer->timeStartOffset   );
+ setDuration ( pDNDContainer->timeDuration      );
+ setNiceness ( pDNDContainer->iHowNiceShouldIBe );
+ setStartAfterDropEvent ( pDNDContainer->bStartAfterDropEvent );
 }
 
 void MovieObject::setStartAfterDropEvent(bool bStartAfterDropEvent)
@@ -403,6 +474,11 @@ bool MovieObject::readProjectFile  (QDomNode &theNode)
 		QTime timeDuration = QTime::fromString (attribute.value());
 		setDuration (timeDuration);
 	}
+	attribute =  theElement.attributeNode ( MOVIE_OBJECT_MENU_LENGTH );
+	if ( ! attribute.isNull ( ) )
+	  setMenuLength ( ( attribute.value ( ) == "true" ) );
+	else
+	  setMenuLength ( true );
 
 	QDomNode manNode = theNode.firstChild();
 	while (!manNode.isNull())	{
@@ -432,6 +508,7 @@ bool MovieObject::writeProjectFile (QDomElement &theElement)
 		movieNode.setAttribute( MOVIE_OBJECT_FILE_NAME, m_qsFileName );
 	movieNode.setAttribute( MOVIE_OBJECT_OFFSET,   m_timeOffset.toString   (qsFormat) );
 	movieNode.setAttribute( MOVIE_OBJECT_DURATION, m_timeDuration.toString (qsFormat) );
+	movieNode.setAttribute( MOVIE_OBJECT_MENU_LENGTH, m_bMenuLength ? "true" : "false" );
 	movieNode.setAttribute( MOVIE_OBJECT_MSEC_PREVIEW, QString ( "%1" ).arg ( m_iMSecPreview ) );
 	movieNode.setAttribute( MOVIE_OBJECT_SIZE, QString("%1x%2").arg(movieSize().width()).arg(movieSize().height()) );
 
@@ -448,59 +525,67 @@ bool MovieObject::createContextMenu ( QPoint globalPos )
   return ImageObject::createContextMenu ( globalPos );
 }
 
-void MovieObject::createStructure (QListViewItem *pParentItem)
+StructureItem *MovieObject::createStructure ( StructureItem *pParentItem )
 {
-	StructureItem *pButtonItem;
-	QFileInfo fileInfo(m_qsFileName);
-	QString qsName;
+  StructureItem *pTemp=NULL;
+  QFileInfo fileInfo ( m_qsFileName );
+  QString qsName;
 	
-	qsName = QString ("Movie Object");
+  qsName = QString ( "Movie Object" );
 
-	pButtonItem = new StructureItem(this, pParentItem, qsName, fileInfo.fileName());
-	pButtonItem->setExpandable (TRUE);
+  if ( ! m_pStructureItem ) {
+    m_pStructureItem = new StructureItem ( this, pParentItem, pParentItem->lastChild ( ), qsName, fileInfo.fileName ( ) );
+    m_pStructureItem->setExpandable      ( TRUE );
+  }
 
-	ImageObject initialValues;
-	// And finally we create the modifiers info ...
-	manipulator().createStructure (pButtonItem);
-	if ( m_pShadow )
-	     m_pShadow->createStructure ( pButtonItem );
+  ImageObject initialValues;
+  // And finally we create the modifiers info ...
+  pTemp = m_pStructureItem->setSibling ( this, pTemp, tr ("Geometry"),
+		      QString ( "%1, %2, %3, %4" ).arg ( rect ( ).x ( ) ).arg ( rect ( ).y ( ) ).
+		      arg ( rect ( ).width ( ) ).arg( rect ( ).height ( ) ) );
+  
+  pTemp = m_pStructureItem->setSibling ( this, pTemp, tr ("Duration"), duration ( ).toString ( ) );
+  pTemp = m_pStructureItem->setSibling ( this, pTemp, tr ("Offset"), m_timeOffset.toString   ( ) );
 
-	new StructureItem(this, pButtonItem, QString ("Geometry"),
-		QString ("%1, %2, %3, %4").
-		arg(rect().x()).arg(rect().y()).arg(rect().width()).arg(rect().height()));
+  if ( m_pShadow )
+    pTemp = m_pShadow->createStructure ( m_pStructureItem );
+  
+  manipulator ( ).createStructure ( m_pStructureItem );
 
-	new StructureItem(this, pButtonItem, QString ("Duration"), m_timeDuration.toString ());
-	new StructureItem(this, pButtonItem, QString ("Offset"),   m_timeOffset.toString   ());
+  return m_pStructureItem;
 }
 
-MenuObject *MovieObject::clone ( )
+MenuObject *MovieObject::clone ( QWidget *pParent, MenuObject * )
 {
-	MovieObject *pNewObject = new MovieObject (MenuObject::parent());
-	pNewObject->setPixmap      ( pixmap   ( ) );
-	pNewObject->setFile        ( fileName ( ) );
-	pNewObject->setZoom        ( zoom     ( ) );
-	pNewObject->setMSecPreview ( msecPreview ( ) );
-	// The following two are not really needed, since we get those
-	// informations solely from the Normal State - objects ...
-	pNewObject->setRect       (rect());
-	pNewObject->setManipulator(manipulator());
+  if ( !pParent )
+    pParent = MenuObject::parent ( );
+  MovieObject *pNewObject = new MovieObject ( pParent );
+  pNewObject->setPixmap      ( pixmap      ( ) );
+  pNewObject->setFile        ( fileName    ( ) );
+  pNewObject->setZoom        ( zoom        ( ) );
+  pNewObject->setMSecPreview ( msecPreview ( ) );
+  // The following two are not really needed, since we get those
+  // informations solely from the Normal State - objects ...
+  pNewObject->setRect       ( rect         ( ) );
+  pNewObject->setManipulator( manipulator  ( ) );
 //	pNewObject->setModifiers  (*modifiers());
-	pNewObject->setMovieSize  (movieSize());
-	pNewObject->setOffset     (offset());
-	pNewObject->setDuration   (duration());
-	pNewObject->setNiceness   (m_iHowNiceShouldIBe);
-//	pNewObject->setMenuName   (m_qsBelongsToMenuName);
-	pNewObject->setDVDMenu    (m_pDVDMenu, false);
-	pNewObject->setStartAfterDropEvent(m_bStartAfterDropEvent);
-//	QImage  m_imagePreview;	// used to create a preview in a background task.
-//	QTimer *m_pConvertTimer;
-
-	MenuObject *pShadow = shadow ( );
-	if ( pShadow )
-	  pShadow = pShadow->clone ( pNewObject );
-	pNewObject->setShadow      (  pShadow   );
-
-	return pNewObject;
+  pNewObject->setMovieSize  ( movieSize    ( ) );
+  pNewObject->setOffset     ( offset       ( ) );
+  pNewObject->setDuration   ( duration     ( ) );
+  pNewObject->setMenuLength ( isMenuLength ( ) );
+  pNewObject->setNiceness   ( m_iHowNiceShouldIBe);
+  //	pNewObject->setMenuName   (m_qsBelongsToMenuName);
+  pNewObject->setDVDMenu    ( m_pDVDMenu, false );
+  pNewObject->setStartAfterDropEvent ( m_bStartAfterDropEvent );
+  //	QImage  m_imagePreview;	// used to create a preview in a background task.
+  //	QTimer *m_pConvertTimer;
+  
+  MenuObject *pShadow = shadow ( );
+  if ( pShadow )
+    pShadow = pShadow->clone ( pParent, pNewObject );
+  pNewObject->setShadow      ( pShadow );
+  
+  return pNewObject;
 }
 
 void MovieObject::loadPixmap(QString qsFileName)
@@ -578,42 +663,46 @@ void MovieObject::loadPixmap(QString qsFileName)
 
 void MovieObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int iTotalFramesToRender)
 {
-	QString qsFullPath, qsFileName, qsMenuName;
-	int  iCurrentClipFile;
+  QString qsFullPath, qsFileName, qsMenuName;
+  int  iCurrentClipFile;
 
-	// Okay first step is get the fileName of the frame
-	qsMenuName = dvdMenu()->getInterface()->qsMenuName;
+  // Okay first step is get the fileName of the frame
+  qsMenuName = dvdMenu()->getInterface()->qsMenuName;
 //	QFileInfo fileInfo (fileName());
 //	qsFullPath = QString ("%1/%2/%3/%4").arg(Global::qsTempPath).arg(Global::qsProjectName) .arg(qsMenuName).arg(fileInfo.fileName ());
-	qsFullPath = QString ("%1/%2/%3/%4").arg(Global::qsTempPath).arg(Global::qsProjectName) .arg(qsMenuName).arg(extractionPath());
-	QDir theDir (qsFullPath);
-	theDir.setNameFilter ("0*.jpg");
+  qsFullPath = QString ("%1/%2/%3/%4").arg(Global::qsTempPath).arg(Global::qsProjectName) .arg(qsMenuName).arg(extractionPath());
+  QDir theDir (qsFullPath);
+  theDir.setNameFilter ("0*.jpg");
 
 //	// Next is to set the AnimationAttributes
 //	for (t=0;t<m_listAnimationAttributes.count();t++)
 //		m_listAnimationAttributes[t]->setValue (iRenderFrameNumber);
 
-	// So we have the full list of the frames, now we pick the appropriate frame ...
-	iCurrentClipFile = (int)((float)theDir.count() * (float)iRenderFrameNumber/(float)iTotalFramesToRender);
-	qsFileName = QString ("%1/%2").arg(qsFullPath).arg(theDir[iCurrentClipFile]);
-	//printf ("MovieObject::drawContents <%s> <%s> <%d> <%d>\n", (const char *)qsFileName, (const char *)qsFileName, theDir.count(), iCurrentClipFile);
-	loadPixmap (qsFileName);
-	//then we call 
-	ImageObject::drawContents(pPainter, iRenderFrameNumber, iTotalFramesToRender);
+  // So we have the full list of the frames, now we pick the appropriate frame ...
+  iCurrentClipFile = (int)((float)theDir.count() * (float)iRenderFrameNumber/(float)iTotalFramesToRender);
+  qsFileName = QString ("%1/%2").arg(qsFullPath).arg(theDir[iCurrentClipFile]);
+  //printf ("MovieObject::drawContents <%s> <%s> <%d> <%d>\n", (const char *)qsFileName, (const char *)qsFileName, theDir.count(), iCurrentClipFile);
+  loadPixmap (qsFileName);
+  // if we have an animation, then the shadow is updated in the imageobject ...
+  if ( m_listAnimationAttributes.count ( ) < 1 )
+    updateShadow ( );
+
+  // then we call 
+  ImageObject::drawContents(pPainter, iRenderFrameNumber, iTotalFramesToRender);
 }
 
 AnimationAttribute *MovieObject::getSpecificAttributes (long iMaxNumberOfFrames, QString qsProperty)
 {
-	AnimationAttribute *pAnimAttr = NULL;
-	static int m_iTestInt;
-	// first check the base class ...
-	pAnimAttr = ImageObject::getSpecificAttributes( iMaxNumberOfFrames, qsProperty);
-	if ( ! pAnimAttr )	{
-		if (qsProperty == "frameNo")
-			pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_iTestInt, &m_iTestInt);
-	}
-
-	return pAnimAttr;
+  AnimationAttribute *pAnimAttr = NULL;
+  static int m_iTestInt;
+  // first check the base class ...
+  pAnimAttr = ImageObject::getSpecificAttributes( iMaxNumberOfFrames, qsProperty);
+  if ( ! pAnimAttr )	{
+    if (qsProperty == "frameNo")
+      pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_iTestInt, &m_iTestInt);
+  }
+  
+  return pAnimAttr;
 }
 
 
