@@ -1,8 +1,10 @@
 /****************************************************************************
 ** ObjectCollection class 
 **
-** Created: Tue Feb 02 22:06:51 2004
-**      by: Varol Okan using Kate
+**   Created : Tue Feb 02 22:06:51 2004
+**        by : Varol Okan using Kate
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 ** This class is the encapsulation of the ObjectCollection.
 **
@@ -77,6 +79,32 @@ void ObjectCollection::append (MenuObject *pNewObject, bool bDeleteThisObject)
     m_listObjectCollection.append ( new Collection ( pNewObject, bDeleteThisObject ) );
 }
 
+bool ObjectCollection::contains ( MenuObject *pObject )
+{
+  uint t;
+  for ( t=0;t<m_listObjectCollection.count ();t++) {
+    if ( m_listObjectCollection[t]->pObject == pObject )
+      return true;
+  }
+  return false;
+}
+
+MenuObject *ObjectCollection::clone ( QWidget *pParent, MenuObject * )
+{
+  if ( ! pParent )
+    pParent = MenuObject::parent ( );
+
+  ObjectCollection *pNewObject = new ObjectCollection ( pParent );
+  MenuObject       *pObject;
+  uint t;
+  for ( t=0; t<m_listObjectCollection.count (); t++) {
+    pObject = m_listObjectCollection[t]->pObject->clone ( pParent, pNewObject );
+    pNewObject->append ( pObject );
+  }
+
+  return pNewObject;
+}
+
 void ObjectCollection::drawContents (QPainter *pPainter)
 {
   // Here we simply pass the painter to the attached objects. No magic here !!!
@@ -120,6 +148,22 @@ bool ObjectCollection::mouseReleaseEvent ( QMouseEvent * )
   return false;
 }
 
+void ObjectCollection::setShadow ( MenuObject *pShadow ) 
+{
+  // In this function we'll create a new shadow object for each object in the list.
+  // and then take control of the ObjectCollections shadow object itself
+  uint t;
+  MenuObject *pNewShadow = NULL;
+
+  for (t=0;t<m_listObjectCollection.count();t++) {
+    if ( pShadow )
+         pNewShadow = pShadow->clone ( );
+    //printf ( "%s::%s::%d  Shadow<%p> for object<%p\n", __FILE__, __FUNCTION__, __LINE__, pNewShadow, m_listObjectCollection[t]->pObject );
+    m_listObjectCollection[t]->pObject->setShadow ( pNewShadow );
+  }
+  MenuObject::setShadow ( pShadow );
+}
+
 void ObjectCollection::slotToFront ()
 {
   // Send it all the way to the front
@@ -144,7 +188,6 @@ void ObjectCollection::slotToBack ()
   m_pContextMenu = NULL;
 }
 
-
 bool ObjectCollection::mouseDoubleClickEvent (QMouseEvent *)
 {
   return false;
@@ -164,9 +207,13 @@ bool ObjectCollection::createContextMenu (QPoint globalPos)
 {
   QPoint globalPos2 = globalPos;
   QPopupMenu *pStackMenu = new QPopupMenu(m_pParent);
+  pStackMenu->insertItem ( tr ("Cut") , this, SLOT ( slotCut  ( ) ) );
+  pStackMenu->insertItem ( tr ("Copy"), this, SLOT ( slotCopy ( ) ) );
+  pStackMenu->insertSeparator ( );
   pStackMenu->insertItem ( tr ("To Front")  , this, SLOT(slotToFront()));
   pStackMenu->insertItem ( tr ("To Back")   , this, SLOT(slotToBack()));
-  globalPos.setX (globalPos.x() - pStackMenu->sizeHint().width()); // -100);
+  globalPos.setY ( globalPos.y ( ) - 25 );
+  globalPos.setX ( globalPos.x ( ) - pStackMenu->sizeHint().width()); // -100);
   pStackMenu->popup(globalPos, 1);
   
   if (m_pContextMenu)
@@ -194,142 +241,25 @@ bool ObjectCollection::createContextMenu (QPoint globalPos)
   return true;
 }
 
-void ObjectCollection::createStructure (QListViewItem *pParentItem)
+StructureItem *ObjectCollection::createStructure ( StructureItem *pParentItem )
 {
   // Creating teh ListView structure of this Button.
-  StructureItem *pCollectionItem;
-  QString qsCollection = tr("Collection of %1").arg(m_listObjectCollection.count());
+  QString qsCollection = tr("Collection of %1").arg(m_listObjectCollection.count ( ) );
   
-  pCollectionItem = new StructureItem(this, pParentItem, m_qsName, qsCollection);
-  pCollectionItem->setExpandable (TRUE);
+  if ( ! m_pStructureItem )  {
+    m_pStructureItem = new StructureItem ( this, pParentItem, m_qsName, qsCollection );
+    m_pStructureItem->setExpandable (TRUE);
+  }
+  else
+    m_pStructureItem->setText ( m_qsName, qsCollection );
   
   uint t;
-  for (t=0;t<m_listObjectCollection.count();t++)	{
-    m_listObjectCollection[t]->pObject->createStructure (pCollectionItem);
-  }
-}
-/*
-bool ButtonObject::readProjectFile  (QDomNode &theNode)
-{
-	// Okay, here we retain the stored data from the xml file.
-	QDomElement theElement = theNode.toElement();
-	QDomAttr attribute;
+  for ( t=0; t<m_listObjectCollection.count ( ); t++ )
+    m_listObjectCollection[t]->pObject->createStructure ( m_pStructureItem );
 
-	attribute = theElement.attributeNode ( BUTTON_OBJECT_NAME );
-	if (!attribute.isNull())
-		m_qsName = attribute.value();
-
-	attribute = theElement.attributeNode ( BUTTON_OBJECT_ACTION );
-	if (!attribute.isNull())
-		m_qsAction = attribute.value();
-
-	attribute = theElement.attributeNode ( BUTTON_OBJECT_UP );
-	if (!attribute.isNull())
-		m_qsUp = attribute.value();
-
-	attribute = theElement.attributeNode ( BUTTON_OBJECT_DOWN );
-	if (!attribute.isNull())
-		m_qsDown = attribute.value();
-
-	attribute = theElement.attributeNode ( BUTTON_OBJECT_LEFT );
-	if (!attribute.isNull())
-		m_qsLeft = attribute.value();
-
-	attribute = theElement.attributeNode ( BUTTON_OBJECT_RIGHT );
-	if (!attribute.isNull())
-		m_qsRight = attribute.value();
-
-	attribute = theElement.attributeNode ( BUTTON_OBJECT_SOURCE_ENTRY);
-	if (!attribute.isNull())
-		m_qsSourceDisplayName = attribute.value();
-	// Please note that the nortmal / selected / highlighted objects are read
-	// in by ButtonObject::readObjects(...);
-//printf ("ButtonObject::readProjectFile <%s> \n", (const char *)m_qsSourceDisplayName);
-	return true;
+  return m_pStructureItem;
 }
 
-bool ButtonObject::writeProjectFile (QDomElement &theElement)
-{
-	uint t;
-	QDomDocument xmlDoc = theElement.ownerDocument();
-	QDomElement buttonNode = xmlDoc.createElement( BUTTON_OBJECT );	// <FrameObject>
-	// Here we set the attributes of the <dvdauthor> tag
-	if (!m_qsName.isNull())
-		buttonNode.setAttribute( BUTTON_OBJECT_NAME,   m_qsName );
-	if (!m_qsAction.isNull())
-		buttonNode.setAttribute( BUTTON_OBJECT_ACTION, m_qsAction );
-	if (!m_qsUp.isNull())
-		buttonNode.setAttribute( BUTTON_OBJECT_UP,     m_qsUp );
-	if (!m_qsDown.isNull())
-		buttonNode.setAttribute( BUTTON_OBJECT_DOWN,   m_qsDown );
-	if (!m_qsLeft.isNull())
-		buttonNode.setAttribute( BUTTON_OBJECT_LEFT,   m_qsLeft );
-	if (!m_qsRight.isNull())
-		buttonNode.setAttribute( BUTTON_OBJECT_RIGHT,  m_qsRight );
-	if (m_pSourceFileEntry)
-		buttonNode.setAttribute( BUTTON_OBJECT_SOURCE_ENTRY,  m_pSourceFileEntry->qsDisplayName );
-//printf ("ButtonObject::writeProjectFile <%s> - <%s> \n", (const char *)m_pSourceFileEntry->qsDisplayName, (const char *)m_qsAction );
-
-	// And here we store the ButtonObjects children ...
-	QDomElement normalNode = xmlDoc.createElement( BUTTON_OBJECT_NORMAL );
-	for (t=0;t<m_listNormalState.count();t++)
-		m_listNormalState[t]->writeProjectFile ( normalNode );
-
-	QDomElement selectedNode = xmlDoc.createElement( BUTTON_OBJECT_SELECTED );
-	for (t=0;t<m_listSelectedState.count();t++)
-		m_listSelectedState[t]->writeProjectFile ( selectedNode );
-
-	QDomElement highlightedNode = xmlDoc.createElement( BUTTON_OBJECT_HIGHLIGHTED );
-	for (t=0;t<m_listHighlightedState.count();t++)
-		m_listHighlightedState[t]->writeProjectFile ( highlightedNode );
-
-	buttonNode.appendChild( normalNode );
-	buttonNode.appendChild( selectedNode );
-	buttonNode.appendChild( highlightedNode );
-	
-	theElement.appendChild( buttonNode );
-	// And here we write the base class ...
-	return MenuObject::writeProjectFile( buttonNode );
-}
-
-void ButtonObject::createStructure (QListViewItem *pParentItem)
-{
-	// Creating teh ListView structure of this Button.
-	QListViewItem *pButtonItem;
-	QListViewItem *pStateItem;
-
-	QString qsAction;
-	QStringList actionList;
-	if (!m_qsAction.isEmpty())	{	// For new buttons this might be empty ...
-		actionList = QStringList::split (QString (STRING_SEPARATOR), m_qsAction);
-		if (actionList.count() == 1)	
-			qsAction = m_qsAction;
-		else	{
-			qsAction = actionList[0] + QString (" ") +actionList[1] + QString (" ") +actionList[2];
-			if (actionList.count() == 4)
-				qsAction += QString (" ") +actionList[3];
-		}
-	}
-	pButtonItem = new QListViewItem(pParentItem, m_qsName, qsAction);
-	pButtonItem->setExpandable (TRUE);
-
-	uint t;
-	for (t=0;t<m_listHighlightedState.count();t++)	{
-		pStateItem = new QListViewItem(pButtonItem, QString ("Highlighted"), QString (""));
-		pStateItem->setExpandable (TRUE);
-		m_listHighlightedState[t]->createStructure (pStateItem);
-	}
-	for (t=0;t<m_listSelectedState.count();t++)	{
-		pStateItem = new QListViewItem(pButtonItem, QString ("Selected"), QString (""));
-		pStateItem->setExpandable (TRUE);
-		m_listSelectedState[t]->createStructure (pStateItem);
-	}
-	for (t=0;t<m_listNormalState.count();t++)	{
-		m_listNormalState[t]->createStructure (pButtonItem);
-	}
-}
-
-*/
 void ObjectCollection::slotEdit()
 {
 	mouseDoubleClickEvent(NULL);
@@ -342,7 +272,6 @@ void ObjectCollection::slotDelete()
 
 void ObjectCollection::slotAddFrame()
 {
-
 }
 
 void ObjectCollection::slotAddText()
