@@ -1,8 +1,10 @@
 /****************************************************************************
 ** Interface to the GUI.
 **
-** Created: Sun Feb 23 21:45:00 2004
-**      by: Varol Okan using kate editor
+**   Created : Sun Feb 23 21:45:00 2004
+**        by : Varol Okan using kate editor
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 **  pure virtual class as base for the three button types.
 **
@@ -41,8 +43,10 @@ public:
 
 	virtual bool readProjectFile       ( QDomNode      & );
 	virtual bool writeProjectFile      ( QDomElement   & );
-	virtual void createStructure       ( QListViewItem * );
 	virtual bool createContextMenu     ( QPoint          );
+	virtual StructureItem *createStructure ( StructureItem * );
+	virtual MenuObject *clone          ( QWidget *p1=NULL, MenuObject *p2=NULL );
+	virtual void setShadow             ( MenuObject *    );
 
 public:
 	int         getCount               ( );
@@ -51,11 +55,11 @@ public:
 	bool readObjects                   ( QDomNode &, MenuPreview * );
 	void deleteAllObjects              ( bool);
 	void append                        ( MenuObject *, bool b=true );
+	bool contains                      ( MenuObject * );
 	void clear                         ( );
 
 signals:
 	void signalDefineAsButton          ( MenuObject * );
-	void signalDeleteMe                ( MenuObject * );
 
 public slots:
 	virtual void slotToFront           ( );
@@ -64,6 +68,7 @@ public slots:
 protected slots:
 	virtual void slotEdit              ( );
 	virtual void slotDelete            ( );
+	//	virtual void slotAddShadow         ( );
 	virtual void slotAddFrame          ( );
 	virtual void slotAddText           ( );
 	virtual void slotAddImage          ( );
