@@ -1,8 +1,10 @@
 /****************************************************************************
 3** Interface to the GUI.
 **
-** Created: Sun Dec 14 12:09:08 2003
-**      by: Varol Okan using kate editor
+**   Created : Sun Dec 14 12:09:08 2003
+**        by : Varol Okan using kate editor
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 ** This class generates the command line for dvdauthor.
 ** Current Version of DVDAUTHOR used is 0.67
@@ -16,14 +18,14 @@
 
 class QDomNode;
 class QDomElement;
-class QListViewItem;
 class QTranslator;
 class QPopupMenu;
 class QTimer;
 class QListBox;
 class QPopupMenu;
 
-#include ".ui/formmain.h"
+#include "formmain.h"
+#include "plugins/interface.h"
 
 class ButtonObject;
 class ColorToolBar;
@@ -31,12 +33,15 @@ class SourceToolBar;
 class StructureToolBar;
 class SourceFileEntry;
 class SourceFileInfo;
+class Subtitles;
 class SubtitlesGui;
+class StructureItem;
 class DVDMenu;
 class MediaInterface;
 class MediaInfo;
 class uiDialogRenderPreview;
 class DialogExecute;
+class DialogLibrary;
 class TemplateWizard;
 class CXmlDVDAuthor;
 class CXmlSpumux;
@@ -44,6 +49,7 @@ class CXmlSpumux;
 #define DVDAUTHOR_XML "dvdauthor.xml"
 #define SUBTITLES_TAB "Subtitles"
 
+#include "rgba.h"
 #include "utils.h"
 #include "dragndropcontainer.h"
 
@@ -56,46 +62,50 @@ public:
 	~QDVDAuthor ();
 
 public slots:
-	virtual void fileNew();
-	virtual void fileOpen();
-	virtual void fileSave();
-	virtual void fileSave(QString);
-	virtual void fileSaveAs();
-	virtual void filePrint();
-	virtual void fileExit();
-	virtual void editUndo();
-	virtual void editRedo();
-	virtual void editCut();
-	virtual void editPaste();
-	virtual void editFind();
-	virtual void helpIndex();
-	virtual void helpContents();
-	virtual void helpAbout();
+	virtual void fileNew      ( );
+	virtual void fileOpen     ( );
+	virtual void fileSave     ( );
+	virtual void fileSave     ( QString, bool b=false );
+	virtual void fileSaveAs   ( );
+	virtual void fileExit     ( );
+	virtual void editUndo     ( );
+	virtual void editRedo     ( );
+	virtual void editCut      ( );
+	virtual void editPaste    ( );
+	virtual void editFind     ( );
+	virtual void helpIndex    ( );
+	virtual void helpContents ( );
+	virtual void helpGuide    ( );
+	virtual void helpAbout    ( );
 
 	virtual void polish                          ( );
 	virtual void slotAutosave                    ( );
-	virtual void slotChangeLanguage          ( int );
+	virtual void slotPluginCallback ( int, QString, QString );
+	virtual void slotActivatePlugin              ( );
+	virtual void slotActivatePlugin         (  int );
+	virtual void slotChangeLanguage         (  int );
 	virtual void slotVisibleRegion          ( bool );
 	virtual void slotSetup                       ( );
 	virtual void slotDialogTemp                  ( );
 	virtual void slotTemplateDownload            ( );
 	virtual void slotExportDVDAuthorXML          ( );
 	virtual void slotEditAddMovie                ( );
+	virtual void slotAddFromLibrary              ( );
 	virtual void slotEditAddSlideshow            ( );
-	virtual void slotStructureClicked ( QListViewItem *);
+	virtual void slotStructureClicked ( StructureItem * );
 	virtual void slotGenerateMasks               ( );
 	virtual void slotCreateDVD                   ( );
-	virtual void slotCreateSVCD                  ( );
-	virtual void slotCreateVCD                   ( );
 	virtual void slotAddSubMenu                  ( );
 	virtual void slotAddFiles                    ( );
 	virtual void slotAddDirectory                ( );
 	virtual void slotAddFromTemplate             ( );
+	virtual void slotOneClickDVD                 ( );
 	virtual void slotFeedback                    ( );
 	virtual void slotTabChanged        ( QWidget * );
 	virtual void slotRemoveCurrentSubMenu        ( );
 	virtual void slotDeleteTemplateWizard        ( );
 	virtual void slotRenameCurrentSubMenu        ( );
+	virtual void slotCloneCurrentSubMenu         ( );
 	virtual void slotUndoStack                   ( );
 	virtual void slotUpdateStructure             ( );
 	virtual void slotDeleteTempOlderThan         ( );
@@ -107,6 +117,8 @@ public slots:
 	virtual void slotCalculateSize               ( );
 	virtual void slotImportKino                  ( );
 	virtual void slotImportDvdauthor             ( );
+	virtual void slotConvert                     ( );
+	virtual void slotConvertCurrentMenu     ( bool );
 	virtual void slotAboutToShowMenu             ( );
 signals:
 	void signalVisibleRegion (bool);
@@ -124,12 +136,14 @@ public:
 	SourceFileEntry *sourceFileEntry                 ( uint );
 	SourceFileEntry *getSourceEntryByDisplayName( QString & );
 	void appendSourceFileEntry          ( SourceFileEntry * );
-	void removeSourceFileEntry          ( SourceFileEntry * ); // called to remove the SourceFileEntry
-	void removedSourceEntry             ( SourceFileEntry * );    // called after entry has been removed from SourceToolBar
+	void removeSourceFileEntry          ( SourceFileEntry * );  // called to remove the SourceFileEntry
+	void removedSourceEntry             ( SourceFileEntry * );  // called after entry has been removed from SourceToolBar
+	void updateSourceFileInfo           ( SourceFileInfo  * );
 	void replaceSourceDisplayName    ( QString &, QString & );
 	bool isSourceEntryUsed                      ( QString & );
 	void addSound                           ( QStringList & );
-	void setColor                            ( uint, QColor );
+	void setColor                              ( uint, Rgba );
+	void updateStatusColor                                ( ); // updates the SourceToolBar color's
 	MediaInfo *getMediaInfo                               ( );
 	DragNDropContainer *getDragNDropContainer             ( );
 	
@@ -152,15 +166,15 @@ private: 	// Private functions ...
 	void newWizard              ( );
 	void buildHistoryEntries    ( );
 	void updateHistoryPix       (  );
-	void initLanguages          (    );
-	void initStyles             (      );
-	void initSubtitlesTab       (        );
-	void addHistory             ( QString  );
-	bool readProjectFile        ( QDomNode & );
+	void initPlugins            (   );
+	void initLanguages          (     );
+	void initStyles             (       );
+	void initSubtitlesTab       (         );
+	void addHistory             ( QString   );
 	bool writeProjectFile       ( QDomElement &);
 	void setAutosave            ( bool b=false   );
-	void renderSubtitles        ( SourceFileInfo * );
-	QRect getSubtitlesRect      ( SourceFileInfo * );
+	bool readProjectFile        ( QDomNode &, float & );
+	bool renderSubtitles        ( SourceFileInfo *, bool b=false );
 	bool buildFromDvdauthorXML  ( CXmlDVDAuthor *, QValueList<CXmlSpumux *> & );
 	void createTempDirStructure ( );
 	void createDvdauthorXml     ( );
@@ -171,8 +185,6 @@ private: 	// Private functions ...
 	QString getTempFile         (QString);
 
 private:
-	// Here we store the path to the different tools required.
-	QValueList<Utils::toolsPaths *>  m_listToolsPaths;
 	bool    m_bVisibleRegion;
 
 	DVDMenu *m_pVMGMenu;
@@ -183,10 +195,10 @@ private:
 	int                     m_iMaxHistoryFiles;
 	int                     m_iAutosave;	// Autosave every x seconds ...
 	QString                 m_qsStyle;
-	QString                 m_qsLanguage;
 	QTimer                 *m_pTimerAutosave;
 	bool                    m_bAutosaving;
-	
+
+	Plugin::Interface      *m_pPluginInterface;
 	ColorToolBar           *m_pColorToolbar;
 	SourceToolBar          *m_pSourceToolbar;
 	StructureToolBar       *m_pStructureToolbar;
@@ -195,9 +207,18 @@ private:
 	bool                    m_bModified;
 	QTranslator            *m_pTranslator;
 	QPopupMenu             *m_pLanguagePopup;
+	QPopupMenu             *m_pPluginsPopup;
 	QPopupMenu             *m_pStylesPopup;
 	DialogExecute          *m_pDialogExecute;
+	DialogLibrary          *m_pDialogLibrary;
 	TemplateWizard         *m_pTemplateWizard;
+
+	QToolBar *m_pToolbar;
+	QAction  *m_pActionToolbarNew;
+	QAction  *m_pActionToolbarOpen;
+	QAction  *m_pActionToolbarSave;
+	QAction  *m_pActionToolbarSaveAs;
+	QAction  *m_pActionToolbarExit;
 };
 
 #endif // QDVDAUTHOR_H
