@@ -1,3 +1,13 @@
+/****************************************************************************
+  ** QDVDAuthorInit - class
+  **
+  **   Created :
+  **        by : Varol Okan using kate editor
+  ** Copyright : (c) Varol Okan
+  **   License : GPL v 2.0
+  **
+  **
+  ****************************************************************************/
 
 // File qdvdauthorinit.h
 
@@ -5,7 +15,7 @@
 #define QDVDAUTHORINIT_H
 
 // This is the version number for the Init-file
-#define INIT_VERSION  2.0
+#define INIT_VERSION  2.5
 
 #define AUTOSAVE_FILE_NAME "/.qdvdauthor/autosave.xml"
 #define INIT_DIR_NAME  "/.qdvdauthor/"
@@ -62,6 +72,7 @@
 #define ATTRIB_NAME              "name"
 #define ATTRIB_COLOR             "color"
 #define ATTRIB_DEFAULT           "default"
+#define ATTRIB_FOREACH           "foreachinput"
 #define ATTRIB_BLOCKNAME         "blockname"
 
 #define BLOCK_MOVIE_CONVERT    "MOVIE_CONVERT"
@@ -73,6 +84,7 @@
 #define BLOCK_MPLEX            "MPLEX"
 #define BLOCK_SPUMUX           "SPUMUX"
 #define BLOCK_OTHERS           "OTHERS"
+#define SUB_BLOCK_VIDEOTRANS   "Videotrans"
 #define SUB_BLOCK_TRANSCODE    "Transcode"
 #define SUB_BLOCK_MENCODER     "MEncoder"
 
@@ -81,7 +93,8 @@
 #include "keyword.h"
 #include "utils.h"
 
-class DragnDropContainer;
+class TranscodeInterface;
+class DragNDropContainer;
 class SourceFileEntry;
 
 class QDVDAuthorInit
@@ -93,14 +106,15 @@ private:
 			class Block
 			{
 				public:
-				 Block ()
-					{ iDefaultCommand = 0; iBlockID = -1; iActive = -1; bHidden = false; bEditable = true;};
-				~Block ()
-					{ for (uint t=0;t<listSubBlocks.count();t++) delete listSubBlocks[t]; };
+				 Block ( )
+				  { iDefaultCommand = 0; iBlockID = -1; iActive = -1; bHidden = false; bEditable = true; };
+				~Block ( )
+				  { for (uint t=0;t<listSubBlocks.count();t++) delete listSubBlocks[t]; };
 				QString     qsBlockTag;
 				int         iActive;
 				int         iBlockID;
 				int         iDefaultCommand;
+
 				bool        bHidden;
 				bool        bEditable;
 				QStringList listComments;
@@ -110,10 +124,12 @@ private:
 			class SubBlock
 			{
 				public:
-				 SubBlock () { iNumber=0; };
+				 SubBlock () { iNumber=0;  iForEachInput = -1; };
 				~SubBlock () { for (uint t=0;t<listBlocks.count();t++) delete listBlocks[t];};
 				QString     qsName;	// Name. E.g. Transcode
 				int         iNumber;	// running number starting from 0. In case we need to sort it.
+				int         iForEachInput;   // this command is to be repeated for each input file (E.g. +AUDIO_LIST+)
+				
 				QValueList<Block *>listBlocks;
 			};
 			MenuBlock ();
@@ -149,41 +165,44 @@ public:
 	int                               maxHistoryFiles   ( );
 	int                               getAutosave       ( );
 	QString                           getStyle          ( );
-	QString                           getLanguage       ( );
 	QString                          &getTemplateAuthor ( );
 	QString                          &getTemplateContact( );
-	void setStyle              ( QString );
-	void setLanguage           ( QString );
-	void setTemplateAuthor     ( QString & );
-	void setTemplateContact    ( QString & );
-	void setAutosave           ( int  );
-	void setVisibleRegion      ( bool );
-	void setHistory            ( int, QStringList, QValueList<QPixmap *> );
-	void appendPreProcessing   ( );
-	void appendConvert         ( SourceFileEntry * );
-	void appendMenu            ( DVDMenu *, QString, QString );
-	void appendPostProcessing  ( );
-	bool readIniFile           ( );
-	bool saveIniFile           ( );
-	bool firstApplicationStart ( );
-	void setDefault            ( int, uint);
+	void setStyle                 ( QString );
+	void setTemplateAuthor        ( QString & );
+	void setTemplateContact       ( QString & );
+	void setAutosave              ( int  );
+	void setVisibleRegion         ( bool );
+	void setHistory               ( int, QStringList, QValueList<QPixmap *> );
+	void appendPreProcessing      ( );
+	void appendConvert            ( SourceFileEntry * );
+	void appendConvertAudioTracks ( SourceFileEntry * );
+	void appendMenu               ( DVDMenu *, QString, QString );
+	void appendPostProcessing     ( );
+	bool readIniFile              ( );
+	bool saveIniFile              ( );
+	bool firstApplicationStart    ( );
+	void setDefault               ( int, uint);
 	QDVDAuthorInit::MenuBlock::Block *getBlock ( int, int *pi=NULL );
-	Keyword *getKeyword        ( );
+	Keyword *getKeyword           ( );
 
 private:	// private functions.
 	bool    initMe ();
-	void    addBlock      (ExecuteInterface *, MenuBlock::Block *);
-	bool    readBlock     (MenuBlock::Block *, QDomElement *);
-	bool    readSubBlock  (MenuBlock::SubBlock *, QDomElement *pElem);
-	bool    readMenuBlock (MenuBlock *, QDomElement *);
-	bool    saveMenuBlock (MenuBlock *, QDomElement *);
-	bool    saveBlock     (MenuBlock::Block *, QDomElement *);
-	bool    saveSubBlock  (MenuBlock::SubBlock *, QDomElement *);
-	int     printBlock    (MenuBlock::Block *, int i=0);
-//	bool    saveSubBlock (MenuBlock::Block *, QDomElement *, bool);
+	void    setAudioAttributes ( SourceFileInfo   *, TranscodeInterface *, QString *p=NULL, int i=0 );
+	void    addMenuAudioBlock  ( ExecuteInterface *, TranscodeInterface *, SourceFileEntry *, MenuBlock::Block * );
+	void    addMenuBlock  ( ExecuteInterface *, MenuBlock::Block *, Keyword::enKeyBase e=Keyword::Keys );
+	void    addSubBlock   ( ExecuteInterface *, MenuBlock::Block *, Keyword::enKeyBase e=Keyword::Keys );
+	void    addBlock      ( ExecuteInterface *, MenuBlock::Block *, Keyword::enKeyBase e=Keyword::Keys );
+	bool    readBlock     ( MenuBlock::Block *,    QDomElement * );
+	bool    readSubBlock  ( MenuBlock::SubBlock *, QDomElement * );
+	bool    readMenuBlock ( MenuBlock *, QDomElement * );
+	bool    saveMenuBlock ( MenuBlock *, QDomElement * );
+	bool    saveBlock     ( MenuBlock::Block *, QDomElement * );
+	bool    saveSubBlock  ( MenuBlock::SubBlock *, QDomElement * );
+	int     printBlock    ( MenuBlock::Block *, int i=0 );
 	QString convertSoundFile (QString);
 	void    resetInitFile ();
 	void    mergeToolsPaths (QValueList<Utils::toolsPaths *>);
+	void    handleMultipleSubtitles ( SourceFileInfo *, QString & );
 
 	void printCommandList ( char * );
 
@@ -197,10 +216,9 @@ private:	// private variables
 	QString              m_qsTemplateContact;
 	QString              m_qsTempPath;
 	QString              m_qsStyle;
-	QString              m_qsLanguage;
 	QString              m_qsProjectPath;
 	QString              m_qsDvdauthorFile;
-	QValueList<QColor *> m_arrayColors;
+	QValueList<Rgba *>   m_arrayColors;
 	int                  m_iColorCounter;
 	MenuBlock            m_convertMenuBlock;
 	MenuBlock            m_subtitlesMenuBlock;
@@ -214,6 +232,7 @@ private:	// private variables
 	int                  m_iMaxHistoryFiles;
 	int                  m_iAutosave;
 	QStringList          m_soundList;
+	QStringList          m_listAudioFiles; // to prevent double transcoding of audio files.
 	Keyword              m_keyword;
 	// Pre processing steps
 	ExecuteInterface m_convertInterface;        // Also incl Subtitles.
