@@ -94,6 +94,22 @@ void DummyWidget::setPositionByTime(uint)
 {
 }
 
+void DummyWidget::setNavigate ( enNavigate )
+{
+}
+
+void DummyWidget::setMenu( enMenu )
+{
+}
+
+void DummyWidget::setSubtitleTrack ( int )
+{
+}
+
+void DummyWidget::setAudioTrack ( int )
+{
+}
+
 float DummyWidget::volume ()
 {
 	return 0.0f;
