@@ -76,18 +76,18 @@ void MPlayerWidget::playMRL (const QString qsMRL)
 
 bool MPlayerWidget::openMRL (const QString qsMRL)
 {
-	if (m_qsMRL != qsMRL)	{
-		// set the filename
-		setFilename (qsMRL);
-		// The we create som information about the stream ...
-		if (m_pMediaInfo)
-			delete m_pMediaInfo;
-		m_pMediaInfo = new MPlayerInfo;
-		m_pMediaInfo->setFileName (qsMRL);
-//printf ("MPlayerWidget::openMRL <%s><%s><%s>\n", (const char *)m_qsMRL, (const char *)qsMRL, (const char *)m_pMediaInfo->getFileName ());
-		m_qsMRL = qsMRL;
-	}
-	return true;
+  if ( m_qsMRL != qsMRL )	{
+    // set the filename
+    setFilename ( qsMRL );
+    // The we create som information about the stream ...
+    if ( m_pMediaInfo )
+      delete m_pMediaInfo;
+    m_pMediaInfo = new MPlayerInfo;
+    m_pMediaInfo->setFileName ( qsMRL );
+    //printf ("MPlayerWidget::openMRL <%s><%s><%s>\n", (const char *)m_qsMRL, (const char *)qsMRL, (const char *)m_pMediaInfo->getFileName ());
+    m_qsMRL = qsMRL;
+  }
+  return true;
 }
 
 void MPlayerWidget::play ()
@@ -99,7 +99,8 @@ void MPlayerWidget::play ()
 void MPlayerWidget::pause()
 {
 	slotPause ();
-	m_bPaused = true;
+	//m_bPaused = true;
+	m_bPaused = m_bInPauseMode;
 }
 
 void MPlayerWidget::stop ()
@@ -116,6 +117,12 @@ void MPlayerWidget::setSpeed(float fValue)
 		QMPlayerWidget::slotSetSpeed (fValue);
 }
 
+void MPlayerWidget::setVolume(float fValue)
+{
+  // MPlayer static volume range is between [0 and 100] %
+  QMPlayerWidget::slotSetVolume( fValue * 100.0 );
+}
+/*
 void MPlayerWidget::setVolume(float fValue)
 {
   // MPlayer takes values above 1.0 as positive
@@ -130,7 +137,7 @@ void MPlayerWidget::setVolume(float fValue)
     QMPlayerWidget::slotSetVolume( fValue );
   bEveryOther = bEveryOther ? false : true;
 }
-
+*/
 void MPlayerWidget::setPosition(uint iPosition)
 {
 	// iPosition defined as [0 .. 65535]
@@ -149,6 +156,26 @@ void MPlayerWidget::setPositionByTime(uint iPosition)
 //	slotSeek ((float)iPosition, 2);
 }
 
+void MPlayerWidget::setNavigate ( enNavigate nav )
+{
+  slotNavigate ( ( int) nav );
+}
+
+void MPlayerWidget::setMenu ( enMenu menu )
+{
+  slotMenu ( (int) menu );
+}
+
+void MPlayerWidget::setSubtitleTrack ( int iTrackNumber )
+{
+  slotSubtitleTrack ( iTrackNumber );
+}
+
+void MPlayerWidget::setAudioTrack ( int iTrackNumber )
+{
+  slotAudioTrack ( iTrackNumber );
+}
+
 float MPlayerWidget::volume ()
 {
 	return 0.0f;
