@@ -55,6 +55,11 @@ public slots:
 	void slotSetSeek(int);
 	void slotScreenshot();
 
+	void slotNavigate      ( int );
+	void slotMenu          ( int );
+	void slotSubtitleTrack ( int );
+	void slotAudioTrack    ( int );
+
 	void setAspectRatio (uint);
 	void playChapter(int);	// 0=current / -x-=play x chapters before / +x=play current chapter + x
 	bool isPlaying();
