@@ -2,8 +2,8 @@
                            videowindow.cpp 
                            -------------------
     begin                : Fre Apr 18 2003
-    revision             : $Revision: 1.81 $
-    last modified        : $Date: 2006/01/13 05:04:19 $ by $Author: qdvdauthor $
+    revision             : $Revision: 1.84 $
+    last modified        : $Date: 2007/04/06 04:03:18 $ by $Author: qdvdauthor $
     copyright            : (C) 2003-2004 by J. Kofler
     email                : kaffeine@gmx.net
  ***************************************************************************/
@@ -549,7 +549,7 @@ void QXineWidget::XineEventListener(void *p, const xine_event_t* xineEvent)
                *++d = '\0';
 
                message = d;
-               delete d;
+               delete []d;
                break;
              }
            case XINE_MSG_GENERAL_WARNING:
@@ -873,7 +873,10 @@ void QXineWidget::run()
      {
        if (event.xexpose.count == 0)
        {
-         xine_gui_send_vo_data (xineStream, XINE_GUI_SEND_EXPOSE_EVENT, &event);
+//		  if ( ( XINE_MAJOR_VERSION <= 1 ) && ( XINE_MINOR_VERSION < 2 ) )
+//		    xine_gui_send_vo_data ( xineStream, XINE_GUI_SEND_EXPOSE_EVENT, &event );
+//		  else
+		    xine_port_send_gui_data (videoDriver, XINE_GUI_SEND_EXPOSE_EVENT, &event);
        }
      }
 
@@ -1003,11 +1006,11 @@ bool QXineWidget::taskInitXine()
 /** set xine parameters **/
 
   const char* const* drivers = NULL;
-  char** audioChoices = NULL;
+  char* audioChoices[15]; // = NULL;
   int i = 0;
 
   drivers = xine_list_audio_output_plugins (xineEngine);
-  audioChoices = new char*[15];
+  //audioChoices = new char*[15];
   for(i = 0; i < 15; i++) audioChoices[i] = new char[10];
   audioChoices[0] = const_cast<char*>("auto");
   i = 0;
@@ -1033,9 +1036,9 @@ bool QXineWidget::taskInitXine()
   debugOut(QString("Use audio driver %1\n").arg(audioDriverName));
 
   i = 0;
-  char** videoChoices = NULL;
+  char* videoChoices[15]; // = NULL;
   drivers = xine_list_video_output_plugins (xineEngine);
-  videoChoices = new char*[15];
+//  videoChoices = new char*[15];
   for(i = 0; i < 15; i++) videoChoices[i] = new char[10];
   i = 0;
   videoChoices[0] = const_cast<char*>("auto");
@@ -1453,9 +1456,10 @@ void QXineWidget::mouseMoveEvent(QMouseEvent* mev)
     rect.w = 0;
     rect.h = 0;
 
-    xine_gui_send_vo_data (xineStream,
-               XINE_GUI_SEND_TRANSLATE_GUI_TO_VIDEO,
-                (void*)&rect);
+//	if ( ( XINE_MAJOR_VERSION <= 1 ) && ( XINE_MINOR_VERSION < 2 ) )
+//	  xine_gui_send_vo_data ( xineStream, XINE_GUI_SEND_TRANSLATE_GUI_TO_VIDEO, (void *)&rect );
+//	else
+	  xine_port_send_gui_data ( videoDriver, XINE_GUI_SEND_TRANSLATE_GUI_TO_VIDEO, (void *)&rect );
 
     event.type        = XINE_EVENT_INPUT_MOUSE_MOVE;
     event.data        = &input;
@@ -1503,9 +1507,11 @@ void QXineWidget::mousePressEvent(QMouseEvent* mev)
      rect.w = 0;
      rect.h = 0;
 
-     xine_gui_send_vo_data (xineStream,
-                XINE_GUI_SEND_TRANSLATE_GUI_TO_VIDEO,
-                   (void*)&rect);
+
+//	 if ( ( XINE_MAJOR_VERSION <= 1 ) && ( XINE_MINOR_VERSION < 2 ) )
+//	   xine_gui_send_vo_data (xineStream, XINE_GUI_SEND_TRANSLATE_GUI_TO_VIDEO, (void*)&rect );
+//	 else
+	   xine_port_send_gui_data ( videoDriver, XINE_GUI_SEND_TRANSLATE_GUI_TO_VIDEO, (void*)&rect );
 
      event.type        = XINE_EVENT_INPUT_MOUSE_BUTTON;
      event.data        = &input;
@@ -2261,6 +2267,8 @@ void QXineWidget::slotHideMouse()
 
 void QXineWidget::GetScreenshot(uchar*& rgb32BitData, int& videoWidth, int& videoHeight, double& scaleFactor)
 {
+  if ( ! xineStream )
+	return;
   uint8_t   *yuv = NULL, *y = NULL, *u = NULL, *v =NULL;
   
   int        width, height, ratio, format;
