@@ -30,7 +30,7 @@ void VLCInfo::queryValues ()
 	printf ("VLCInfo::queryValues\n");
 }
 
-QImage VLCInfo::getScreenshot(uint)
+QImage VLCInfo::getScreenshot( long )
 {
 	return QImage ();
 }
