@@ -49,6 +49,8 @@ public:
 	virtual QString supportedExtensions();
 	virtual QImage getScreenshot       ();
 	virtual QImage getScreenshot(float f  = 0.0f);
+	virtual bool   setScreenshot ( long );
+	virtual bool   setScreenshot ( QPixmap & );
 
 	// Functions handled in the MediaInterface - calss
 	const QString& getMRL();
