@@ -348,7 +348,7 @@ char * XineInfo::get_fourcc_string (int f)
 	fcc[4] = 0;
 
 	if (f <= 0xFFFF)
-		sprintf (fcc, "0x%x", f);
+		snprintf (fcc, 5, "0x%x", f);
 		
 	if  ( (fcc[0] == 'm') && (fcc[1] == 's') )
 	{
@@ -366,9 +366,10 @@ xine_stream_t *XineInfo::getXineStream ()
 
 QImage XineInfo::getScreenshot ( long iMSecOffset )
 {
-	xine_open(m_pXineStream, (const char *)m_qsFileName);
+	if ( ! xine_open ( m_pXineStream, (const char *)m_qsFileName ) ) 
+		return getScreenshot ( m_qsFileName );
 	if (iMSecOffset == 0)
-		return getScreenshot (m_qsFileName);
+		return getScreenshot ( m_qsFileName );
 	// first we try the trick mode ... Ooops not implemented, will crash QDVDAuthor. Maybe in the future.
 	int iTricky = 0; // xine_trick_mode (m_pXineStream, XINE_TRICK_MODE_SEEK_TO_TIME, iStartTime * 1000);
 	if (iTricky == 0)	{	// Input does not support the trick mode, 
