@@ -54,10 +54,13 @@ QPlayer::QPlayer( QWidget* parent, const char* name, WFlags fl )
 {
 	MediaCreator::setPreferredEngine (QString ("DummyWidget"));
 	m_iIsPlaying = STATE_STOPPED;
+	m_iSubtitleTrack   = -1;
+	m_iAudioTrack      = -1;
+	m_bIgnoreSliderPos = false;
 	// Next we will create the ComboBox in the MenuBar ...
-	m_pMediaInterface = NULL;
-	m_pLanguagePopup  = NULL;
-	m_pTranslator     = NULL;
+	m_pMediaInterface  = NULL;
+	m_pLanguagePopup   = NULL;
+	m_pTranslator      = NULL;
 	initLanguages();
 	m_pToolBarPrevious  = new QToolBar (QString("Previous"), this, DockTop);
 	m_pToolBarPrevious->setHorizontalStretchable ( true );
@@ -74,15 +77,16 @@ QPlayer::QPlayer( QWidget* parent, const char* name, WFlags fl )
 	m_pVideoLayout = new QGridLayout( m_pFramePreview, 1, 1, 4, 6, "XineMainLayout");
 	m_pVideoLayout->addWidget (m_pMediaInterface->getWidget(), 0, 0);
 
-	fileOpenAction->addTo( toolBar );
-	fileOpenPrevious->addTo( toolBar );
-	fileExitAction->addTo( toolBar );
-	m_pActionAbout->addTo( toolBar );
+	fileOpenAction->addTo      ( toolBar );
+	fileOpenPrevious->addTo    ( toolBar );
+	fileExitAction->addTo      ( toolBar );
+	m_pActionScreenshot->addTo ( toolBar );
+	m_pActionAbout->addTo      ( toolBar );
 
 	m_pSliderTime->setRange (0, 65535);
 	m_fSpeed = 1.0;
 	
-	m_pSliderVolume->setRange(-100, 0);
+	m_pSliderVolume->setRange(0, 100);
 	m_pSliderVolume->setValue(-80);
 
 	m_pButtonPrev      ->setPaletteBackgroundColor (QColor (COLOR_QUICK_NORMAL));
@@ -101,16 +105,28 @@ QPlayer::QPlayer( QWidget* parent, const char* name, WFlags fl )
 
 	editCopyAction  ->setIconSet( QIconSet( QPixmap::fromMimeSource( "editcopy" ) ) );
 	fileExitAction  ->setIconSet( QIconSet( QPixmap::fromMimeSource( "exit.png" ) ) );
-	fileOpenPrevious->setIconSet( QIconSet( QPixmap::fromMimeSource( "filenew" ) ) );
-	fileOpenAction  ->setIconSet( QIconSet( QPixmap::fromMimeSource( "fileopen" ) ) );
-	fileSaveAction  ->setIconSet( QIconSet( QPixmap::fromMimeSource( "filesave" ) ) );
-	filePrintAction ->setIconSet( QIconSet( QPixmap::fromMimeSource( "print" ) ) );
+	fileOpenPrevious->setIconSet( QIconSet( QPixmap::fromMimeSource( "new.png" ) ) );
+	fileOpenAction  ->setIconSet( QIconSet( QPixmap::fromMimeSource( "open.png" ) ) );
+	fileSaveAction  ->setIconSet( QIconSet( QPixmap::fromMimeSource( "save.png" ) ) );
 	editRedoAction  ->setIconSet( QIconSet( QPixmap::fromMimeSource( "redo" ) ) );
 	editCutAction   ->setIconSet( QIconSet( QPixmap::fromMimeSource( "editcut" ) ) );
 	editPasteAction ->setIconSet( QIconSet( QPixmap::fromMimeSource( "editpaste" ) ) );
 	editFindAction  ->setIconSet( QIconSet( QPixmap::fromMimeSource( "searchfind" ) ) );
 	m_pActionScreenshot->setIconSet( QIconSet( QPixmap::fromMimeSource( "desktop.png" ) ) );
 	
+	// The buttons fro the DVD menu guidance.
+	connect ( m_pButtonUp,            SIGNAL ( clicked ( ) ), this, SLOT ( slotUp            ( ) ) );
+	connect ( m_pButtonDown,          SIGNAL ( clicked ( ) ), this, SLOT ( slotDown          ( ) ) );
+	connect ( m_pButtonLeft,          SIGNAL ( clicked ( ) ), this, SLOT ( slotLeft          ( ) ) );
+	connect ( m_pButtonRight,         SIGNAL ( clicked ( ) ), this, SLOT ( slotRight         ( ) ) );
+	connect ( m_pButtonSet,           SIGNAL ( clicked ( ) ), this, SLOT ( slotSet           ( ) ) );
+	connect ( m_pButtonRoot,          SIGNAL ( clicked ( ) ), this, SLOT ( slotRoot          ( ) ) );
+	connect ( m_pButtonTitle,         SIGNAL ( clicked ( ) ), this, SLOT ( slotTitle         ( ) ) );
+	connect ( m_pButtonSubtitleMinus, SIGNAL ( clicked ( ) ), this, SLOT ( slotSubtitleMinus ( ) ) );
+	connect ( m_pButtonSubtitlePlus,  SIGNAL ( clicked ( ) ), this, SLOT ( slotSubtitlePlus  ( ) ) );
+	connect ( m_pButtonAudioMinus,    SIGNAL ( clicked ( ) ), this, SLOT ( slotAudioMinus    ( ) ) );
+	connect ( m_pButtonAudioPlus,     SIGNAL ( clicked ( ) ), this, SLOT ( slotAudioPlus     ( ) ) );
+
 	connect (m_pButtonPrev,       SIGNAL(clicked()), this, SLOT(slotPrev()));
 	connect (m_pButtonNext,       SIGNAL(clicked()), this, SLOT(slotNext()));
 	connect (m_pButtonStop,       SIGNAL(clicked()), this, SLOT(slotStop()));
@@ -118,7 +134,8 @@ QPlayer::QPlayer( QWidget* parent, const char* name, WFlags fl )
 	connect (m_pButtonSpeedPlus,  SIGNAL(clicked()), this, SLOT(slotSpeedPlus()));
 	connect (m_pButtonSpeedMinus, SIGNAL(clicked()), this, SLOT(slotSpeedMinus()));
 	connect (m_pSliderVolume,     SIGNAL(valueChanged(int)), this, SLOT(slotSetVolume(int)));
-	connect (m_pSliderTime,       SIGNAL(sliderReleased()), this, SLOT(slotSeekPosition()));
+	connect (m_pSliderTime,       SIGNAL(sliderPressed ( ) ), this, SLOT(slotStartSeekPos ( ) ) );
+	connect (m_pSliderTime,       SIGNAL(sliderReleased( ) ), this, SLOT(slotSeekPosition ( ) ) );
 	
 	connect (m_pComboPrevious,    SIGNAL(activated(int)), this, SLOT(slotHistory(int)));
 
@@ -397,11 +414,6 @@ void QPlayer::getImage(uint /* iFrameNumber */)
 void QPlayer::polish ()
 {
 	QWidget::polish ();
-//	sleep (1);
-//	m_pMediaInterface->getWidget()->polish ();
-//	sleep (1);
-//	show ();
-//	sleep (1);
 	
 	if (m_pMediaInterface)	{
 		m_pMediaInterface->initMediaEngine ();
@@ -415,6 +427,84 @@ void QPlayer::slotHistory(int iSelected)
 	addFileToHistory(m_qsFileName);
 }
 
+void QPlayer::slotUp ( )
+{
+  if ( m_pMediaInterface )
+       m_pMediaInterface->setNavigate ( MediaInterface::NavigateUp );
+}
+
+void QPlayer::slotDown ( )
+{
+  if ( m_pMediaInterface )
+       m_pMediaInterface->setNavigate ( MediaInterface::NavigateDown );
+}
+
+void QPlayer::slotLeft ( )
+{
+  if ( m_pMediaInterface )
+       m_pMediaInterface->setNavigate ( MediaInterface::NavigateLeft );
+}
+
+void QPlayer::slotRight ( )
+{
+  if ( m_pMediaInterface )
+       m_pMediaInterface->setNavigate ( MediaInterface::NavigateRight );
+}
+
+void QPlayer::slotSet ( )
+{
+  if ( m_pMediaInterface )
+       m_pMediaInterface->setNavigate ( MediaInterface::NavigateSelect );
+}
+
+void QPlayer::slotRoot ( )
+{
+  if ( m_pMediaInterface )
+       m_pMediaInterface->setMenu ( MediaInterface::MenuRoot );
+}
+
+void QPlayer::slotTitle ( )
+{
+  if ( m_pMediaInterface )
+       m_pMediaInterface->setMenu ( MediaInterface::MenuTitle );
+}
+
+void QPlayer::slotSubtitleMinus ( )
+{
+  m_iSubtitleTrack --;
+  if ( m_iSubtitleTrack < 0 )
+    m_iSubtitleTrack = -1;
+  if ( m_pMediaInterface )
+       m_pMediaInterface->setSubtitleTrack ( m_iSubtitleTrack );
+}
+
+void QPlayer::slotSubtitlePlus ( )
+{
+  m_iSubtitleTrack ++;
+  if ( m_iSubtitleTrack > 31 )
+    m_iSubtitleTrack = 31;
+  if ( m_pMediaInterface )
+       m_pMediaInterface->setSubtitleTrack ( m_iSubtitleTrack );
+}
+
+void QPlayer::slotAudioMinus ( )
+{
+  m_iAudioTrack --;
+  if ( m_iAudioTrack < 0 )
+    m_iAudioTrack = -1;
+  if ( m_pMediaInterface )
+       m_pMediaInterface->setAudioTrack ( m_iAudioTrack );
+}
+
+void QPlayer::slotAudioPlus ( )
+{
+  m_iAudioTrack ++;
+  if ( m_iAudioTrack > 7 )
+    m_iAudioTrack = 7;
+  if ( m_pMediaInterface )
+       m_pMediaInterface->setAudioTrack ( m_iAudioTrack );
+}
+
 void QPlayer::slotPrev ()
 {
 	if (m_pMediaInterface->hasChapters())
@@ -435,7 +525,7 @@ void QPlayer::slotStop ()
 	colorMovieButtons (m_pButtonStop);
 	m_pButtonPlay->setPixmap (QPixmap ().fromMimeSource("play.png"));
 	m_iIsPlaying = STATE_STOPPED;
-	m_pSliderTime->setValue(0);
+	m_pSliderTime->setValue ( 0 );
 }
 
 void QPlayer::slotPlay ()
@@ -505,7 +595,7 @@ void QPlayer::slotPlaybackFinished ()
 {
 	colorMovieButtons (m_pButtonStop);
 	m_pButtonPlay->setPixmap (QPixmap ().fromMimeSource("play.png"));
-	m_pSliderTime->setValue(0);
+	m_pSliderTime->setValue ( 0 );
 	m_iIsPlaying = STATE_STOPPED;
 }
 
@@ -520,8 +610,9 @@ void QPlayer::colorMovieButtons (void *pButton)
 void QPlayer::slotNewPosition (int iPos, const QString& qsTime)
 {
   // iPos [0 .. 65535]
-//printf (" QPlayer::slotNewPosition <%d><%s>\n", iPos, (const char *)qsTime);
-  m_pSliderTime->setValue (iPos);
+  //printf (" QPlayer::slotNewPosition <%d><%s> Ignore<%d>\n", iPos, (const char *)qsTime, m_bIgnoreSliderPos );
+  if ( ! m_bIgnoreSliderPos )
+    m_pSliderTime->setValue ( iPos );
   m_pLabelTime->setText (QString("<p align=\"center\">%1</p>").arg(qsTime));
 }
 
@@ -589,15 +680,26 @@ void QPlayer::slotMediaInfo ()
 	bool hasAudio ();
 	bool hasVideo ();
 */
-void QPlayer::slotSetVolume (int /*iVolume*/)
+void QPlayer::slotSetVolume (int iVolume)
 {
-//v	xine_set_param(m_pMediaWidget->GetStream(), XINE_PARAM_AUDIO_VOLUME, -iVolume);
+  float fValue = (float)(100 - iVolume) / 100.0;
+  //  printf ( "QPlayer::slotSetVolume <%f>\n", fValue );
+  if ( m_pMediaInterface )
+       m_pMediaInterface->setVolume ( fValue );
+}
+
+void QPlayer::slotStartSeekPos ()
+{
+  m_bIgnoreSliderPos = true;
 }
 
 void QPlayer::slotSeekPosition ()
 {
-//v	int iPosition = m_pSliderTime->value();
-//v	m_pMediaWidget->slotChangePosition(iPosition);
+  int iPosition = m_pSliderTime->value ( );
+  //printf ( "QPlayer::slotSeekPosition <%d>\n", iPosition );
+  if ( m_pMediaInterface )
+       m_pMediaInterface->setPosition ( iPosition );
+  m_bIgnoreSliderPos = false;
 }
 
 void QPlayer::fileOpenRecent()
@@ -611,10 +713,26 @@ void QPlayer::fileExit()
 
 void QPlayer::slotScreenshot()
 {
-	QImage screenShot = m_pMediaInterface->getScreenshot ();
+	Utils theUtils;
+	long iMsecOffset  = 0;
+	QString qsCurrent = m_pLabelTime->text (); //QString("<p align=\"center\">%1</p>").arg(qsTime));
+printf ( "<%s> ", qsCurrent.ascii () );
+	qsCurrent.remove ( "<p align=\"center\">" );
+	qsCurrent.remove ( "</p>" );
+	iMsecOffset = theUtils.getMsFromString ( qsCurrent );
+printf ( "%ld %s\n", iMsecOffset, qsCurrent.ascii() );
+//	MediaInfo *pMediaInfo = m_pMediaInterface->getMediaInfo ( );
+
+	QImage screenShot;
+//	if ( pMediaInfo )
+//		screenShot = pMediaInfo->getScreenshot ( iMsecOffset );
+//	else
+		screenShot = m_pMediaInterface->getScreenshot ( (float)(iMsecOffset / 1000.0f) );
 	
-	if (screenShot.isNull())
-		return;
+	if (screenShot.isNull()) {
+	  printf ( "Could not create screenshot\n" );
+	  return;
+	}
 	
 	QString qsFileName = QFileDialog::getSaveFileName("./", tr("Images (*.png *.xpm *.jpg)"), this, tr("save file Dialog"), tr("Save Screenshot under ..."));
 
