@@ -69,6 +69,7 @@
 
 #include <qdir.h>
 #include <qtimer.h>
+#include <qlabel.h>
 #include <qregexp.h>
 #include <qdatetime.h>
 #include <qmessagebox.h>
@@ -262,10 +263,10 @@ int StartMenuRender::checkStatusFile (QString qsFullPath)
 void StartMenuRender::renderMovieObject ()
 {
 	QFileInfo fileInfo;
-	int iStatusCheck;
-	
-	QString qsFullPath, qsMenuName, qsCommand, qsOffset, qsDuration, qsFormat;
-	qsFormat = QString ("hh:mm:s.zzz");
+	int     iStatusCheck;
+	QTime   timeEndpos, zeroTime;
+	QString qsFullPath, qsMenuName, qsCommand, qsOffset, qsEndpos, qsFormat;
+	qsFormat = QString ("hh:mm:ss.zzz");
 	// This is the separate thread which extracts the images of the movie clips for this menu
 	// (after generating the status / xml - files)
 	// First we should generate the directories to store the data in ...
@@ -275,7 +276,7 @@ void StartMenuRender::renderMovieObject ()
 	if (m_pMovieObject->dvdMenu())
 		qsMenuName = m_pMovieObject->dvdMenu()->getInterface()->qsMenuName;
 
-	qsFullPath = QString ("%1/%2/%3/%4").arg(Global::qsTempPath).arg(Global::qsProjectName).arg(qsMenuName).arg(m_pMovieObject->extractionPath());
+	qsFullPath = QString ("%1/%2/%3/%4").arg ( Global::qsTempPath ).arg ( Global::qsProjectName ).arg ( qsMenuName ).arg ( m_pMovieObject->extractionPath ( ) );
 
 	// Okay we should check the status file ...
 	iStatusCheck = checkStatusFile (qsFullPath);
@@ -293,13 +294,45 @@ void StartMenuRender::renderMovieObject ()
 
 	statusStream << QString ("-+-+-+-+-+-+ Starting new extraction of file %1 -+-+-+-+-+-+ \n").arg(m_pMovieObject->fileName());
 
-	qsOffset   = m_pMovieObject->offset  ().toString (qsFormat);
-	qsDuration = m_pMovieObject->duration().toString (qsFormat);
-	statusStream << "[00] " << qsOffset << " " << qsDuration << "\n";
+	qsOffset   = m_pMovieObject->offset   ( ).toString ( qsFormat );
+	//timeEndpos = m_pMovieObject->offset   ( ).addMSecs ( zeroTime.msecsTo ( m_pMovieObject->duration( ) ) );
+	// endpos is duration in conjunction with -ss
+	qsEndpos   = m_pMovieObject->duration ( ).toString ( qsFormat );
+	statusStream << "[00] " << qsOffset << " " << qsEndpos << "\n";
 	statusFile.flush();
 
-	// 1) Cleaning the movie material ...
+	// 1) extracting the wanted time frame ...
+	//    mencoder -oac pcm -ovc lavc -ss 0 -endpos 10 -o "snl/clip.avi" "snl/clean.avi"
+	qsCommand = QString ("mencoder -oac pcm -ovc lavc -ss %1 -endpos %2 -o \"%3/clip.avi\" \"%4\" 2>/dev/null").arg(qsOffset).arg(qsEndpos).arg(qsFullPath).arg( m_pMovieObject->fileName ( ) );
+	statusStream << "[01] " << QDate::currentDate().toString() << " " << QTime::currentTime().toString() << " cmd > " << qsCommand << "\n";
+	statusFile.flush();
+	if (iStatusCheck < 2)  {
+		if ( system (qsCommand) == -1 ) 
+			return;
+	}
+	fileInfo.setFile(qsFullPath + QString ("/clip.avi"));
+	if (fileInfo.exists())
+		statusStream << "[02] Okay.\n";
+	else
+		statusStream << "[02] Error.\n";
+
+	// 2) Cleaning the movie material ...
 	//    mencoder -oac pcm -ovc lavc -o "snl/clean.avi" "./snl.mpg" 
+	qsCommand = QString ("mencoder -oac pcm -ovc lavc -o \"%1/clean.avi\" \"%2/clip.avi\" 2>/dev/null").arg(qsFullPath).arg( qsFullPath );
+	statusStream << "[03] " << QDate::currentDate().toString() << " " << QTime::currentTime().toString() << " cmd > " << qsCommand << "\n";
+	statusFile.flush();
+	if (iStatusCheck < 1)  {
+		if ( system (qsCommand) == -1 )
+			return;
+	}
+	fileInfo.setFile(qsFullPath + QString ("/clean.avi"));
+	if ( (fileInfo.exists()) || (iStatusCheck > 0) )
+		statusStream << "[04] Okay.\n";
+	else
+		statusStream << "[04] Error.\n";
+/*
+	// 1) Cleaning the movie material ...
+	//    mencoder -oac pcm -ovc lavc -o "snl/clean.avi" "./snl.mpg"
 	qsCommand = QString ("mencoder -oac pcm -ovc lavc -o \"%1/clean.avi\" \"%2\" 2>/dev/null").arg(qsFullPath).arg(m_pMovieObject->fileName());
 	statusStream << "[01] " << QDate::currentDate().toString() << " " << QTime::currentTime().toString() << " cmd > " << qsCommand << "\n";
 	statusFile.flush();
@@ -320,17 +353,19 @@ void StartMenuRender::renderMovieObject ()
 	statusFile.flush();
 	if (iStatusCheck < 2)  {
 		if ( system (qsCommand) == -1 ) 
-			return;
-	}
+			return; 
+	} 
 	fileInfo.setFile(qsFullPath + QString ("/clip.avi"));
 	if (fileInfo.exists())
 		statusStream << "[04] Okay.\n";
 	else
 		statusStream << "[04] Error.\n";
-
+*/
 	// 3) extracting audio (audiodump.wav) : 
 	//    mplayer -ao pcm -vo null -vc dummy -aofile "snl/clip.wav" "snl/clip.avi"
-	qsCommand = QString ("mplayer -ao pcm -vo null -vc dummy -aofile \"%1/clip.wav\" \"%2/clip.avi\" 2>/dev/null").arg(qsFullPath).arg(qsFullPath);
+	// mplayer changed switches ... so no more aofile=...
+	//qsCommand = QString ("mplayer -ao pcm -vo null -vc dummy -aofile \"%1/clip.wav\" \"%2/clip.avi\" 2>/dev/null").arg(qsFullPath).arg(qsFullPath);
+	qsCommand = QString ("mplayer -ao pcm:file=\"%1/clean.wav\" -vo null -vc dummy \"%2/clean.avi\" 2>/dev/null").arg(qsFullPath).arg(qsFullPath);
 	statusStream  << "[05] " << QDate::currentDate().toString() << " " << QTime::currentTime().toString() << " cmd > " << qsCommand << "\n";
 	statusFile.flush();
 	if (iStatusCheck < 3)  {
@@ -351,7 +386,7 @@ void StartMenuRender::renderMovieObject ()
 			return;
 	}
 		
-	qsCommand = QString ("mplayer -ao null -vo jpeg:outdir=\"%1\" \"%2/clip.avi\" 2>/dev/null").arg(qsFullPath).arg(qsFullPath);
+	qsCommand = QString ("mplayer -ao null -vo jpeg:outdir=\"%1\" \"%2/clean.avi\" 2>/dev/null").arg(qsFullPath).arg(qsFullPath);
 	statusStream  << "[07] " << QDate::currentDate().toString() << " " << QTime::currentTime().toString() << " cmd > " << qsCommand << "\n";
 	statusFile.flush();
 	if (iStatusCheck < 4)  {
