@@ -138,14 +138,15 @@ bool DialogCreate::sanityCheck()
 {
 	// first we check if we can write to the temp directory specified ...
 	QString qsTestFile = m_pEditTempDir->text() + QString("/writeCheck.txt");
-	QFile theFile(qsTestFile);
-	theFile.open(IO_WriteOnly);
-	QTextStream theStream( &theFile );
-	theStream << "Test" << "\n";
-	theFile.close ();
+	QFile theFile ( qsTestFile );
+	if ( theFile.open ( IO_WriteOnly ) ) {
+	  QTextStream theStream( &theFile );
+	  theStream << "Test" << "\n";
+	  theFile.close ();
+	}
 
-	QFileInfo fileInfo (qsTestFile);
-	if (!fileInfo.exists())	{
+	QFileInfo fileInfo ( qsTestFile );
+	if ( ! fileInfo.exists ( ) )	{
 		QMessageBox::about (NULL, tr ("Could not write"),
 		tr ("Attention, I could not write to the temp directory.\n\n"
 			"Please make sure the name is correct and you have read/write\n"
@@ -359,7 +360,8 @@ void DialogCreate::createDVDSlideshowFile()
 //	QString qsSlideshowFile = m_pEditTempDir->text() + QString ("/slideshow.in");
 	QString qsSlideshowFile = m_pEditTempDir->text() + QString ("/") + m_pEditSlideshowTitle->text() + QString (".in");
 	QFile theFile (qsSlideshowFile);
-	theFile.open (IO_WriteOnly);
+	if ( ! theFile.open (IO_WriteOnly) )
+	  return;
 	QTextStream theStream( &theFile );
 	int iDelay = m_Slideshow.delay;
 	int iFilterDelay = m_Slideshow.filter_delay;
