@@ -311,7 +311,14 @@ void CSlideDialog::slotListRightMouseClicked( QListBoxItem *, const QPoint &poin
 
 void CSlideDialog::slotSelectionChanged()
 {
-	previewImage (m_pListTable->currentItem());
+  previewImage ( m_pListTable->currentItem ( ) );
+  uint t;
+  for ( t=0;t<m_pListTable->count ( ); t++ ) {
+    if ( m_pListTable->isSelected ( t ) ) {
+      m_pButtonDelete->setEnabled ( TRUE );
+      return;
+    }
+  }
 }
 
 void CSlideDialog::slotUpdateListInfo()
@@ -420,4 +427,39 @@ CXmlSlideshow &CSlideDialog::createFilterSlideshow ()
 	return theSlideshow;
 }
 
+void CSlideDialog::slotDelete()
+{
+  uint t, i;
+  QString   qsTemp;
+  QFileInfo fileInfo;
+  QValueList<QListBoxItem *> list;
+  // Make sure we leave at least one image ...
+  if ( m_pListTable->count ( ) < 2 )
+    return;
+
+  for ( t=0;t<m_pListTable->count ( ); t++ ) {
+    if ( m_pListTable->isSelected ( t ) ) {
+      list.append(m_pListTable->item( t ) );
+    }
+  }
+  for ( t=0; t<list.count ( ); t++ ) {
+    qsTemp = list[t]->text ( );
+    for ( i=0; i<m_Slideshow.countImg ( ); i++ ) {
+      CXmlSlideshow::img_struct *pImg = m_Slideshow.getImg ( i );
+      if ( pImg ) { 
+	fileInfo.setFile ( pImg->src );
+	if ( fileInfo.fileName ( ) == qsTemp ) {
+	  // delete entry from QStringLIst and m_Slideshow ...
+	  m_slideshowFiles.remove ( pImg->src );
+	  m_pPreview->resetImage ( );
+	  m_Slideshow.delImg ( pImg );
+	  break; // exit inner loop
+	}
+      }
+    }
+    // delete entry from ListBox ...
+    delete list[t];
+  }
+}
+
 
