@@ -86,9 +86,9 @@ void ImagePreview::setBackground ( QString &fileName, bool bRefresh )
   setFixedSize(m_background.width(), m_background.height());
   // Before we go on we should calculate the correct m_iStartX, and m_iStartY
   if ( (m_manipulator.fStartX == 0.0 ) && (m_manipulator.fStartY == 0.0) ) {
-    if (m_background.width() > m_image.width())
+    if (m_background.width () > m_image.width ( ) )
       m_manipulator.fStartX = ((m_background.width()-m_image.width())/2.0)/m_background.width();
-    if (m_background.height() > m_image.height())
+    if (m_background.height() > m_image.height ( ) )
       m_manipulator.fStartY = ((m_background.height()-m_image.height())/2.0)/m_background.height();
   }
   if (bRefresh)
@@ -128,6 +128,11 @@ void ImagePreview::setImage (QPixmap &theImage, ImageManipulator *pManipulator)
 	rotate (0.0, false);
 }
 
+void ImagePreview::resetImage ( )
+{
+  m_pImage = NULL;
+}
+
 void ImagePreview::setImage (CXmlSlideshow::img_struct *pImg)
 {
   // before we change the image, we should connect the current 
@@ -230,7 +235,8 @@ void ImagePreview::drawContents(QPainter *pPainter)
 		QRect startRect, boundingRect;
 		float fZoom = m_manipulator.fZoom * m_fStartZoom;
 		// Next we move the Image but keep the moving point centered.
-		matrix.translate ((int)(m_manipulator.fStartX * pPainter->window().width())+(int)((float)m_image.width()/2.0*fZoom), (int)(m_manipulator.fStartY*pPainter->window().height())+(int)((float)m_image.height()/2.0*fZoom));
+		matrix.translate ((int)(m_manipulator.fStartX * pPainter->window().width ())+(int)((float)m_image.width ()/2.0*fZoom), 
+				  (int)(m_manipulator.fStartY * pPainter->window().height())+(int)((float)m_image.height()/2.0*fZoom) );
 
 		matrix.scale (fZoom, fZoom);
 		matrix.rotate(m_pImage->rotate);
@@ -272,7 +278,8 @@ void ImagePreview::refreshPreview ()
 
 	if (m_manipulator.iTransformationMode == 1)
 		matrix.setTransformationMode(QWMatrix::Areas);
-	matrix.translate ((int)(m_manipulator.fStartX*m_background.width())+(int)((float)m_image.width()/2.0*fZoom), (int)(m_manipulator.fStartY*m_background.height())+(int)((float)m_image.height()/2.0*fZoom));
+	matrix.translate ((int)(m_manipulator.fStartX * m_background.width ())+(int)((float)m_image.width ()/2.0*fZoom), 
+			  (int)(m_manipulator.fStartY * m_background.height())+(int)((float)m_image.height()/2.0*fZoom) );
 //	matrix.translate (m_manipulator.iStartX, m_manipulator.iStartY);
 	matrix.scale (fZoom, fZoom);
 	if ( m_pImage )
@@ -466,7 +473,7 @@ void ImagePreview::centerImage ()
 {
 	if (m_image.isNull())
 		return;
-	if ( (m_manipulator.fStartX != 0.0) || (m_manipulator.fStartY != 0.0) )
+	if ( (m_manipulator.fStartX != 0.0) || (m_manipulator.fStartY >= 0.0) )
 		return;
 	m_manipulator.fStartX = ((width () - m_image.width ()) / 2.0 )/width ();
 	m_manipulator.fStartY = ((height() - m_image.height()) / 2.0 )/height();
