@@ -1,8 +1,10 @@
 /****************************************************************************
 ** SourceFileEntry - class
 **
-** Created: Tue Mar 22 12:09:08 2004
-**      by: Varol Okan using kate editor
+**   Created : Tue Mar 22 12:09:08 2004
+**        by : Varol Okan using kate editor
+** Copyright : (c) Varol Okan
+** License   : GPL v 2.0
 **
 ** This class is a simple container class to store the info
 ** for a entry in the Source File List.
@@ -16,48 +18,13 @@
 #include <qfont.h>
 #include <qsize.h>
 
+#include "subtitles.h"
+
 class QDomNode;
 class QDomElement;
 class QImage;
 
-#define MAX_COLORS 4
-
-class Subtitles
-{
-public:
-  class entry {
-  public:
-    entry ();
-    entry &operator = ( entry & );
-
-    int iIndex;
-    QString qsTimeStart;// 00:00:00.000
-    QString qsTimeStop; // 00:00:00.000
-    long    iTimeStart; // in ms
-    long    iTimeStop;  // in ms
-    QString qsText;
-    QRect   rect;       // Note not stored as it is created when drawing the text.
-  };
-
-   Subtitles ();
-  ~Subtitles ();
-
-  Subtitles & operator =    ( Subtitles   & );
-  bool    readProjectFile   ( QDomNode    & );
-  bool    writeProjectFile  ( QDomElement & );
-  long    getTimeFromString ( QString     & );
-  QString getStringFromTime ( long          );
-  QString getXMLFileName    (               );
-    
-  QFont                font;
-  QRect                rect;
-  QPoint               alignment;
-  QValueList <entry *> listOfSubtitles;
-  // this is the file that is going to be created.
-  QString              qsTempFile; 
-  QColor               subColors[ MAX_COLORS ];
-  unsigned char        iTransparency; // 0 .. 255
-};
+#define MAX_AUDIO 8
 
 class TranscodeInterface
 {
@@ -77,9 +44,9 @@ public:
 	float   fFrameRate;
 	QString qsRatio;
 
-	QString qsAudioFormat;
-	QString qsAudioType;
-	int     iAudioBitrate;
+	QString qsAudioFormat;  // "Stereo"
+	QString qsAudioType;    // One of [ mp2, ac3, or pcm ]
+	int     iAudioBitrate;  // in kbps E.g. 192 (instead of 196608 or 192000)
 	int     iSample;
 
 	int     iStartingAt;	// The movie should start here (in mSec)
@@ -89,18 +56,51 @@ public:
 	// Note: once the transcoding part terminates, 
 	// o the transcoding interface is deleted, 
 	// o the original file-name is replaced with the generated mpeg2 movie file-name
-	QString     qsTempFile;
+
+	// the following flag is set if we have meta info present in the video stream
+	// Currently only DV material is handled.
+	// If set, then a subtitle will be created using dv2sub and this flag will be set to -1
+	int     iSubtitleFromMetaInfo; 
+	QString qsTempFile;
+};
+
+class AudioEntry 
+{
+public:
+  AudioEntry ( );
+  AudioEntry &operator = ( AudioEntry & );
+  QString qsIso639;
+  int     iAudioNumber;
+};
+ 
+class Audio : public AudioEntry
+{
+public:
+   Audio ( );
+  ~Audio ( );
+  Audio &operator =      ( Audio       & );
+  bool  readProjectFile  ( QDomNode    & );
+  bool  writeProjectFile ( QDomElement & );
+
+  QString             qsFileName;
+  TranscodeInterface *pTranscodeInterface;
 };
 
 // the following class is filled with information after the source has been added to the SourceToolbar
 class SourceFileInfo
 {
 public:
-	 SourceFileInfo ();
-	~SourceFileInfo ();
+	 SourceFileInfo ( );
+	~SourceFileInfo ( );
 
 	SourceFileInfo & operator = (SourceFileInfo &);
-	QString getFileName ();
+	QString getFileName     ( );
+	int     audioCount      ( );
+	void    deleteAudio     ( );
+	void    addAudio        ( Audio * );
+	int     subtitleCount   ( );
+	void    deleteSubtitles ( );
+	void    addSubtitles    ( Subtitles * );
 
 	QString qsFileName;	  // E.g. video.mpg
 	QString qsSize;		  // E.g. 2.2M
@@ -108,10 +108,12 @@ public:
 	QString qsFPS;		  // E.g. 25
 	QString qsRatio;	  // E.g. 16:9
 	QString qsLength;	  // E.g. 01:22:23
-	QString qsVideoFormat;	  // E.g. for video :'PAL' // used to be also for audio 
+	QString qsVideoFormat;	  // E.g. 'PAL'
+	QString qsVideoCodec;	  // E.g. 'mpeg'
 	QString qsStatus;	  // E.g. Ok	-=> to say this file we can autmatically convert to a DVD video
 	// For Audio Sources :
-	QString qsAudioFormat;    // E.g. 'Stereo' 
+	QString qsAudioFormat;    // E.g. 'Stereo'
+	QString qsAudioCodec;     // E.g. "mp2"
 	QString qsBits;		  // E.g. 16
 	QString qsSample;	  // E.g. 48kHz
 	QString qsBPS;		  // E.g. 00:05:32
@@ -126,8 +128,10 @@ public:
 	int         iPause;       // The pause attribute for dvdauthor (-1=inf)
 	int         iTitleset;    // In case the user wants to define the titleset number
 	bool        bAutotranscode; // The user elected not to have this entry autotranscoded any more.
+	bool        bMetaSubtitles; // per def for DV Subtitles are created. If the user unselect this info, then we should do no longer the auto thingy ...
 	TranscodeInterface *pTranscodeInterface;
-	Subtitles   *pSubtitles;
+	Subtitles  *arraySubtitles[ MAX_SUBTITLES ];
+	Audio      *arrayAudio    [ MAX_AUDIO ];
 };
 
 // Note if the entry is a dvd-slideshow, then the qsDisplayName will end in .xml
@@ -142,6 +146,8 @@ public:
 	bool writeProjectFile (QDomElement &, bool b=false);
 	SourceFileEntry & operator = (SourceFileEntry &);
 	SourceFileEntry * flatClone  ( );
+	int audioCount    ( bool );
+	int subtitleCount ( bool );
 
 	QString qsDisplayName;          // The name that appears on the display
 	QValueList <SourceFileInfo *> listFileInfos;
@@ -156,6 +162,9 @@ public:
 	QString qsPre;
 	QString qsPost;
 	int     iPause;                 // The pause attribute for dvdauthor (-1=inf)
+
+	AudioEntry    arrayAudioEntries    [MAX_AUDIO];     // link between multiple Infos audio setting and the avail 8 audio streams.
+	SubtitleEntry arraySubtitleEntries [MAX_SUBTITLES]; // link between multiple Infos subtitle settings and the 32 subtitle tracks.
 };
 
 #endif // SOURCEFILEENTRY_H
