@@ -1,8 +1,10 @@
 /****************************************************************************
 ** DialogAnimation class
 **
-** Created: Mon May 30 22:48:00 2005
-**      by: Varol Okan using xemacs
+**   Created : Mon May 30 22:48:00 2005
+**        by : Varol Okan using xemacs
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 ** Note this dialog plays hand in hand with the TemplateDialog.
 ** All templates are first loaded from the $PREFIX directory
@@ -27,8 +29,12 @@
 </Templates>
 */
 
+#include <stdlib.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#ifdef QDVD_LINUX 
+#include <unistd.h>
+#endif
 
 #include <qprogressbar.h>
 #include <qradiobutton.h>
@@ -45,6 +51,7 @@
 
 #include <qnetwork.h>
 
+#include "win32.h"
 #include "CONFIG.h"
 #include "global.h"
 #include "messagebox.h"
@@ -239,7 +246,7 @@ void TemplateDownload::slotHelp ()
 
   if ( m_pTabMain->currentPageIndex ( ) == 0 ) {
     qsHtml  = tr ("You have to connect to the server by clicking on [<B>Connect</B>].<P>");
-    qsHtml += tr ("After the the information was found on the server you will be able to select and Downlad / Install the templates.<BR>");
+    qsHtml += tr ("After the information was found on the server you will be able to select and Download / Install the templates.<BR>");
   }
   else if ( m_pTabMain->currentPageIndex ( ) == 1 ) {
     qsHtml  = tr ("In this tab you can select the templates you want to install on your computer.<P>"); 
@@ -494,6 +501,7 @@ void TemplateDownload::createSelection ()
       else if ( pEntry->qsType == "transition" )
 	pIconView = m_pIconViewTransition;
       QIconViewItem *pItem = new QIconViewItem ( pIconView, pEntry->qsDescription, pEntry->theThumbnail );
+      pItem->setKey ( pEntry->qsName );
       pItem->setSelectable  ( true  );
      }
   }
@@ -527,7 +535,8 @@ void TemplateDownload::slotDownload ( )
 	for (i=0;i<m_xml.entryCount ();i++) {
 	  pEntry = m_xml.entry ( i );
 	  if ( pEntry ) {
-	    if ( pEntry->qsDescription == pItem->text ( ) ) {
+	    if ( ( pEntry->qsName        == pItem->key  ( ) ) && 
+		 ( pEntry->qsDescription == pItem->text ( ) ) ) {
 	      pEntry->bSelectedForInstall = true;
 	      iSelectedCounter ++;
 	      m_iTotalBytes += pEntry->iLocationSize;
@@ -544,7 +553,7 @@ void TemplateDownload::slotDownload ( )
       pIconView = m_pIconViewTransition;
   }
 
-  qsOutput = tr ( "%1 Selected Temlates. Total size = %2" ).arg ( iSelectedCounter ).arg ( m_iTotalBytes );
+  qsOutput = tr ( "%1 Selected Templates. Total size = %2" ).arg ( iSelectedCounter ).arg ( m_iTotalBytes );
   m_pEditDownload->append ( qsOutput );
   // sanity check ...
   if ( iSelectedCounter < 1 ) {
@@ -617,7 +626,7 @@ void TemplateDownload::installTemplates ( )
     file.close();
   }
   // And here we grant read/write/execute permission.
-  chmod ((const char *)QString( qsExecutable ), S_IEXEC | S_IRUSR | S_IWRITE);
+  chmod ((const char *)QString( qsExecutable ), S_IEXEC | S_IRUSR | S_IWRITE | S_IROTH | S_IXOTH | S_IWOTH );
   
   // install the Templates ...
   installToSystem ( qsExecutable, m_pRadioLocally->isChecked ( ) );
@@ -625,14 +634,16 @@ void TemplateDownload::installTemplates ( )
 
 QString TemplateDownload::findGuiSU ( )
 {
+  int iRet = 0;
   uint t;
   QString qsReturn;
+  QString qsTmpOut = QString ( "%1/%2_out.txt" ).arg ( Global::qsTempPath ).arg ( getlogin ( ) );
   char *arraySUs[3] = {"kdesu", "xsu", "gnomesu"};
-  QFileInfo fileInfo("/tmp/out.txt");
+  QFileInfo fileInfo( qsTmpOut );
   for (t=0;t<3;t++)	{
     // the next check is to see if we can find kdesu
-    system ((const char *)QString ("which %1 > /tmp/out.txt 2>/dev/null").arg(arraySUs[t]));
-    fileInfo.setFile("/tmp/out.txt");
+    iRet = system ((const char *)QString ("which %1 > %2 2>/dev/null").arg( arraySUs[t] ).arg ( qsTmpOut ) );
+    fileInfo.setFile( qsTmpOut );
     // Okay we cna not find it, so we wont bother asking the user ...
     if (fileInfo.size() > 4)	{
       qsReturn = QString ("%1").arg(arraySUs[t]);
