@@ -1,8 +1,10 @@
 /****************************************************************************
 ** TextObject class
 **
-** Created: Tue Feb 02 22:06:51 2004
-**      by: Varol Okan using Kate
+**   Created : Tue Feb 02 22:06:51 2004
+**        by : Varol Okan using Kate
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 **
 ****************************************************************************/
@@ -26,8 +28,8 @@
 TextObject::TextObject (QWidget *pParent)
 	: MenuObject (pParent)
 {
-	m_qsObjectType    = QString (TEXT_OBJECT);
-	m_colorBackground = QColor(TRANSPARENT_COLOR);	// indicate the transparent color.
+	m_qsObjectType    = QString ( TEXT_OBJECT );
+	m_colorBackground = Rgba    ( TRANSPARENT_COLOR );   // indicate the transparent color.
 	m_iStyleStrategy  = QFont::PreferAntialias;
 	m_pContextMenu    = NULL;
 }
@@ -51,8 +53,16 @@ QFont &TextObject::getFont ()
 
 void TextObject::setText (QString &theText)
 {
-	m_qsText = theText;
-	setName (theText);
+  m_qsText = theText;
+  
+  // Here we seal off after 20 char and remove special characters from the Object Name.
+  QString qsTemp = theText;
+  qsTemp = qsTemp.remove  ( '\n' );
+  qsTemp = qsTemp.remove  ( '\t' );
+  if ( qsTemp.length ( )  > 20 )
+    qsTemp = qsTemp.left  ( 20 );
+
+  setName ( qsTemp );
 }
 
 QString &TextObject::getText ()
@@ -81,43 +91,44 @@ int TextObject::getStyleStrategy ()
   return (int)m_iStyleStrategy;
 }
 
-void TextObject::replaceColor (QColor theColor, QColor oldColor)
+void TextObject::replaceColor ( Rgba theColor, Rgba oldColor )
 {
-	if (getForegroundColor () == oldColor)
-		setForegroundColor (theColor);
-	if (getBackgroundColor () == oldColor)
-		setBackgroundColor (theColor);
+  if ( getForegroundColor ( ) == oldColor )
+       setForegroundColor ( theColor );
+  if ( getBackgroundColor ( ) == oldColor )
+       setBackgroundColor ( theColor );
 }
 
-void TextObject::setForegroundColor ( const QColor &theColor)
+void TextObject::setForegroundColor ( const Rgba &theColor)
 {
   m_colorForeground = theColor;
 }
 
-void TextObject::setBackgroundColor ( const QColor &theColor)
+void TextObject::setBackgroundColor ( const Rgba &theColor)
 {
   m_colorBackground = theColor;
 }
 
-QColor &TextObject::getForegroundColor ()
+Rgba &TextObject::getForegroundColor ()
 {
-	return m_colorForeground;
+  return m_colorForeground;
 }
 
-QColor &TextObject::getBackgroundColor ()
+Rgba &TextObject::getBackgroundColor ()
 {
-	return m_colorBackground;
+  return m_colorBackground;
 }
 
 void TextObject::drawSemiTransparent (QPainter *pPainter)
 {
+//printf ( "%s::%s : %d  \n", __FILE__, __FUNCTION__, __LINE__ );
         if ( m_pShadow && ! m_bDrawRect )
 	     m_pShadow->drawContents ( pPainter );
 	QWMatrix theMatrix;
 	QRect dummyRect, theRect;
 	int iFlags, x, y;
 	int iSourceHeight, iSourceWidth, iSourceStartX, iSourceStartY, iTargetStartX, iTargetStartY;
-	QColor sourceColor, targetColor, theColor;
+	Rgba sourceColor, targetColor, theColor;
 	QRgb sourcePixel, targetPixel;
 	QImage sourceImg, targetImg;
 	float fTargetTrans, fSourceTrans;
@@ -126,7 +137,7 @@ void TextObject::drawSemiTransparent (QPainter *pPainter)
 	fTargetTrans = 1.0 - modifiers()->fTransparency;
 	fSourceTrans = modifiers()->fTransparency;
 
-	QPen thePen (m_colorForeground, 2, Qt::DashDotLine);
+	QPen thePen ( m_colorForeground.color ( ), 2, Qt::DashDotLine );
 	// Here we define the cenetered rect.
 	theRect = QRect((int)-(rect().width()/ 2.0), (int)-(rect().height()/2.0), rect().width(), rect().height());
 
@@ -147,18 +158,18 @@ void TextObject::drawSemiTransparent (QPainter *pPainter)
 	theMatrix.rotate (modifiers()->fRotate);
 	theMatrix.shear  (modifiers()->fShearX, modifiers()->fShearY);
 
-	QPixmap thePixmap = QPixmap(m_boundingRect.size());
+	QPixmap thePixmap = QPixmap ( m_boundingRect.size ( ) );
 	if (thePixmap.isNull())
 		return;
 
-	thePixmap.fill (QColor (TRANSPARENT_COLOR));
+	thePixmap.fill ( QColor ( TRANSPARENT_COLOR ) );
 	QPainter pmPainter (&thePixmap);
 	//  then we actually set the world matrix 
 	pmPainter.setWorldMatrix(theMatrix);
 
-	pmPainter.setPen(Qt::NoPen);
-	pmPainter.setBrush (QBrush(m_colorBackground));
-	pmPainter.drawRect(theRect);
+	pmPainter.setPen   ( Qt::NoPen );
+	pmPainter.setBrush ( QBrush    ( m_colorBackground.color ( ) ) );
+	pmPainter.drawRect ( theRect   );
  
 	m_Font.setStyleStrategy ((QFont::StyleStrategy)m_iStyleStrategy);
 	pmPainter.setFont(m_Font);
@@ -202,14 +213,14 @@ void TextObject::drawSemiTransparent (QPainter *pPainter)
 			if (sourcePixel != 0x00FFFFFF)	{	// And check if this is a pixel we 
 				targetPixel = targetImg.pixel(x, y);
 				targetPixel &= 0x00ffffff;	// filter out the transparency part of the color
-				targetColor = QColor ( targetPixel );
-				sourceColor = QColor ( sourcePixel );
-				theColor    = QColor (
+				targetColor = Rgba ( targetPixel );
+				sourceColor = Rgba ( sourcePixel );
+				theColor    = Rgba (
 					(int)(fSourceTrans * sourceColor.red()   + (int)(fTargetTrans * targetColor.red())),
 					(int)(fSourceTrans * sourceColor.green() + (int)(fTargetTrans * targetColor.green())),
 					(int)(fSourceTrans * sourceColor.blue()  + (int)(fTargetTrans * targetColor.blue()))
 				);
-				pPainter->setPen ( theColor );
+				pPainter->setPen ( theColor.color ( ) );
 				pPainter->drawPoint(x+iTargetStartX, y+iTargetStartY);
 			}
 		}
@@ -248,8 +259,8 @@ void TextObject::drawContents (QPainter *painter)
 	theMatrix.rotate (modifiers()->fRotate);
 	theMatrix.shear  (modifiers()->fShearX, modifiers()->fShearY);
 	
-	QPen thePen (m_colorForeground, 2, Qt::DashDotLine);
-	painter->setPen(thePen);
+	QPen thePen ( m_colorForeground.color ( ), 2, Qt::DashDotLine);
+	painter->setPen ( thePen );
 	
 	// Here we get the rect that encompasses the button for this object.
 	m_boundingRect = theMatrix.mapRect(theRect);
@@ -261,24 +272,23 @@ void TextObject::drawContents (QPainter *painter)
 	painter->setWorldMatrix(theMatrix);
 
 	// and continue to draw the contents ...
-	if (m_colorBackground != QColor(TRANSPARENT_COLOR))	{
+	if ( m_colorBackground.alpha ( ) > 0 )  {
 		// No frame wanted, we take care of that ourself if requested ...
-		painter->setPen(Qt::NoPen);
-		painter->setBrush (QBrush(m_colorBackground));
-		painter->drawRect(theRect);
+		painter->setPen   ( Qt::NoPen );
+		painter->setBrush ( QBrush ( m_colorBackground.color ( ) ) );
+		painter->drawRect ( theRect );
 		// and re-set the PEN.
-		painter->setPen(thePen);
+		painter->setPen   ( thePen );
 	}
 	else
-		painter->setBrush(Qt::NoBrush);
- 
+		painter->setBrush ( Qt::NoBrush );
+
 	m_Font.setStyleStrategy ((QFont::StyleStrategy)m_iStyleStrategy);
 	painter->setFont(m_Font);
 	QRect boundingRect;
 	bool bUpdateAgain = false;
 	// Okay, I abused a QPoint class to hold some other infos ... so what ???
 	int iFlags = Qt::DontClip|Qt::WordBreak|m_ptTextAlign.x()|m_ptTextAlign.y();
-
 	if (m_bDrawRect)
 		painter->drawRect(theRect);
 
@@ -303,60 +313,66 @@ void TextObject::drawContents (QPainter *painter)
 	painter->setWorldMatrix(theMatrix);
 }
 
-
 void TextObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int)
 {
-	// Next is to set the AnimationAttributes
-	for (uint t=0;t<m_listAnimationAttributes.count();t++)
-		m_listAnimationAttributes[t]->setValue (iRenderFrameNumber);
+  // Next is to set the AnimationAttributes
+  for (uint t=0;t<m_listAnimationAttributes.count();t++)
+    m_listAnimationAttributes[t]->setValue (iRenderFrameNumber);
+  
+  // If start stop have been set then we check the range
+  if ( ( ( iRenderFrameNumber < modifiers ( )->iStartFrame ) && ( modifiers ( )->iStartFrame != -1 ) ) || 
+       ( ( iRenderFrameNumber > modifiers ( )->iStopFrame  ) && ( modifiers ( )->iStopFrame  != -1 ) ) ) 
+    return;
 
-	drawContents (pPainter);
+  drawContents (pPainter);
 }
 
 bool TextObject::readProjectFile  (QDomNode &theNode)
 {
-	QDomElement theElement = theNode.toElement();
-	QDomAttr attribute;
-
-	attribute = theElement.attributeNode ( TEXT_OBJECT_TEXT );
-	if (!attribute.isNull())
-		m_qsText = attribute.value();
-
-	attribute = theElement.attributeNode ( TEXT_OBJECT_TEXT_ALIGN );
-	if (!attribute.isNull())	{
-		// QString "x,y" - we abused a QPoint object for the Align info.
-		QStringList list = QStringList::split (",", attribute.value());
-		QPoint textAlign;
-		if (list.count() == 2)
-			textAlign = QPoint(list[0].toInt(), list[1].toInt());
-		setTextAlign (textAlign);
-	}
-
-	attribute = theElement.attributeNode ( TEXT_OBJECT_STYLE_STRATEGY );
-	if (!attribute.isNull())
-	        m_iStyleStrategy = attribute.value().toInt();
-
-	attribute = theElement.attributeNode ( TEXT_OBJECT_FONT);
-	if (!attribute.isNull())	{
-		QFont theFont;
-		if (theFont.fromString (attribute.value()))
-			setFont (theFont);
-	}
-
-	attribute = theElement.attributeNode ( TEXT_OBJECT_BACKGROUND_COLOR );
-	if (!attribute.isNull())	{
-		QColor backgroundColor (attribute.value());
-		setBackgroundColor (backgroundColor);
-	}
-
-	attribute = theElement.attributeNode ( TEXT_OBJECT_FOREGROUND_COLOR );
-	if (!attribute.isNull())	{
-		QColor foregroundColor (attribute.value());
-		setForegroundColor (foregroundColor);
-	}
-
-	MenuObject::readProjectFile( theNode );
-	return true;
+  QDomElement theElement = theNode.toElement();
+  QDomAttr attribute;
+  
+  attribute = theElement.attributeNode ( TEXT_OBJECT_TEXT );
+  if (!attribute.isNull())
+    m_qsText = attribute.value();
+  
+  attribute = theElement.attributeNode ( TEXT_OBJECT_TEXT_ALIGN );
+  if (!attribute.isNull())	{
+    // QString "x,y" - we abused a QPoint object for the Align info.
+    QStringList list = QStringList::split (",", attribute.value());
+    QPoint textAlign;
+    if (list.count() == 2)
+      textAlign = QPoint(list[0].toInt(), list[1].toInt());
+    setTextAlign (textAlign);
+  }
+  
+  attribute = theElement.attributeNode ( TEXT_OBJECT_STYLE_STRATEGY );
+  if (!attribute.isNull())
+    m_iStyleStrategy = attribute.value().toInt();
+  
+  attribute = theElement.attributeNode ( TEXT_OBJECT_FONT);
+  if (!attribute.isNull())	{
+    QFont theFont;
+    if (theFont.fromString (attribute.value()))
+      setFont (theFont);
+  }
+  
+  attribute = theElement.attributeNode ( TEXT_OBJECT_BACKGROUND_COLOR );
+  if (!attribute.isNull())	{
+    Rgba backgroundColor;
+    backgroundColor.fromString ( attribute.value ( ) );
+    setBackgroundColor ( backgroundColor );
+  }
+  
+  attribute = theElement.attributeNode ( TEXT_OBJECT_FOREGROUND_COLOR );
+  if (!attribute.isNull())	{
+    Rgba foregroundColor;
+    foregroundColor.fromString ( attribute.value ( ) );
+    setForegroundColor ( foregroundColor );
+  }
+  
+  MenuObject::readProjectFile( theNode );
+  return true;
 }
 
 bool TextObject::writeProjectFile (QDomElement &theElement)
@@ -375,9 +391,9 @@ bool TextObject::writeProjectFile (QDomElement &theElement)
 	if (getFont() != initialValues.getFont())
 		textNode.setAttribute( TEXT_OBJECT_FONT, getFont().toString() );
 	if (getBackgroundColor() != initialValues.getBackgroundColor())
-		textNode.setAttribute( TEXT_OBJECT_BACKGROUND_COLOR, getBackgroundColor().name() );
+		textNode.setAttribute( TEXT_OBJECT_BACKGROUND_COLOR, getBackgroundColor().toString ( ) );
 	if (getForegroundColor() != initialValues.getForegroundColor())
-		textNode.setAttribute( TEXT_OBJECT_FOREGROUND_COLOR, getForegroundColor().name() );
+		textNode.setAttribute( TEXT_OBJECT_FOREGROUND_COLOR, getForegroundColor().toString ( ) );
 	
 	theElement.appendChild( textNode );
 	// And here we write the base class ...
@@ -386,11 +402,15 @@ bool TextObject::writeProjectFile (QDomElement &theElement)
 
 bool TextObject::createContextMenu (QPoint globalPos)
 {
-        QPoint globalPos2 = globalPos;
+	QPoint globalPos2 = globalPos;
 	QPopupMenu *pStackMenu = new QPopupMenu(m_pParent);
+	pStackMenu->insertItem ( tr ("Cut") , this, SLOT ( slotCut  ( ) ) );
+	pStackMenu->insertItem ( tr ("Copy"), this, SLOT ( slotCopy ( ) ) );
+	pStackMenu->insertSeparator ( );
 	pStackMenu->insertItem ( tr ("To Front")  , this, SLOT(slotToFront()));
 	pStackMenu->insertItem ( tr ("To Back")   , this, SLOT(slotToBack()));
-	globalPos.setX (globalPos.x() - pStackMenu->sizeHint().width()); // -100);
+	globalPos.setY ( globalPos.y ( ) - 25 );
+	globalPos.setX ( globalPos.x ( ) - pStackMenu->sizeHint().width()); // -100);
 	pStackMenu->popup(globalPos, 1);
 
 	if (m_pContextMenu)
@@ -400,10 +420,16 @@ bool TextObject::createContextMenu (QPoint globalPos)
 	m_pContextMenu->insertItem ( tr ("Matrix ..."), this,  SLOT(slotMatrix    ( ) ) );
 	m_pContextMenu->insertItem ( tr ("Delete")    , this,  SLOT(slotDelete    ( ) ) );
 	m_pContextMenu->insertSeparator();
-	m_pContextMenu->insertItem ( tr ("Add Shadow"),this,   SLOT(slotAddShadow ( ) ) );
-	m_pContextMenu->insertItem ( tr ("Add Frame"), this,   SLOT(slotAddFrame  ( ) ) );
-	m_pContextMenu->insertItem ( tr ("Add Image"), this,   SLOT(slotAddImage  ( ) ) );
-	m_pContextMenu->insertItem ( tr ("Add Movie"), this,   SLOT(slotAddMovie  ( ) ) );
+	if ( shadow ( ) )  {
+	  m_pContextMenu->insertItem ( tr ( "Edit Shadow ..." ), this, SLOT ( slotAddShadow    ( ) ) );
+	  m_pContextMenu->insertItem ( tr ( "Delete Shadow" ),   this, SLOT ( slotDeleteShadow ( ) ) );
+	}
+	else
+	  m_pContextMenu->insertItem ( tr ( "Add Shadow ..." ),  this, SLOT ( slotAddShadow ( ) ) );
+
+	//	m_pContextMenu->insertItem ( tr ("Add Frame"), this,   SLOT(slotAddFrame  ( ) ) );
+	//	m_pContextMenu->insertItem ( tr ("Add Image"), this,   SLOT(slotAddImage  ( ) ) );
+	//	m_pContextMenu->insertItem ( tr ("Add Movie"), this,   SLOT(slotAddMovie  ( ) ) );
 	m_pContextMenu->insertSeparator();
 	m_pContextMenu->insertItem ( tr ("Define as Button") , this, SLOT(slotDefineAsButton()));
 	// Blocking call
@@ -418,49 +444,41 @@ bool TextObject::createContextMenu (QPoint globalPos)
 	return true;
 }
 
-void TextObject::createStructure (QListViewItem *pParentItem)
+StructureItem *TextObject::createStructure ( StructureItem *pParentItem )
 {
-	StructureItem *pButtonItem;
-	StructureItem *pModifierItem;
+  StructureItem *pTemp=NULL;
 
-	QString qsName = tr ("Text Object");
-	pButtonItem = new StructureItem(this, pParentItem, qsName, m_qsText);
-	pButtonItem->setExpandable (TRUE);
+  QString qsName = tr ( "Text Object" );
+  if ( ! m_pStructureItem ) {
+    m_pStructureItem = new StructureItem ( this, pParentItem, qsName, m_qsText );
+    m_pStructureItem->setExpandable      ( TRUE );
+  }
+  else
+    m_pStructureItem->setText ( qsName, m_qsText );
 
-	// And finally we create the modifiers info ...
-	if ( !((m_modifiers.fRotate == 0.0) && (m_modifiers.fShearX == 0.0) && (m_modifiers.fShearY == 0.0) &&
-		   (m_modifiers.fZoom   == 1.0) && (m_modifiers.fScaleX == 1.0) && (m_modifiers.fScaleY == 1.0)) )	{
-	  pModifierItem = new StructureItem(this, pButtonItem, tr ("Modifiers"), NULL);
-		pButtonItem->setExpandable (TRUE);
+  pTemp = m_pStructureItem->setSibling ( this, pTemp, tr ( "Geometry" ), QString ( "%1, %2, %3, %4" ).
+       	         arg ( rect().x()).arg(rect().y()).arg(rect().width()).arg(rect().height()) );
 
-		new StructureItem(this, pModifierItem, tr ("Shear (x, y)"),
-			QString ("%1, %2").arg(m_modifiers.fShearX).arg(m_modifiers.fShearY));
-		new StructureItem(this, pModifierItem, tr ("Zoom"),
-			QString ("%1").arg(m_modifiers.fZoom));
-		new StructureItem(this, pModifierItem, tr ("Rotate"),
-			QString ("%1 deg").arg(m_modifiers.fRotate));
-	}
-	if ( m_pShadow )
-	     m_pShadow->createStructure ( pButtonItem );
+  pTemp = m_pStructureItem->setSibling ( this, pTemp, tr ("Foreground"),
+                tr ("color(%1, %2, %3)").
+		arg ( m_colorForeground.red   ( ) ).
+		arg ( m_colorForeground.green ( ) ).
+		arg ( m_colorForeground.blue  ( ) ) );
+  
+  if ( m_colorBackground == Rgba ( TRANSPARENT_COLOR ) )
+    pTemp = m_pStructureItem->setSibling ( this, pTemp, tr ("Background"), tr ("Transparent") );
+  else
+    pTemp = m_pStructureItem->setSibling ( this, pTemp, tr ("Background"),
+			tr  ( "color(%1, %2, %3)").
+			arg ( m_colorBackground.red   ( ) ).
+			arg ( m_colorBackground.green ( ) ).
+			arg ( m_colorBackground.blue  ( ) ) );
+  if ( m_pShadow )
+    pTemp = m_pShadow->createStructure ( m_pStructureItem );
+  
+  m_modifiers.createStructure ( m_pStructureItem, pTemp );
 
-	if (m_colorBackground == QColor (TRANSPARENT_COLOR))
-	  new StructureItem(this, pButtonItem, tr ("Background"), tr ("Transparent"));
-	else
-	  new StructureItem(this, pButtonItem, tr ("Background"),
-			tr ("color(%1, %2, %3)").
-				arg(m_colorBackground.red()).
-				arg(m_colorBackground.green()).
-				arg(m_colorBackground.blue()));
-
-	new StructureItem(this, pButtonItem, tr ("Foreground"),
-		QString ("color(%1, %2, %3)").
-			arg(m_colorForeground.red()).
-			arg(m_colorForeground.green()).
-			arg(m_colorForeground.blue()));
-
-	new StructureItem(this, pButtonItem, tr ("Geometry"),
-		QString ("%1, %2, %3, %4").
-		arg(rect().x()).arg(rect().y()).arg(rect().width()).arg(rect().height()));
+  return m_pStructureItem;
 }
 
 bool TextObject::mousePressEvent (QMouseEvent *pEvent)
@@ -475,46 +493,6 @@ bool TextObject::mousePressEvent (QMouseEvent *pEvent)
 	return false;
 }
 
-/*
-	m_currentMousePos = pEvent->pos();
-	if (pEvent->button() == Qt::RightButton)	{
-		QPoint globalPos = pEvent->globalPos();
-
-		QPopupMenu *pStackMenu = new QPopupMenu(m_pParent);
-		pStackMenu->insertItem ( tr ("To Front")  , this, SLOT(slotToFront()));
-		pStackMenu->insertItem ( tr ("To Back")   , this, SLOT(slotToBack()));
-		globalPos.setX (globalPos.x() - pStackMenu->sizeHint().width()); // -100);
-		pStackMenu->popup(globalPos, 1);
-
-		if (m_pContextMenu)
-			delete m_pContextMenu;
-		m_pContextMenu = new QPopupMenu(m_pParent);
-		m_pContextMenu->insertItem ( tr ("Edit ...")  , this,  SLOT(slotEdit()));
-		m_pContextMenu->insertItem ( tr ("Matrix ..."), this,  SLOT(slotMatrix()));
-		m_pContextMenu->insertItem ( tr ("Delete")    , this,  SLOT(slotDelete()));
-		m_pContextMenu->insertSeparator();
-		m_pContextMenu->insertItem ( tr ("Add Frame"), this,   SLOT(slotAddFrame()));
-		m_pContextMenu->insertItem ( tr ("Add Image"), this,   SLOT(slotAddImage()));
-		m_pContextMenu->insertItem ( tr ("Add Movie"), this,   SLOT(slotAddMovie()));
-		m_pContextMenu->insertSeparator();
-		m_pContextMenu->insertItem ( tr ("Define as Button") , this, SLOT(slotDefineAsButton()));
-		// Blocking call
-		m_pContextMenu->exec(pEvent->globalPos(), 3);
-		// Here we mark that the user called a menu item thus we don't want the
-		// base classes to continue with the mouse event
-		delete pStackMenu;
-		// Note the menu might have been already deleted in slotToFront/slotToBack
-		if (m_pContextMenu)
-			delete m_pContextMenu;
-		m_pContextMenu = NULL;
-		return true;
-	}
-	else
-		m_bDrawRect = true;
-	return false;
-}
-*/
-
 bool TextObject::mouseReleaseEvent (QMouseEvent *)
 {
 	m_bDrawRect = false;
@@ -529,14 +507,14 @@ bool TextObject::mouseDoubleClickEvent (QMouseEvent *)
 	DialogTextFont fontDialog (m_pParent);
 	fontDialog.setFont (getFont());
 	fontDialog.setText (getText());
-	fontDialog.setTextAlign (getTextAlign());
-	fontDialog.setBackgroundColor (getBackgroundColor());
-	fontDialog.setForegroundColor (getForegroundColor());
-	fontDialog.setTransparency (modifiers()->fTransparency);
-	fontDialog.setAnimation ( animation () );
-	fontDialog.setRect (rect());	// setRect (boundingRect());
-	if (fontDialog.exec() == QDialog::Rejected)
-		return false;
+	fontDialog.setTextAlign       ( getTextAlign       ( ) );
+	fontDialog.setBackgroundColor ( getBackgroundColor ( ) );
+	fontDialog.setForegroundColor ( getForegroundColor ( ) );
+	fontDialog.setTransparency    ( modifiers ( )->fTransparency);
+	fontDialog.setAnimation       ( animation ( ) );
+	fontDialog.setRect   ( rect ( ) );	// setRect (boundingRect());
+	if ( fontDialog.exec ( ) == QDialog::Rejected )
+	  return false;
 
 	setFont(fontDialog.getFont());
 	QString theString = fontDialog.getText();
@@ -612,70 +590,77 @@ void TextObject::slotDefineAsButton ()
 	emit (signalDefineAsButton(this));
 }
 
-MenuObject *TextObject::clone()
+MenuObject *TextObject::clone ( QWidget *pParent, MenuObject * )
 {
-	TextObject *pNewObject = new TextObject (MenuObject::parent());
-	pNewObject->setFont (getFont());
-	pNewObject->setText (getText());
-	pNewObject->setTextAlign (getTextAlign());
-	pNewObject->setForegroundColor (getForegroundColor());
-	pNewObject->setBackgroundColor (getBackgroundColor());
-	pNewObject->setStyleStrategy   ((QFont::StyleStrategy)m_iStyleStrategy);
-
-	// The following two are not really needed, since we get those 
-	// informations solely from the Normal State - objects ...
-	pNewObject->setRect(rect());
-	pNewObject->setModifiers(*modifiers());
-
-	MenuObject *pShadow = shadow ( );
-	if ( pShadow )
-	     pShadow = pShadow->clone ( pNewObject );
-	pNewObject->setShadow         (  pShadow   );
-
-	return pNewObject;
+  if ( !pParent )
+    pParent = MenuObject::parent ( );
+  
+  TextObject *pNewObject = new TextObject ( pParent );
+  pNewObject->setFont (getFont());
+  pNewObject->setText (getText());
+  pNewObject->setTextAlign (getTextAlign());
+  pNewObject->setForegroundColor (getForegroundColor());
+  pNewObject->setBackgroundColor (getBackgroundColor());
+  pNewObject->setStyleStrategy   ((QFont::StyleStrategy)m_iStyleStrategy);
+  
+  // The following two are not really needed, since we get those 
+  // informations solely from the Normal State - objects ...
+  pNewObject->setRect(rect());
+  pNewObject->setModifiers(*modifiers());
+  
+  MenuObject *pShadow = shadow ( );
+  if ( pShadow )
+    pShadow = pShadow->clone ( pParent, pNewObject );
+  pNewObject->setShadow      ( pShadow );
+  
+  return pNewObject;
 }
 
-#include <qfont.h>
 AnimationAttribute *TextObject::getSpecificAttributes (long iMaxNumberOfFrames, QString qsProperty)
 {
-//	QFont       m_Font;
-//	QPoint      m_ptTextAlign;
+  AnimationAttribute *pAnimAttr = NULL;
+  static int m_iTestInt = 0;
 
-	AnimationAttribute *pAnimAttr = NULL;
-	static int m_iTestInt = 0;
-
-	if (qsProperty == "text")
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_qsText, &m_qsText);
-	else if (qsProperty == "font")	{
-		FunctionCallback<QFont> *callMeBack = new FunctionCallback<QFont>(m_Font, &QFont::fromString);
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_Font.toString(), callMeBack);
-	}
-	else if (qsProperty == "textAlign")
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_iTestInt, &m_iTestInt);
-	else if (qsProperty == "foregroundColor.red")	{
-		FunctionCallback<QColor> *callMeBack = new FunctionCallback<QColor>(m_colorForeground, TYPE_COLOR_RED);
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorForeground.red(), callMeBack);
-	}
-	else if (qsProperty == "foregroundColor.green")	{
-		FunctionCallback<QColor> *callMeBack = new FunctionCallback<QColor>(m_colorForeground, TYPE_COLOR_GREEN);
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorForeground.green(), callMeBack);
-	}
-	else if (qsProperty == "foregroundColor.blue")	{
-		FunctionCallback<QColor> *callMeBack = new FunctionCallback<QColor>(m_colorForeground, TYPE_COLOR_BLUE);
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorForeground.blue(), callMeBack);
-	}
-	else if (qsProperty == "backgroundColor.red")	{
-		FunctionCallback<QColor> *callMeBack = new FunctionCallback<QColor>(m_colorBackground, TYPE_COLOR_RED);
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorBackground.red(), callMeBack);
-	}
-	else if (qsProperty == "backgroundColor.green")	{
-		FunctionCallback<QColor> *callMeBack = new FunctionCallback<QColor>(m_colorBackground, TYPE_COLOR_GREEN);
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorBackground.green(), callMeBack);
-	}
-	else if (qsProperty == "backgroundColor.blue")	{
-		FunctionCallback<QColor> *callMeBack = new FunctionCallback<QColor>(m_colorBackground, TYPE_COLOR_BLUE);
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorBackground.blue(), callMeBack);
-	}
-	return pAnimAttr;
+  if (qsProperty == "text")
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_qsText, &m_qsText);
+  else if (qsProperty == "font")	{
+    FunctionCallback<QFont> *callMeBack = new FunctionCallback<QFont>(m_Font, &QFont::fromString);
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_Font.toString(), callMeBack);
+  }
+  else if (qsProperty == "textAlign")
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_iTestInt, &m_iTestInt);
+  else if (qsProperty == "foregroundColor.red")	{
+    FunctionCallback<Rgba> *callMeBack = new FunctionCallback<Rgba>(m_colorForeground, TYPE_COLOR_RED );
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorForeground.red(), callMeBack);
+  }
+  else if (qsProperty == "foregroundColor.green")	{
+    FunctionCallback<Rgba> *callMeBack = new FunctionCallback<Rgba>(m_colorForeground, TYPE_COLOR_GREEN);
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorForeground.green(), callMeBack);
+  }
+  else if (qsProperty == "foregroundColor.blue")	{
+    FunctionCallback<Rgba> *callMeBack = new FunctionCallback<Rgba>(m_colorForeground, TYPE_COLOR_BLUE);
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorForeground.blue(), callMeBack);
+  }
+  else if (qsProperty == "foregroundColor.alpha")	{
+    FunctionCallback<Rgba> *callMeBack = new FunctionCallback<Rgba>(m_colorForeground, TYPE_COLOR_ALPHA);
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorForeground.alpha(), callMeBack);
+  }
+  else if (qsProperty == "backgroundColor.red")	{
+    FunctionCallback<Rgba> *callMeBack = new FunctionCallback<Rgba>(m_colorBackground, TYPE_COLOR_RED);
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorBackground.red(), callMeBack);
+  }
+  else if (qsProperty == "backgroundColor.green")	{
+    FunctionCallback<Rgba> *callMeBack = new FunctionCallback<Rgba>(m_colorBackground, TYPE_COLOR_GREEN);
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorBackground.green(), callMeBack);
+  }
+  else if (qsProperty == "backgroundColor.blue")	{
+    FunctionCallback<Rgba> *callMeBack = new FunctionCallback<Rgba>(m_colorBackground, TYPE_COLOR_BLUE);
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorBackground.blue(), callMeBack);
+  }
+  else if (qsProperty == "backgroundColor.alpha")	{
+    FunctionCallback<Rgba> *callMeBack = new FunctionCallback<Rgba>(m_colorBackground, TYPE_COLOR_ALPHA);
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorBackground.alpha(), callMeBack);
+  }
+  return pAnimAttr;
 }
 
