@@ -1,7 +1,10 @@
 /****************************************************************************
 ** Class Utils implementation ...
 **
-** Created: Wed Sep 09 07:53:05 2004
+**   Created : Wed Sep 09 07:53:05 2004
+**        by : Varol Okan
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 ** Here we have some misc functions which are needed by a few classes 
 ** but can not really be assigned to any of those classes.
@@ -9,7 +12,9 @@
 ****************************************************************************/
 
 #include <stdlib.h>
+#ifdef QDVD_LINUX 
 #include <unistd.h>
+#endif 
 
 #include <qfileinfo.h>
 #include <qimage.h>
@@ -25,6 +30,7 @@
 #include "utils.h"
 #include "messagebox.h"
 
+#include "win32.h"
 
 Utils::Utils()
 {
@@ -71,6 +77,60 @@ QString Utils::formatChapter (QString qsInput)
 	return qsReturn;
 }
 
+QString Utils::longToNorm ( long iInput )
+{
+	// This function returns a string like 4400k from 4400000
+	QString qsReturn;
+	float fValue;
+	if (iInput > 1000000000)	{
+		fValue = (double)iInput / 1000000000.0;
+		qsReturn = QString ("%1G").arg(fValue);
+	}
+	else if (iInput > 1000000)	{
+		fValue = (double)iInput / 1000000.0;
+		qsReturn = QString ("%1M").arg(fValue);
+	}
+	else if (iInput > 1000)	{
+		fValue = (double)iInput / 1000.0;
+		qsReturn = QString ("%1k").arg(fValue);
+	}
+	else	{
+		qsReturn = QString ("%1").arg(iInput);
+	}
+	return qsReturn;
+}
+
+long Utils::normToLong ( QString qsInput )
+{
+	QString qsValue, arrayDigit (".0123456789");
+	uint t, i;
+	long iReturn, iMultiplicator = 1;
+	// Here we take a string like 4400kbps and return 4400000.
+	for (t=0;t<qsInput.length();t++)	{
+		for (i=0;i<arrayDigit.length();i++)	{
+			if ( qsInput.at ( t ) == arrayDigit.at ( i ) )	{
+				qsValue += qsInput.at ( t );
+				i = 10;
+				continue;
+			}
+		}
+		if (qsInput.at ( t ).upper () == "K")	{
+			iMultiplicator = 1000;
+			break;
+		}
+		if (qsInput.at ( t ).upper () == "M")	{
+			iMultiplicator = 1000000;
+			break;
+		}
+		if (qsInput.at ( t ).upper () == "G")	{
+			iMultiplicator = 1000000000;
+			break;
+		}
+	}
+	iReturn = (long)(qsValue.toFloat() * iMultiplicator);
+	return iReturn;
+}
+
 QString Utils::getAttribute (QString qsAttrName, QString qsFullString)
 {
 	QString qsReturn;
@@ -87,38 +147,58 @@ QString Utils::getAttribute (QString qsAttrName, QString qsFullString)
 	qsReturn = qsFullString.mid (iStart, iEnd-iStart);
 	return qsReturn;
 }
+/* Some issues ...
+QRgb Utils::nearestColor (QRgb *rgbPalette, int iNumColors, QRgb rgbSeeking)
+{
+  QRgb rgbReturn = rgbPalette[0];
+  int t, iRed, iGreen, iBlue, r, g, b;
+  unsigned long iSquare, iClosestColor = 0x1ff*0x1ff*3+1;
+  
+  r = qRed   (rgbSeeking) - 255;
+  g = qGreen (rgbSeeking) - 255;
+  b = qBlue  (rgbSeeking) - 255;
+  
+  for (t=0;t<iNumColors;t++)	{
+    iRed    = qRed   (rgbPalette[t]) - r;
+    iGreen  = qGreen (rgbPalette[t]) - g;
+    iBlue   = qBlue  (rgbPalette[t]) - b;
+    iSquare = iRed*iRed + iGreen*iGreen + iBlue*iBlue;
+    
+    // Now let us check if we found a color closer then the previous one.
+    if (   iSquare  < iClosestColor   )  {
+      rgbReturn     = rgbPalette[t];
+      iClosestColor = iSquare;
+    }
+  }
+  return rgbReturn;
+}
+*/
 
 QRgb Utils::nearestColor (QRgb *rgbPalette, int iNumColors, QRgb rgbSeeking)
 {
-	QRgb rgbReturn = rgbPalette[0];
-	int t, iRed, iGreen, iBlue, iSquare, iSeeking, iCompare, iClosestColor = 0xff*0xff*3+1;
-	
-	iRed     = qRed   (rgbSeeking);
-	iGreen   = qGreen (rgbSeeking);
-	iBlue    = qBlue  (rgbSeeking);
-	// iSeeking holds the value for the color to seek.
-	iSeeking = iRed*iRed + iGreen*iGreen + iBlue*iBlue;
-
-	for (t=0;t<iNumColors;t++)	{
-		iRed   = qRed   (rgbPalette[t]);
-		iGreen = qGreen (rgbPalette[t]);
-		iBlue  = qBlue  (rgbPalette[t]);
-		iSquare = iRed*iRed + iGreen*iGreen + iBlue*iBlue;
-		// Okay we are only interested in the total value (not +/-)
-		iCompare = iSquare - iSeeking;
-
-		if (iCompare < 0)
-			iCompare = -iCompare;
-		// Now let us check if we found a color closer then the previous one.
-		if (iCompare < iClosestColor)	{
-			rgbReturn = rgbPalette[t];
-			iClosestColor = iCompare;
-		}
-	}
-	return rgbReturn;
+  QRgb rgbReturn = rgbPalette[0];
+  int t, iRed, iGreen, iBlue, r, g, b;
+  unsigned long iSquare, iClosestColor = 0xff*0xff*3+1;
+  
+  r = qRed   (rgbSeeking);
+  g = qGreen (rgbSeeking);
+  b = qBlue  (rgbSeeking);
+  
+  for (t=0;t<iNumColors;t++)	{
+    iRed    = qRed   (rgbPalette[t]) - r;
+    iGreen  = qGreen (rgbPalette[t]) - g;
+    iBlue   = qBlue  (rgbPalette[t]) - b;
+    iSquare = iRed*iRed + iGreen*iGreen + iBlue*iBlue;
+    
+    // Now let us check if we found a color closer then the previous one.
+    if (   iSquare  < iClosestColor   )  {
+      rgbReturn     = rgbPalette[t];
+      iClosestColor = iSquare;
+    }
+  }
+  return rgbReturn;
 }
 
-
 /** 
  * After a lot of frustration I decided to write this little (slow) routine, to 
  * - reduce the used colors to 4 AND
@@ -132,30 +212,36 @@ void Utils::reduceColors ( QImage &theImage, int iNumColors, QRgb *pPalette )
   bool bFound;
   uchar *pLine;
   unsigned long iCounter = 0;
-  int x, y, t, iIndex, iImageColors;
+  int  x, y, t, iIndex, iImageColors;
   QRgb theNearestColor, theColor, *pImageColors;
 
   // First we have to ensure that we do have a color indexed image.
-  theImage = theImage.convertDepthWithPalette (8, (QRgb *)pPalette, MAX_MASK_COLORS, Qt::ThresholdDither);
+  theImage = theImage.convertDepthWithPalette (8, (QRgb *)pPalette, iNumColors, Qt::ThresholdDither);
+
+//  theImage.save ( "/tmp/Unnamed/Main Menu VMGM/3.png", "PNG", 100);
+//printf ( "Image 3 has <%d> diff colors. Color Table size=<%d>\n", (int)countColors ( theImage ), //theImage.numColors ( ) );
+//for (x=0;x<theImage.numColors ();x++)
+//  printf ("colorTable[%d]=<%X>\n", x, theImage.color ( x ) );
 
   // This will create a image which might have more then the requested colors.
   // So we replace all colors with the nearest color of the four.
   pImageColors = theImage.colorTable ();
   iImageColors = theImage.numColors  ();
-
+//  printf ( "%s::%s:%d  <%d> <%d>\n",  __FILE__, __FUNCTION__, __LINE__, iImageColors, iNumColors );
   for (t=0;(int)t<iImageColors; t++) {
-    theNearestColor = nearestColor (pPalette, 4, pImageColors[t]);
-    //    theImage.setColor (t, theNearestColor & 0x00ffffff);
+    theNearestColor = nearestColor (pPalette, iNumColors, pImageColors[t]);
+//printf ( "color[%d]<%X> nearestFound<%X>\n", t, pImageColors[t], theNearestColor );
+//    theImage.setColor (t, theNearestColor & 0x00ffffff);
     theImage.setColor (t, theNearestColor );
   }
-  
+
   // Here we are going to shift all colors down to the first iNumColors places
   for (y=0;y<theImage.height();y++) {
     pLine = theImage.scanLine ( y );
     for (x=0;x<theImage.width();x++) {
       iIndex = pLine[x];
       theColor = theImage.color ( iIndex );
-      //      theColor &= 0x00ffffff; // disregard the alpha channel for now ...
+//      theColor &= 0x00ffffff; // disregard the alpha channel for now ...
       pLine[x] = 0;
       bFound = false;
       for ( t=0;t<iNumColors;t++ ) {
@@ -171,14 +257,14 @@ void Utils::reduceColors ( QImage &theImage, int iNumColors, QRgb *pPalette )
     }
   }
 
-  //  printf ( "numColors=%d width=<%d> height=<%d>\n", iImageColors, theImage.width(), theImage.height());
-  //  for (t=0;t<iImageColors;t++) {
-  //    printf ( "Color[%d] = %X", t, theImage.color (t));
-  //    if ( t<iNumColors )
-  //      printf ( " - Palette[%d] = %X", t, pPalette[t]);
-  //    printf ("\n");
-  //  }
-
+//  printf ( "numColors=%d width=<%d> height=<%d>\n", iImageColors, theImage.width(), theImage.height());
+//  for (t=0;t<iImageColors;t++) {
+//    printf ( "Color[%d] = %X", t, theImage.color (t));
+//    if ( t<iNumColors )
+//      printf ( " - Palette[%d] = %X", t, pPalette[t]);
+//    printf ("\n");
+//  }
+//  printf ("\n\n" );
   // Then we should cut down the number of colors used ...
   theImage.setNumColors ( iNumColors );
 
@@ -187,6 +273,64 @@ void Utils::reduceColors ( QImage &theImage, int iNumColors, QRgb *pPalette )
     theImage.setColor ( t, pPalette [t] );
 }
 
+long Utils::countColors ( QImage &theImage )
+{
+  bool bFound;
+  int  x, y, z, iIndex;
+
+  if ( theImage.depth () == 8 )  {
+    uchar *pLine;
+    QValueList<int> listFoundColors;
+    // Here we are going to shift all colors down to the first iNumColors places
+    for (y=0;y<theImage.height();y++) {
+      pLine = theImage.scanLine ( y );
+      for (x=0;x<theImage.width();x++) {
+        bFound=false;
+        iIndex = pLine[x];
+        for (z=0;z<(int)listFoundColors.count ();z++)  {
+          if ( iIndex == listFoundColors[z] )  {
+            z=listFoundColors.count ( );
+            bFound=true;
+          }
+        }
+        if ( !bFound )
+          listFoundColors.append ( iIndex );
+      }
+    }
+    return listFoundColors.count ();
+  }
+  else  { // 32 bits
+static bool bFirst=true;
+
+    QRgb *pLine, rgb;
+    QValueList<QRgb> listFoundColors;
+    for (y=0;y<theImage.height();y++) {
+      pLine = (QRgb *)theImage.scanLine ( y );
+      for (x=0;x<theImage.width();x++) {
+        bFound=false;
+        rgb = pLine[x];
+        for (z=0;z<(int)listFoundColors.count ();z++)  {
+          if ( rgb == listFoundColors[z] )  {
+            z=listFoundColors.count ( );
+            bFound=true;
+          }
+        }
+        if ( !bFound )
+          listFoundColors.append ( rgb );
+      }
+    }
+if ( bFirst )  {
+  qHeapSort ( listFoundColors );
+  for (z=0;z<(int)listFoundColors.count ();z++)  {
+    printf ( "[%d]=<%X>\n", z, listFoundColors[z] );
+  }
+  bFirst = false;
+}
+    return listFoundColors.count ();
+  }
+  return 0L;
+}
+
 QString Utils::getVideoFormat (int iWidth, int iHeight)
 {
 	QString qsFormat = ("custom");
@@ -227,7 +371,7 @@ int Utils::getFormat (int iWidth, int iHeight)
 	return iFormat;
 }
 
-QString Utils::iso639 (QString qsCode, bool bReverse)
+QString Utils::iso639 (QString qsCode, bool bReverse, int iWhich )
 {
 	// This function will return the Country name of the found two-letter - code
 	// according to the iso639 standard (ftp://dkuug.dk/i18n/ISO_639)
@@ -266,7 +410,12 @@ QString Utils::iso639 (QString qsCode, bool bReverse)
 	iReverse = 0;
 	if (bReverse)
 		iReverse = -1;
-	
+	if ( iWhich > -1 ) {
+	  if ( iWhich < (int)iCount )
+	    qsReturn = QString ((char *)arrayCountry[iWhich*2+1 + iReverse]);
+	  return qsReturn;
+	}
+	// else ...
 	for (t=0;t<iCount;t++)	{
 		if (qsCode == arrayCountry[t*2 - iReverse])	{
 			qsReturn = QString ((char *)arrayCountry[t*2+1 + iReverse]);
@@ -349,6 +498,19 @@ QString Utils::getToolByIndex (uint iIndex)
 	return QString (toolsArray[iIndex].pExecutableName);
 }
 
+QString Utils::getToolPath ( QString qsToolName )
+{
+  QString qsReturn;
+  Utils::toolsPaths *pToolPath;
+  uint t;
+  for ( t=0; t<Global::listToolsPaths.count ( ); t++ ) {
+    pToolPath = Global::listToolsPaths[ t ];
+    if ( pToolPath && ( pToolPath->qsExecutableName == qsToolName ) )
+      return pToolPath->qsFullPath;
+  }
+  return qsReturn;
+}
+
 QValueList<Utils::toolsPaths *>Utils::scanSystem()
 {
 	static QValueList<Utils::toolsPaths *>listToolsPaths;
@@ -400,20 +562,15 @@ QString Utils::getTempFile (QString qsOrigFileName)
 {
 	QString qsTempDir = Global::qsTempPath + QString ("/") +  Global::qsProjectName + QString ("/");
 	// we take this to check if the temp drive exists and if not, then we will create one ...
-	QDir tempDir (qsTempDir);
-	if (!tempDir.exists())
-		tempDir.mkdir (qsTempDir);
-	if (!tempDir.exists())	{
-		MessageBox::warning ( NULL, QObject::tr ("Could not create temp directory"),
-		QObject::tr ("Failed to create temp directory\n"
-			"%1").arg (qsTempDir),
-			QMessageBox::Ok, QMessageBox::NoButton);
-			return Global::qsTempPath + QString ("/");
-	}
+	QDir tempDir  ( qsTempDir );
+	if ( ! tempDir.exists ( ) )  {
+		 if ( ! recMkdir  ( qsTempDir ) )
+			 return Global::qsTempPath + QString ("/");
+    }
 	// Here we append the file name to the temp path ...
-	if (!qsOrigFileName.isEmpty())	{
-		QFileInfo fileInfo = QFileInfo(qsOrigFileName);
-		qsTempDir = QString (qsTempDir + fileInfo.fileName());
+	if ( ! qsOrigFileName.isEmpty ( ) )	{
+		QFileInfo fileInfo  = QFileInfo ( qsOrigFileName );
+		qsTempDir = QString ( qsTempDir + fileInfo.fileName ( ) );
 	}
 	return qsTempDir;
 }
@@ -423,13 +580,9 @@ QString Utils::getTempPath ( QString qsInputPath )
 {
   QString qsPath = getTempFile ( qsInputPath );
   QDir tempDir ( qsPath );
-  if ( ! tempDir.exists ( ) )
-    tempDir.mkdir ( qsPath );
   if ( ! tempDir.exists ( ) )  {
-    MessageBox::warning ( NULL, QObject::tr ("Could not create temp directory"),
-       QObject::tr ("Failed to create temp directory\n%1").arg ( qsPath ), 
-       QMessageBox::Ok, QMessageBox::NoButton);
-    return Global::qsTempPath + QString ("/");
+    if ( ! recMkdir ( qsPath ) )
+      return Global::qsTempPath + QString ("/");
   }
   return qsPath;
 }
@@ -489,7 +642,7 @@ QImage  Utils::convertStringToImage (QString &qsImage)
 
 	// Here we convert the hex values to char ...
 	for (t=0;t<qsImage.length();t++)
-		baData[t] = qsImage.mid (t*2, 2).toUInt(&bOk, 16);
+		baData.at ( t ) = qsImage.mid (t*2, 2).toUInt(&bOk, 16);
 	
 	QDataStream stream( baData, IO_ReadOnly );
 	stream >> theImage;
@@ -505,7 +658,7 @@ QString Utils::convertImageToString (QImage &theImage)
 	QDataStream stream( baData, IO_WriteOnly );
 	stream << (const QImage &)theImage;
 	for (t=0;t<baData.count();t++)	{
-		qsTemp.sprintf ("%02X", (uchar)baData[t]);
+		qsTemp.sprintf ("%02X", (uchar)baData.at ( t ) );
 		qsResult += qsTemp;
 	}
 //printf ("Utils::convertImageToString QByteArray<\n%s\n>\n", (const char *)qsResult);
@@ -547,6 +700,38 @@ bool Utils::recRmdir( const QString &dirName, const char *pExcludeFiles ) const
 	return dir.rmdir(dirN); // delete empty dir and return if (now empty) dir-removing was successfull
 }
 
+bool Utils::recMkdir ( const QString &qsDir )
+{
+	QDir theDir ( qsDir );
+	if ( theDir.exists ( ) )
+		return true;
+
+	int t;
+	QString qsFullPath, qsPartialDir;
+	qsFullPath = theDir.absPath ( );
+	QStringList dirList = QStringList::split ( "/", qsFullPath );
+
+	for ( t=0; t<(int)dirList.count ( ); t++ )  {
+		qsPartialDir += "/" + dirList[t];
+		theDir.setPath ( qsPartialDir );
+		if ( theDir.exists ( ) )
+			continue;
+		if ( ! theDir.mkdir ( qsPartialDir ) )
+			return false;
+	}
+
+	// Sanity check if the dir exists ...
+	theDir.setPath ( qsFullPath );
+    if ( ! theDir.exists ( ) )  {
+      MessageBox::warning ( NULL, QObject::tr ("Could not create temp directory"),
+      QObject::tr ("Failed to create temp directory\n%1\nPlease make sure you have the read/write access.").arg  ( qsFullPath ),
+      QMessageBox::Ok, QMessageBox::NoButton);
+      return false;
+    }
+
+	return true;
+}
+
 long Utils::getMsFromString(QString qsInput)
 {
   long iMilliSeconds;
@@ -689,18 +874,18 @@ bool Utils::hasVobus ( QString qsFileName )
   if ( ! theFile.open ( IO_ReadOnly ) )
     return false;
   
-  const long MAX_LENGTH=16384; // only looking at 1st 16KB - enough to contain nav packs
-  unsigned char buffer[MAX_LENGTH];
-  
   // skip zeroes at start of file
   int zeroCnt = 0;
   char c;
   while ( (c = (char)theFile.getch ( ) ) == 0)
     zeroCnt++;
   
-  if (zeroCnt < 2 || c != 1)
+  if (zeroCnt < 2 || c != 1) 
     return false;
-  
+ 
+  const long MAX_LENGTH=16384; // only looking at 1st 16KB - enough to contain nav packs
+  unsigned char *buffer = new unsigned char[MAX_LENGTH];
+
   buffer[0] = buffer[1] = 0; buffer[2] = 1;
   int iRead = theFile.readBlock ( (char *)(buffer+3), MAX_LENGTH-3);
   
@@ -724,9 +909,49 @@ bool Utils::hasVobus ( QString qsFileName )
 	  valid_dsi=true;
       }
       
-      if (valid_pci && valid_dsi)
-	return true;
+      if (valid_pci && valid_dsi) {
+		delete []buffer;
+        return true;
+	  }
     }
   
   return false;
 }
+
+bool Utils::checkCommand ( const char *pCommand )
+{
+  // executes a command and checks if there was a result
+  int iRet = 0;
+  QString qsCommand = QString ( "%1 > /tmp/test " ).arg ( pCommand );
+  iRet = system ( qsCommand.ascii ( ) );
+  QFile theFile ( "/tmp/test" );
+  if ( theFile.exists ( ) ) {
+    if ( theFile.size ( ) > 2 )
+      return true;
+    theFile.remove ( );
+  }
+  return false;
+}
+
+QString Utils::getDefaultParameter ( enDefaultParameter enWhich )
+{
+  QString qsReturn;
+  switch ( enWhich ) {
+    //For mjpegtools versions smaller than 1.8.0, use '-S 420_mpeg2' instead of '-S 420mpeg2' in your 'ppmtoy4m' line
+  case ppmtoy4mChroma: {
+    qsReturn = QString ( "420mpeg2" );
+    if ( checkCommand ( "ppmtoy4m -h 2>&1 | grep 420_mpeg2" ) )
+         qsReturn = QString ( "420_mpeg2" ); // must be mjpegtools version smaller then 1.8.0 !!!
+  }
+  break;
+  case toolameSampleRate:
+  default: {
+    qsReturn = QString ( "48000" ); // E.g. toolame 0.2m
+    // execute [toolame -h 2>&1 | grep sfrq | grep "rate in Hz" > /tmp/test ] and check if result is empty.
+    if ( checkCommand ( "toolame -h 2>&1 | grep sfrq | grep \"rate in kHz\"" ) )
+	 qsReturn = QString ( "48" ); // E.g.  toolame 0.2i
+  }
+  break;
+  };
+  return qsReturn;
+}
